import { Direction } from '@angular/cdk/bidi';
import { BooleanInput } from '@angular/cdk/coercion';
import { ElementRef, InputSignal, InputSignalWithTransform, ModelSignal, Signal } from '@angular/core';
import { DataOrientation } from '@radix-ng/primitives/core';
import * as i0 from "@angular/core";
type AcceptableValue = string | Record<string, any> | null;
export type AccordionRootContext = {
    disabled: InputSignalWithTransform<boolean, BooleanInput>;
    direction: InputSignal<Direction>;
    orientation: InputSignal<DataOrientation>;
    value: ModelSignal<AcceptableValue | AcceptableValue[] | undefined>;
    collapsible: Signal<boolean>;
    isSingle: Signal<boolean>;
    elementRef: ElementRef<HTMLElement>;
    changeModelValue: (value: string) => void;
};
export declare const injectAccordionRootContext: (optional?: boolean) => AccordionRootContext | null, provideAccordionRootContext: (useFactory: () => AccordionRootContext) => import("@angular/core").Provider;
/**
 * @group Components
 */
export declare class RdxAccordionRootDirective {
    readonly elementRef: ElementRef<HTMLElement>;
    readonly id: InputSignal<string>;
    /**
     * The reading direction of the accordion when applicable. If omitted, assumes LTR (left-to-right) reading mode.
     *
     * @group Props
     */
    readonly dir: InputSignal<Direction>;
    /** Whether the Accordion is disabled.
     * @defaultValue false
     * @group Props
     */
    readonly disabled: InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The orientation of the accordion.
     *
     * @defaultValue 'vertical'
     * @group Props
     */
    readonly orientation: InputSignal<DataOrientation>;
    /**
     * The default active value of the item(s).
     *
     * Use when you do not need to control the state of the item(s).
     * @group Props
     */
    readonly defaultValue: InputSignal<string | string[] | undefined>;
    /**
     * The controlled value of the item to expand.
     *
     * @group Props
     */
    readonly value: ModelSignal<AcceptableValue | AcceptableValue[] | undefined>;
    /**
     * When type is "single", allows closing content when clicking trigger for an open item.
     * When type is "multiple", this prop has no effect.
     *
     * @defaultValue false
     * @group Props
     */
    readonly collapsible: InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Determines whether a "single" or "multiple" items can be selected at a time.
     *
     * @defaultValue 'single'
     * @group Props
     */
    readonly type: InputSignal<"multiple" | "single">;
    /**
     * Event handler called when the expanded state of an item changes and type is "multiple".
     * @group Emits
     */
    readonly onValueChange: import("@angular/core").OutputEmitterRef<void>;
    readonly isSingle: Signal<boolean>;
    constructor();
    changeModelValue: (newValue: string) => void;
    private isValueEqualOrExist;
    private isEqual;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxAccordionRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxAccordionRootDirective, "[rdxAccordionRoot]", ["rdxAccordionRoot"], { "id": { "alias": "id"; "required": false; "isSignal": true; }; "dir": { "alias": "dir"; "required": false; "isSignal": true; }; "disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; "orientation": { "alias": "orientation"; "required": false; "isSignal": true; }; "defaultValue": { "alias": "defaultValue"; "required": false; "isSignal": true; }; "value": { "alias": "value"; "required": false; "isSignal": true; }; "collapsible": { "alias": "collapsible"; "required": false; "isSignal": true; }; "type": { "alias": "type"; "required": false; "isSignal": true; }; }, { "value": "valueChange"; "onValueChange": "onValueChange"; }, never, never, true, never>;
}
export {};
