import { NumberInput } from '@angular/cdk/coercion';
import { AfterViewInit } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Directive to maintain an aspect ratio for an element.
 * The element will have its `padding-bottom` dynamically calculated
 * based on the provided aspect ratio to maintain the desired ratio.
 * The content inside the element will be positioned absolutely.
 * @group Components
 */
export declare class RdxAspectRatioDirective implements AfterViewInit {
    private readonly element;
    private readonly renderer;
    /**
     * The desired aspect ratio (e.g., 16/9).
     * By default, it is set to 1 (which results in a square, 1:1).
     * @group Props
     * @defaultValue 1
     */
    readonly ratio: import("@angular/core").InputSignalWithTransform<number, NumberInput>;
    /**
     * Dynamically computed `padding-bottom` style for the element.
     * This value is calculated based on the inverse of the aspect ratio.
     *
     * If the ratio is zero, it defaults to `0%` to avoid division by zero.
     *
     */
    protected readonly paddingBottom: import("@angular/core").Signal<string>;
    ngAfterViewInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxAspectRatioDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxAspectRatioDirective, "[rdxAspectRatio]", ["rdxAspectRatio"], { "ratio": { "alias": "ratio"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}
