import { BooleanInput } from '@angular/cdk/coercion';
import { AfterViewInit } from '@angular/core';
import { DateValue } from '@internationalized/date';
import { DateMatcher, Formatter, Month } from '@radix-ng/primitives/core';
import * as i0 from "@angular/core";
export declare class RdxCalendarRootDirective implements AfterViewInit {
    private readonly elementRef;
    /**
     * The controlled checked state of the calendar
     */
    readonly value: import("@angular/core").ModelSignal<DateValue | DateValue[] | undefined>;
    /**
     * The default placeholder date
     */
    readonly defaultPlaceholder: import("@angular/core").ModelSignal<DateValue | undefined>;
    readonly locale: import("@angular/core").InputSignal<string>;
    readonly defaultDate: DateValue;
    /**
     * The placeholder date, which is used to determine what month to display when no date is selected.
     * This updates as the user navigates the calendar and can be used to programmatically control the calendar view
     */
    readonly placeholder: import("@angular/core").ModelSignal<DateValue>;
    readonly multiple: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether to always display 6 weeks in the calendar
     */
    readonly fixedWeeks: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether the calendar is disabled
     */
    readonly disabled: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether to prevent the user from deselecting a date without selecting another date first
     */
    readonly preventDeselect: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The day of the week to start the calendar on
     */
    readonly weekStartsOn: import("@angular/core").InputSignal<0 | 1 | 2 | 3 | 4 | 5 | 6>;
    /**
     * The number of months to display at once
     */
    readonly numberOfMonths: import("@angular/core").InputSignal<number>;
    /**
     * The reading direction of the calendar when applicable.
     */
    readonly dir: import("@angular/core").InputSignal<"ltr" | "rtl">;
    /**
     * The minimum date that can be selected
     */
    readonly minValue: import("@angular/core").InputSignal<DateValue | undefined>;
    /**
     * The maximum date that can be selected
     */
    readonly maxValue: import("@angular/core").InputSignal<DateValue | undefined>;
    /**
     * The format to use for the weekday strings provided via the weekdays slot prop
     */
    readonly weekdayFormat: import("@angular/core").InputSignal<"long" | "short" | "narrow" | undefined>;
    /**
     * The accessible label for the calendar
     */
    readonly calendarLabel: import("@angular/core").InputSignal<string | undefined>;
    /**
     * Whether the calendar is readonly
     */
    readonly readonly: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * This property causes the previous and next buttons to navigate by the number of months displayed at once, rather than one month
     */
    readonly pagedNavigation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    readonly propsNextPage: import("@angular/core").InputSignal<((placeholder: DateValue) => DateValue) | undefined>;
    readonly propsPrevPage: import("@angular/core").InputSignal<((placeholder: DateValue) => DateValue) | undefined>;
    /**
     * A function that returns whether a date is disabled
     */
    readonly isDateDisabled: import("@angular/core").InputSignal<DateMatcher | undefined>;
    /**
     * A function that returns whether a date is unavailable
     */
    readonly isDateUnavailable: import("@angular/core").InputSignal<DateMatcher | undefined>;
    readonly initialFocus: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    readonly months: import("@angular/core").ModelSignal<Month<DateValue>[] | undefined>;
    /**
     * The days of the week
     */
    readonly weekDays: import("@angular/core").ModelSignal<string[] | undefined>;
    protected readonly _fixedWeeks: import("@angular/core").WritableSignal<boolean>;
    protected readonly _disabled: import("@angular/core").WritableSignal<boolean>;
    protected readonly _pagedNavigation: import("@angular/core").WritableSignal<boolean>;
    /**
     * @ignore
     */
    readonly headingValue: import("@angular/core").WritableSignal<string>;
    /**
     * @ignore
     */
    readonly fullCalendarLabel: import("@angular/core").WritableSignal<string>;
    /**
     * @ignore
     */
    nextPage: (nextPageFunc?: (date: DateValue) => DateValue) => void;
    /**
     * @ignore
     */
    prevPage: (nextPageFunc?: (date: DateValue) => DateValue) => void;
    /**
     * @ignore
     */
    isNextButtonDisabled: (nextPageFunc?: (date: DateValue) => DateValue) => boolean;
    /**
     * @ignore
     */
    isPrevButtonDisabled: (nextPageFunc?: (date: DateValue) => DateValue) => boolean;
    /**
     * @ignore
     */
    isDateSelected: DateMatcher;
    /**
     * @ignore
     */
    isInvalid: boolean;
    /**
     * @ignore
     */
    isOutsideVisibleView: (date: DateValue) => boolean;
    /**
     * @ignore
     */
    formatter: Formatter;
    /**
     * @ignore
     */
    currentElement: HTMLElement;
    private readonly calendar;
    constructor();
    ngAfterViewInit(): void;
    /**
     * @ignore
     */
    onPlaceholderChange(value: DateValue): void;
    /**
     * @ignore
     */
    onDateChange(date: DateValue): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxCalendarRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxCalendarRootDirective, "[rdxCalendarRoot]", ["rdxCalendarRoot"], { "value": { "alias": "value"; "required": false; "isSignal": true; }; "defaultPlaceholder": { "alias": "defaultPlaceholder"; "required": false; "isSignal": true; }; "locale": { "alias": "locale"; "required": false; "isSignal": true; }; "placeholder": { "alias": "placeholder"; "required": false; "isSignal": true; }; "multiple": { "alias": "multiple"; "required": false; "isSignal": true; }; "fixedWeeks": { "alias": "fixedWeeks"; "required": false; "isSignal": true; }; "disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; "preventDeselect": { "alias": "preventDeselect"; "required": false; "isSignal": true; }; "weekStartsOn": { "alias": "weekStartsOn"; "required": false; "isSignal": true; }; "numberOfMonths": { "alias": "numberOfMonths"; "required": false; "isSignal": true; }; "dir": { "alias": "dir"; "required": false; "isSignal": true; }; "minValue": { "alias": "minValue"; "required": false; "isSignal": true; }; "maxValue": { "alias": "maxValue"; "required": false; "isSignal": true; }; "weekdayFormat": { "alias": "weekdayFormat"; "required": false; "isSignal": true; }; "calendarLabel": { "alias": "calendarLabel"; "required": false; "isSignal": true; }; "readonly": { "alias": "readonly"; "required": false; "isSignal": true; }; "pagedNavigation": { "alias": "pagedNavigation"; "required": false; "isSignal": true; }; "propsNextPage": { "alias": "propsNextPage"; "required": false; "isSignal": true; }; "propsPrevPage": { "alias": "propsPrevPage"; "required": false; "isSignal": true; }; "isDateDisabled": { "alias": "isDateDisabled"; "required": false; "isSignal": true; }; "isDateUnavailable": { "alias": "isDateUnavailable"; "required": false; "isSignal": true; }; "initialFocus": { "alias": "initialFocus"; "required": false; "isSignal": true; }; "months": { "alias": "months"; "required": false; "isSignal": true; }; "weekDays": { "alias": "weekDays"; "required": false; "isSignal": true; }; }, { "value": "valueChange"; "defaultPlaceholder": "defaultPlaceholderChange"; "placeholder": "placeholderChange"; "months": "monthsChange"; "weekDays": "weekDaysChange"; }, never, never, true, never>;
}
