import { InputSignal, ModelSignal, WritableSignal } from '@angular/core';
import { DateValue } from '@internationalized/date';
import { DateMatcher, Month } from '@radix-ng/primitives/core';
export type CalendarProps = {
    locale: InputSignal<string>;
    placeholder: WritableSignal<DateValue>;
    weekStartsOn: InputSignal<0 | 1 | 2 | 3 | 4 | 5 | 6>;
    fixedWeeks: WritableSignal<boolean>;
    numberOfMonths: InputSignal<number>;
    minValue: InputSignal<DateValue | undefined>;
    maxValue: InputSignal<DateValue | undefined>;
    disabled: WritableSignal<boolean>;
    weekdayFormat: InputSignal<Intl.DateTimeFormatOptions['weekday']>;
    pagedNavigation: WritableSignal<boolean>;
    isDateDisabled?: InputSignal<DateMatcher | undefined>;
    isDateUnavailable?: InputSignal<DateMatcher | undefined>;
    calendarLabel: InputSignal<string | undefined>;
    nextPage: InputSignal<((placeholder: DateValue) => DateValue) | undefined>;
    prevPage: InputSignal<((placeholder: DateValue) => DateValue) | undefined>;
};
export type CalendarStateProps = {
    date: ModelSignal<DateValue | DateValue[] | undefined>;
    isDateDisabled?: DateMatcher;
    isDateUnavailable?: DateMatcher;
};
export declare function calendarState(props: CalendarStateProps): {
    isDateSelected: (dateObj: DateValue) => boolean;
    isInvalid: import("@angular/core").Signal<boolean>;
};
export declare function calendar(props: CalendarProps): {
    isDateDisabled: (dateObj: DateValue) => boolean;
    isDateUnavailable: (date: DateValue) => boolean;
    isNextButtonDisabled: (nextPageFunc?: (date: DateValue) => DateValue) => boolean;
    isPrevButtonDisabled: (prevPageFunc?: (date: DateValue) => DateValue) => boolean;
    month: WritableSignal<Month<DateValue>[]>;
    weekdays: import("@angular/core").Signal<string[]>;
    visibleView: import("@angular/core").Signal<DateValue[]>;
    isOutsideVisibleView: (date: DateValue) => boolean;
    formatter: import("@radix-ng/primitives/core").Formatter;
    nextPage: (nextPageFunc?: (date: DateValue) => DateValue) => void;
    prevPage: (prevPageFunc?: (date: DateValue) => DateValue) => void;
    headingValue: import("@angular/core").Signal<string>;
    fullCalendarLabel: import("@angular/core").Signal<string>;
};
