import { EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
export type CheckboxState = 'unchecked' | 'checked' | 'indeterminate';
/**
 * @group Components
 */
export declare class RdxCheckboxRootDirective implements ControlValueAccessor, OnChanges {
    /**
     * The controlled checked state of the checkbox. Must be used in conjunction with onCheckedChange.
     * @group Props
     */
    checked: boolean;
    /**
     * Defines whether the checkbox is indeterminate.
     * @group Props
     */
    indeterminate: boolean;
    /**
     * Defines whether the checkbox is disabled.
     * @group Props
     */
    disabled: boolean;
    /**
     * @group Props
     */
    required: boolean;
    /**
     * Event emitted when the checkbox checked state changes.
     * @group Emits
     */
    readonly checkedChange: EventEmitter<boolean>;
    /**
     * Event emitted when the indeterminate state changes.
     * @group Emits
     */
    readonly indeterminateChange: EventEmitter<boolean>;
    /**
     * Determine the state
     */
    get state(): CheckboxState;
    /**
     * Store the callback function that should be called when the checkbox checked state changes.
     * @internal
     */
    private onChange?;
    /**
     * Store the callback function that should be called when the checkbox is blurred.
     * @internal
     */
    private onTouched?;
    protected onKeyDown(event: KeyboardEvent): void;
    protected onClick($event: MouseEvent): void;
    protected onBlur(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Sets the checked state of the checkbox.
     * @param checked The checked state of the checkbox.
     * @internal
     */
    writeValue(checked: boolean): void;
    /**
     * Registers a callback function that should be called when the checkbox checked state changes.
     * @param fn The callback function.
     * @internal
     */
    registerOnChange(fn: (checked: boolean) => void): void;
    /**
     * Registers a callback function that should be called when the checkbox is blurred.
     * @param fn The callback function.
     * @internal
     */
    registerOnTouched(fn: () => void): void;
    /**
     * Sets the disabled state of the checkbox.
     * @param isDisabled The disabled state of the checkbox.
     * @internal
     */
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxCheckboxRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxCheckboxRootDirective, "[rdxCheckboxRoot]", never, { "checked": { "alias": "checked"; "required": false; }; "indeterminate": { "alias": "indeterminate"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "checkedChange": "checkedChange"; "indeterminateChange": "indeterminateChange"; }, never, never, true, never>;
    static ngAcceptInputType_checked: unknown;
    static ngAcceptInputType_indeterminate: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_required: unknown;
}
