import { BooleanInput } from '@angular/cdk/coercion';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * A reusable ControlValueAccessor implementation for form controls
 * @template T The type of the control's value
 */
export declare class RdxControlValueAccessor<T> implements ControlValueAccessor {
    /**
     * Input for the control's value with alias 'value'
     * @default undefined
     */
    readonly valueInput: import("@angular/core").InputSignal<T | undefined>;
    /**
     * Input for the disabled state with alias 'disabled'
     * Uses booleanAttribute transform to convert string attributes to booleans
     * @default false
     */
    readonly disabledInput: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    readonly valueChange: import("@angular/core").OutputEmitterRef<T>;
    private readonly _value;
    /**
     * Readonly access to the current value
     */
    readonly value: import("@angular/core").Signal<T | undefined>;
    private readonly _disabled;
    /**
     * Readonly access to the disabled state
     */
    readonly disabled: import("@angular/core").Signal<boolean>;
    onChange?: (value: T | undefined) => void;
    private onTouched?;
    /**
     * Writes a new value to the control (ControlValueAccessor interface)
     * @param value The new value for the control
     */
    writeValue(value: T | undefined): void;
    /**
     * Registers a callback for when the control value changes (ControlValueAccessor interface)
     * @param fn The callback function
     */
    registerOnChange(fn: (value: T | undefined) => void): void;
    /**
     * Registers a callback for when the control is touched (ControlValueAccessor interface)
     * @param fn The callback function
     */
    registerOnTouched(fn: () => void): void;
    /**
     * Sets the disabled state of the control (ControlValueAccessor interface)
     * @param isDisabled Whether the control should be disabled
     */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Updates the control's value and triggers change detection
     * @param value The new value
     */
    setValue(value: T): void;
    markAsTouched(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxControlValueAccessor<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxControlValueAccessor<any>, never, ["rdxControlValueAccessor"], { "valueInput": { "alias": "value"; "required": false; "isSignal": true; }; "disabledInput": { "alias": "disabled"; "required": false; "isSignal": true; }; }, { "valueChange": "valueChange"; }, never, never, true, never>;
}
/**
 * Provides a type-safe way to inject the RdxControlValueAccessor
 * @template T The type of the control's value
 * @returns An instance of RdxControlValueAccessor<T>
 */
export declare function injectControlValueAccessor<T>(): RdxControlValueAccessor<T>;
