import { Direction } from '@angular/cdk/bidi';
import { BooleanInput } from '@angular/cdk/coercion';
import { AfterViewInit, OnInit } from '@angular/core';
import { DateValue } from '@internationalized/date';
import { DateMatcher, DateStep, Formatter, Granularity, HourCycle, SegmentValueObj } from '@radix-ng/primitives/core';
import * as i0 from "@angular/core";
export declare class RdxDateFieldRootDirective implements OnInit, AfterViewInit {
    private readonly elementRef;
    /**
     * The controlled checked state of the calendar.
     */
    readonly value: import("@angular/core").ModelSignal<DateValue | undefined>;
    /**
     * A callback fired when the date field's value is invalid.
     */
    readonly isDateUnavailable: import("@angular/core").InputSignal<DateMatcher | undefined>;
    /**
     * The hour cycle to use for formatting times. Defaults to the locale preference
     */
    readonly hourCycle: import("@angular/core").InputSignal<HourCycle>;
    /**
     * The granularity to use for formatting the field. Defaults to 'day' if a CalendarDate is provided, otherwise defaults to 'minute'.
     * The field will render segments for each part of the date up to and including the specified granularity.
     */
    readonly granularity: import("@angular/core").InputSignal<Granularity | undefined>;
    /**
     * The locale to use for formatting dates.
     */
    readonly locale: import("@angular/core").InputSignal<string>;
    readonly dir: import("@angular/core").InputSignal<Direction>;
    /**
     * The minimum valid date that can be entered.
     */
    readonly minValue: import("@angular/core").InputSignal<DateValue | undefined>;
    /**
     * The maximum valid date that can be entered.
     */
    readonly maxValue: import("@angular/core").InputSignal<DateValue | undefined>;
    /**
     * Whether or not to hide the time zone segment of the field.
     */
    readonly hideTimeZone: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    readonly disabled: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether or not the field is readonly.
     */
    readonly readonly: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The stepping interval for the time fields. Defaults to 1
     */
    readonly step: import("@angular/core").InputSignal<DateStep | undefined>;
    readonly step$: import("@angular/core").Signal<DateStep>;
    /**
     * @ignore
     */
    readonly defaultDate: import("@angular/core").Signal<DateValue>;
    /**
     * The placeholder date, which is used to determine what month to display when no date is selected. This updates as the user navigates the calendar and can be used to programmatically control the calendar view
     */
    readonly placeholder: import("@angular/core").ModelSignal<DateValue | undefined>;
    /**
     * @ignore
     */
    readonly segmentElements: import("@angular/core").WritableSignal<Set<HTMLElement>>;
    /**
     * @ignore
     */
    readonly currentFocusedElement: import("@angular/core").WritableSignal<HTMLElement | null>;
    /**
     * @ignore
     */
    formatter: Formatter;
    /**
     * @ignore
     */
    readonly segmentValues: import("@angular/core").WritableSignal<SegmentValueObj>;
    /**
     * @ignore
     */
    readonly inferredGranularity: import("@angular/core").Signal<Granularity | undefined>;
    /**
     * @ignore
     */
    readonly isInvalid: import("@angular/core").Signal<boolean>;
    /**
     * @ignore
     */
    readonly allSegmentContent: import("@angular/core").Signal<{
        obj: import("@radix-ng/primitives/core").SegmentContentObj;
        arr: {
            part: import("@radix-ng/primitives/core").SegmentPart;
            value: string;
        }[];
    }>;
    /**
     * An array of segments that should be readonly, which prevent user input on them.
     */
    readonly segmentContents: import("@angular/core").Signal<{
        part: import("@radix-ng/primitives/core").SegmentPart;
        value: string;
    }[]>;
    /**
     * @ignore
     */
    readonly currentSegmentIndex: import("@angular/core").Signal<number>;
    /**
     * @ignore
     */
    readonly prevFocusableSegment: import("@angular/core").Signal<HTMLElement | null>;
    /**
     * @ignore
     */
    readonly nextFocusableSegment: import("@angular/core").Signal<HTMLElement | null>;
    /**
     * @ignore
     */
    readonly focusNext: () => void;
    constructor();
    ngOnInit(): void;
    ngAfterViewInit(): void;
    /**
     * @ignore
     */
    onKeydown(event: KeyboardEvent): void;
    /**
     * @ignore
     */
    setFocusedElement(el: HTMLElement): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxDateFieldRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxDateFieldRootDirective, "[rdxDateFieldRoot]", ["rdxDateFieldRoot"], { "value": { "alias": "value"; "required": false; "isSignal": true; }; "isDateUnavailable": { "alias": "isDateUnavailable"; "required": false; "isSignal": true; }; "hourCycle": { "alias": "hourCycle"; "required": false; "isSignal": true; }; "granularity": { "alias": "granularity"; "required": false; "isSignal": true; }; "locale": { "alias": "locale"; "required": false; "isSignal": true; }; "dir": { "alias": "dir"; "required": false; "isSignal": true; }; "minValue": { "alias": "minValue"; "required": false; "isSignal": true; }; "maxValue": { "alias": "maxValue"; "required": false; "isSignal": true; }; "hideTimeZone": { "alias": "hideTimeZone"; "required": false; "isSignal": true; }; "disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; "readonly": { "alias": "readonly"; "required": false; "isSignal": true; }; "step": { "alias": "step"; "required": false; "isSignal": true; }; "placeholder": { "alias": "placeholder"; "required": false; "isSignal": true; }; }, { "value": "valueChange"; "placeholder": "placeholderChange"; }, never, never, true, never>;
}
