import { DialogRef } from '@angular/cdk/dialog';
import { Observable } from 'rxjs';
import { RdxDialogConfig, RdxDialogResult } from './dialog.config';
export declare const DISMISSED_VALUE: {};
/**
 * Represents a reference to an open dialog.
 * Provides methods and observables to interact with and monitor the dialog's state.
 * @template C - The type of the dialog's content component
 */
export declare class RdxDialogRef<C = unknown> {
    readonly cdkRef: DialogRef<RdxDialogResult<C> | typeof DISMISSED_VALUE, C>;
    readonly config: RdxDialogConfig<C>;
    private _previousTimeout;
    private readonly _openSignal;
    readonly state: import("@angular/core").Signal<"open" | "closed">;
    closed$: Observable<RdxDialogResult<C> | undefined>;
    dismissed$: Observable<void>;
    result$: Observable<RdxDialogResult<C>>;
    /**
     * @param cdkRef - Reference to the underlying CDK dialog
     * @param config - Configuration options for the dialog
     */
    constructor(cdkRef: DialogRef<RdxDialogResult<C> | typeof DISMISSED_VALUE, C>, config: RdxDialogConfig<C>);
    get instance(): C | null;
    /**
     * Attempts to dismiss the dialog
     * Checks the canClose condition before dismissing
     */
    dismiss(): void;
    close(result: RdxDialogResult<C>): void;
}
/**
 * Represents a simplified interface for dialog interaction
 * Typically used by dialog content components
 * @template R - The type of the result when closing the dialog
 */
export type RdxDialogSelfRef<R> = {
    dismiss(): void;
    close(res: R): void;
};
