import * as i0 from '@angular/core';
import { Directive, inject, ElementRef, input, booleanAttribute, model, output, computed, effect, NgModule } from '@angular/core';
import * as i1 from '@radix-ng/primitives/collapsible';
import { RdxCollapsibleContentPresenceDirective, injectCollapsibleRootContext, RdxCollapsibleRootDirective, RdxCollapsibleContentDirective, RdxCollapsibleTriggerDirective } from '@radix-ng/primitives/collapsible';
import { createContext, useArrowNavigation } from '@radix-ng/primitives/core';
import { _IdGenerator } from '@angular/cdk/a11y';

class RdxAccordionContentPresenceDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionContentPresenceDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAccordionContentPresenceDirective, isStandalone: true, selector: "ng-template[rdxAccordionContentPresence]", hostDirectives: [{ directive: i1.RdxCollapsibleContentPresenceDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionContentPresenceDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[rdxAccordionContentPresence]',
                    hostDirectives: [RdxCollapsibleContentPresenceDirective]
                }]
        }] });

const [injectAccordionRootContext, provideAccordionRootContext] = createContext('AccordionRootContext');
const rootContext = () => {
    const instance = inject(RdxAccordionRootDirective);
    return {
        disabled: instance.disabled,
        direction: instance.dir,
        collapsible: instance.collapsible,
        orientation: instance.orientation,
        elementRef: instance.elementRef,
        value: instance.value,
        isSingle: instance.isSingle,
        changeModelValue: instance.changeModelValue
    };
};
/**
 * @group Components
 */
class RdxAccordionRootDirective {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.id = input(inject(_IdGenerator).getId('rdx-accordion-'));
        /**
         * The reading direction of the accordion when applicable. If omitted, assumes LTR (left-to-right) reading mode.
         *
         * @group Props
         */
        this.dir = input('ltr');
        /** Whether the Accordion is disabled.
         * @defaultValue false
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        /**
         * The orientation of the accordion.
         *
         * @defaultValue 'vertical'
         * @group Props
         */
        this.orientation = input('vertical');
        /**
         * The default active value of the item(s).
         *
         * Use when you do not need to control the state of the item(s).
         * @group Props
         */
        this.defaultValue = input();
        /**
         * The controlled value of the item to expand.
         *
         * @group Props
         */
        this.value = model();
        /**
         * When type is "single", allows closing content when clicking trigger for an open item.
         * When type is "multiple", this prop has no effect.
         *
         * @defaultValue false
         * @group Props
         */
        this.collapsible = input(false, { transform: booleanAttribute });
        /**
         * Determines whether a "single" or "multiple" items can be selected at a time.
         *
         * @defaultValue 'single'
         * @group Props
         */
        this.type = input('single');
        /**
         * Event handler called when the expanded state of an item changes and type is "multiple".
         * @group Emits
         */
        this.onValueChange = output();
        this.isSingle = computed(() => this.type() === 'single');
        this.changeModelValue = (newValue) => {
            if (this.type() === 'single') {
                this.value.set(this.isEqual(newValue, this.value()) ? undefined : newValue);
            }
            else {
                const currentValue = this.value();
                let modelValueArray = [];
                if (Array.isArray(currentValue)) {
                    modelValueArray = [...currentValue];
                }
                else if (currentValue !== undefined && currentValue !== null) {
                    modelValueArray = [currentValue];
                }
                if (this.isValueEqualOrExist(modelValueArray, newValue)) {
                    const index = modelValueArray.findIndex((item) => this.isEqual(item, newValue));
                    if (index !== -1) {
                        modelValueArray.splice(index, 1);
                    }
                }
                else {
                    modelValueArray.push(newValue);
                }
                this.value.set(modelValueArray);
            }
        };
        effect(() => {
            if (this.defaultValue() !== undefined) {
                this.value.set(this.defaultValue());
            }
        });
    }
    isValueEqualOrExist(arr, value) {
        return arr.some((item) => this.isEqual(item, value));
    }
    isEqual(a, b) {
        return JSON.stringify(a) === JSON.stringify(b);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxAccordionRootDirective, isStandalone: true, selector: "[rdxAccordionRoot]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, dir: { classPropertyName: "dir", publicName: "dir", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, orientation: { classPropertyName: "orientation", publicName: "orientation", isSignal: true, isRequired: false, transformFunction: null }, defaultValue: { classPropertyName: "defaultValue", publicName: "defaultValue", isSignal: true, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, collapsible: { classPropertyName: "collapsible", publicName: "collapsible", isSignal: true, isRequired: false, transformFunction: null }, type: { classPropertyName: "type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { properties: { "attr.data-orientation": "orientation()" } }, providers: [provideAccordionRootContext(rootContext)], exportAs: ["rdxAccordionRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAccordionRoot]',
                    exportAs: 'rdxAccordionRoot',
                    providers: [provideAccordionRootContext(rootContext)],
                    host: {
                        '[attr.data-orientation]': 'orientation()'
                    }
                }]
        }], ctorParameters: () => [] });

const [injectAccordionItemContext, provideAccordionItemContext] = createContext('AccordionItemContext');
const itemContext = () => {
    const instance = inject(RdxAccordionItemDirective);
    return {
        open: instance.open,
        dataState: instance.dataState,
        disabled: instance.disabled,
        dataDisabled: instance.isDisabled,
        triggerId: '',
        currentElement: instance.elementRef,
        value: computed(() => instance.value()),
        updateOpen: instance.updateOpen
    };
};
/**
 * @group Components
 */
class RdxAccordionItemDirective {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.collapsibleContext = injectCollapsibleRootContext();
        this.rootContext = injectAccordionRootContext();
        /**
         * A string value for the accordion item. All items within an accordion should use a unique value.
         * @group Props
         */
        this.value = input();
        /**
         * Whether or not an accordion item is disabled from user interaction.
         * When `true`, prevents the user from interacting with the item.
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        this.isDisabled = computed(() => {
            return this.rootContext.disabled() || this.disabled();
        });
        this.open = computed(() => this.rootContext.isSingle()
            ? this.value() === this.rootContext.value()
            : Array.isArray(this.rootContext.value()) && this.rootContext.value().includes(this.value()));
        this.dataState = computed(() => (this.open() ? 'open' : 'closed'));
        this.updateOpen = () => {
            this.collapsibleContext.open.set(this.open());
        };
        effect(() => {
            this.updateOpen();
        });
    }
    handleArrowKey(event) {
        const target = event.target;
        const allCollectionItems = Array.from(this.rootContext.elementRef.nativeElement?.querySelectorAll('[data-rdx-collection-item]') ?? []);
        const collectionItemIndex = allCollectionItems.findIndex((item) => item === target);
        if (collectionItemIndex === -1)
            return;
        useArrowNavigation(event, this.elementRef.nativeElement.querySelector('[data-rdx-collection-item]'), this.rootContext.elementRef.nativeElement, {
            arrowKeyOptions: this.rootContext.orientation(),
            dir: this.rootContext.direction(),
            focus: true
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxAccordionItemDirective, isStandalone: true, selector: "[rdxAccordionItem]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "keydown.arrowDown": "handleArrowKey($event)", "keydown.arrowUp": "handleArrowKey($event)", "keydown.arrowLeft": "handleArrowKey($event)", "keydown.arrowRight": "handleArrowKey($event)", "keydown.home": "handleArrowKey($event)", "keydown.end": "handleArrowKey($event)" }, properties: { "attr.data-orientation": "rootContext.orientation()", "attr.data-disabled": "disabled() ? \"\" : undefined", "attr.data-state": "dataState()" } }, providers: [provideAccordionItemContext(itemContext)], exportAs: ["rdxAccordionItem"], hostDirectives: [{ directive: i1.RdxCollapsibleRootDirective, inputs: ["disabled", "disabled", "open", "open"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAccordionItem]',
                    exportAs: 'rdxAccordionItem',
                    providers: [provideAccordionItemContext(itemContext)],
                    hostDirectives: [
                        {
                            directive: RdxCollapsibleRootDirective,
                            inputs: ['disabled: disabled', 'open: open']
                        }
                    ],
                    host: {
                        '[attr.data-orientation]': 'rootContext.orientation()',
                        '[attr.data-disabled]': 'disabled() ? "" : undefined',
                        '[attr.data-state]': 'dataState()',
                        '(keydown.arrowDown)': 'handleArrowKey($event)',
                        '(keydown.arrowUp)': 'handleArrowKey($event)',
                        '(keydown.arrowLeft)': 'handleArrowKey($event)',
                        '(keydown.arrowRight)': 'handleArrowKey($event)',
                        '(keydown.home)': 'handleArrowKey($event)',
                        '(keydown.end)': 'handleArrowKey($event)'
                    }
                }]
        }], ctorParameters: () => [] });

class RdxAccordionContentDirective {
    constructor() {
        this.rootContext = injectAccordionRootContext();
        this.itemContext = injectAccordionItemContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAccordionContentDirective, isStandalone: true, selector: "[rdxAccordionContent]", host: { attributes: { "role": "region" }, properties: { "attr.aria-labelledby": "itemContext.triggerId", "attr.data-state": "itemContext.dataState()", "attr.data-disabled": "itemContext.dataDisabled()", "attr.data-orientation": "rootContext.orientation()", "style": "{\n            '--radix-accordion-content-height': 'var(--radix-collapsible-content-height)',\n            '--radix-accordion-content-width': 'var(--radix-collapsible-content-width)',\n          }" } }, hostDirectives: [{ directive: i1.RdxCollapsibleContentDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAccordionContent]',
                    hostDirectives: [RdxCollapsibleContentDirective],
                    host: {
                        role: 'region',
                        '[attr.aria-labelledby]': 'itemContext.triggerId',
                        '[attr.data-state]': 'itemContext.dataState()',
                        '[attr.data-disabled]': 'itemContext.dataDisabled()',
                        '[attr.data-orientation]': 'rootContext.orientation()',
                        '[style]': `{
            '--radix-accordion-content-height': 'var(--radix-collapsible-content-height)',
            '--radix-accordion-content-width': 'var(--radix-collapsible-content-width)',
          }`
                    }
                }]
        }] });

class RdxAccordionHeaderDirective {
    constructor() {
        this.rootContext = injectAccordionRootContext();
        this.itemContext = injectAccordionItemContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionHeaderDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAccordionHeaderDirective, isStandalone: true, selector: "[rdxAccordionHeader]", host: { properties: { "attr.data-state": "itemContext.dataState()", "attr.data-disabled": "itemContext.dataDisabled()", "attr.data-orientation": "rootContext.orientation()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionHeaderDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAccordionHeader]',
                    host: {
                        '[attr.data-state]': 'itemContext.dataState()',
                        '[attr.data-disabled]': 'itemContext.dataDisabled()',
                        '[attr.data-orientation]': 'rootContext.orientation()'
                    }
                }]
        }] });

class RdxAccordionTriggerDirective {
    constructor() {
        this.rootContext = injectAccordionRootContext();
        this.itemContext = injectAccordionItemContext();
        this.itemContext.triggerId = inject(_IdGenerator).getId('rdx-accordion-trigger-');
    }
    changeItem() {
        const triggerDisabled = this.rootContext.isSingle() && this.itemContext.open() && !this.rootContext.collapsible();
        if (this.itemContext.disabled() || triggerDisabled) {
            this.itemContext.updateOpen();
            return;
        }
        this.rootContext.changeModelValue(this.itemContext.value());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAccordionTriggerDirective, isStandalone: true, selector: "[rdxAccordionTrigger]", host: { listeners: { "click": "changeItem()" }, properties: { "id": "itemContext.triggerId", "attr.data-rdx-collection-item": "\"\"", "attr.role": "\"button\"", "attr.aria-disabled": "itemContext.open() && !rootContext.collapsible() ? \"true\" : undefined", "attr.data-orientation": "rootContext.orientation()", "disabled": "itemContext.disabled()" } }, hostDirectives: [{ directive: i1.RdxCollapsibleTriggerDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAccordionTrigger]',
                    hostDirectives: [RdxCollapsibleTriggerDirective],
                    host: {
                        '[id]': 'itemContext.triggerId',
                        '[attr.data-rdx-collection-item]': '""',
                        '[attr.role]': '"button"',
                        '[attr.aria-disabled]': 'itemContext.open() && !rootContext.collapsible() ? "true" : undefined',
                        '[attr.data-orientation]': 'rootContext.orientation()',
                        '[disabled]': 'itemContext.disabled()',
                        '(click)': 'changeItem()'
                    }
                }]
        }], ctorParameters: () => [] });

const _imports = [
    RdxAccordionContentDirective,
    RdxAccordionHeaderDirective,
    RdxAccordionItemDirective,
    RdxAccordionRootDirective,
    RdxAccordionTriggerDirective,
    RdxAccordionContentPresenceDirective
];
class RdxAccordionModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionModule, imports: [RdxAccordionContentDirective,
            RdxAccordionHeaderDirective,
            RdxAccordionItemDirective,
            RdxAccordionRootDirective,
            RdxAccordionTriggerDirective,
            RdxAccordionContentPresenceDirective], exports: [RdxAccordionContentDirective,
            RdxAccordionHeaderDirective,
            RdxAccordionItemDirective,
            RdxAccordionRootDirective,
            RdxAccordionTriggerDirective,
            RdxAccordionContentPresenceDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAccordionModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxAccordionContentDirective, RdxAccordionContentPresenceDirective, RdxAccordionHeaderDirective, RdxAccordionItemDirective, RdxAccordionModule, RdxAccordionRootDirective, RdxAccordionTriggerDirective, injectAccordionItemContext, injectAccordionRootContext, provideAccordionItemContext, provideAccordionRootContext };
//# sourceMappingURL=radix-ng-primitives-accordion.mjs.map
