import * as i0 from '@angular/core';
import { Injectable, inject, Directive, Renderer2, ElementRef, Input, ViewContainerRef, NgModule } from '@angular/core';
import * as i1 from '@angular/cdk/overlay';
import { TemplatePortal } from '@angular/cdk/portal';
import * as i1$1 from '@angular/cdk/a11y';
import { CdkTrapFocus } from '@angular/cdk/a11y';

class RdxAlertDialogService {
    constructor(overlay) {
        this.overlay = overlay;
    }
    setDialogContent(viewContainerRef, template) {
        this.dialogContent = { viewContainerRef, template };
    }
    open() {
        if (!this.dialogContent) {
            throw new Error('Dialog content is not set');
        }
        this.overlayRef = this.overlay.create({
            hasBackdrop: true,
            backdropClass: 'cdk-overlay-dark-backdrop',
            positionStrategy: this.overlay.position().global().centerHorizontally().centerVertically()
        });
        const templatePortal = new TemplatePortal(this.dialogContent.template, this.dialogContent.viewContainerRef);
        this.overlayRef.attach(templatePortal);
        this.overlayRef.keydownEvents().subscribe((event) => {
            if (event.key === 'Escape' || event.code === 'Escape') {
                this.close();
            }
        });
        this.overlayRef.backdropClick().subscribe(() => this.close());
    }
    close() {
        if (this.overlayRef) {
            this.overlayRef.dispose();
            this.overlayRef = null;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogService, deps: [{ token: i1.Overlay }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.Overlay }] });

class RdxAlertDialogCancelDirective {
    constructor() {
        this.alertDialogService = inject(RdxAlertDialogService);
    }
    onClick() {
        this.alertDialogService.close();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogCancelDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAlertDialogCancelDirective, isStandalone: true, selector: "[rdxAlertDialogCancel]", host: { listeners: { "click": "onClick()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogCancelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAlertDialogCancel]',
                    standalone: true,
                    host: {
                        '(click)': 'onClick()'
                    }
                }]
        }] });

class RdxAlertDialogContentDirective {
    constructor() {
        this.renderer = inject(Renderer2);
        this.elementRef = inject(ElementRef);
    }
    set maxWidth(value) {
        this.renderer.setStyle(this.elementRef.nativeElement, 'maxWidth', value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAlertDialogContentDirective, isStandalone: true, selector: "[rdxAlertDialogContent]", inputs: { maxWidth: "maxWidth" }, host: { properties: { "attr.data-state": "\"open\"", "attr.cdkTrapFocusAutoCapture": "true" } }, hostDirectives: [{ directive: i1$1.CdkTrapFocus }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAlertDialogContent]',
                    standalone: true,
                    hostDirectives: [
                        {
                            directive: CdkTrapFocus
                        }
                    ],
                    host: {
                        '[attr.data-state]': '"open"',
                        '[attr.cdkTrapFocusAutoCapture]': 'true'
                    }
                }]
        }], propDecorators: { maxWidth: [{
                type: Input
            }] } });

class RdxAlertDialogRootDirective {
    constructor() {
        this.viewContainerRef = inject(ViewContainerRef);
        this.alertDialogService = inject(RdxAlertDialogService);
    }
    set content(template) {
        this.alertDialogService.setDialogContent(this.viewContainerRef, template);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAlertDialogRootDirective, isStandalone: true, selector: "[rdxAlertDialogRoot]", inputs: { content: "content" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAlertDialogRoot]',
                    standalone: true
                }]
        }], propDecorators: { content: [{
                type: Input
            }] } });

class RdxAlertDialogTitleDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAlertDialogTitleDirective, isStandalone: true, selector: "[rdxAlertDialogTitle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAlertDialogTitle]',
                    standalone: true
                }]
        }] });

class RdxAlertDialogTriggerDirective {
    constructor() {
        this.alertDialogService = inject(RdxAlertDialogService);
    }
    handleClick() {
        this.alertDialogService.open();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAlertDialogTriggerDirective, isStandalone: true, selector: "[rdxAlertDialogTrigger]", host: { listeners: { "click": "handleClick()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxAlertDialogTrigger]',
                    standalone: true,
                    host: {
                        '(click)': 'handleClick()'
                    }
                }]
        }] });

const _imports = [
    RdxAlertDialogRootDirective,
    RdxAlertDialogContentDirective,
    RdxAlertDialogCancelDirective,
    RdxAlertDialogTriggerDirective,
    RdxAlertDialogTitleDirective
];
class RdxAlertDialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogModule, imports: [RdxAlertDialogRootDirective,
            RdxAlertDialogContentDirective,
            RdxAlertDialogCancelDirective,
            RdxAlertDialogTriggerDirective,
            RdxAlertDialogTitleDirective], exports: [RdxAlertDialogRootDirective,
            RdxAlertDialogContentDirective,
            RdxAlertDialogCancelDirective,
            RdxAlertDialogTriggerDirective,
            RdxAlertDialogTitleDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAlertDialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxAlertDialogCancelDirective, RdxAlertDialogContentDirective, RdxAlertDialogModule, RdxAlertDialogRootDirective, RdxAlertDialogService, RdxAlertDialogTitleDirective, RdxAlertDialogTriggerDirective };
//# sourceMappingURL=radix-ng-primitives-alert-dialog.mjs.map
