import * as i0 from '@angular/core';
import { InjectionToken, inject, input, signal, Directive, PLATFORM_ID, output, NgModule } from '@angular/core';
import { watch, provideToken } from '@radix-ng/primitives/core';
import { isPlatformBrowser } from '@angular/common';

const AVATAR_ROOT_CONTEXT = new InjectionToken('AVATAR_ROOT_CONTEXT');
function injectAvatarRootContext() {
    return inject(AVATAR_ROOT_CONTEXT);
}

const defaultAvatarConfig = {
    delayMs: 0
};
const RdxAvatarConfigToken = new InjectionToken('RdxAvatarConfigToken');
function provideRdxAvatarConfig(config) {
    return [
        {
            provide: RdxAvatarConfigToken,
            useValue: { ...defaultAvatarConfig, ...config }
        }
    ];
}
function injectAvatarConfig() {
    return inject(RdxAvatarConfigToken, { optional: true }) ?? defaultAvatarConfig;
}

/**
 * @group Components
 */
class RdxAvatarFallbackDirective {
    constructor() {
        this.config = injectAvatarConfig();
        this.rootContext = injectAvatarRootContext();
        /**
         * Useful for delaying rendering so it only appears for those with slower connections.
         *
         * @group Props
         * @defaultValue 0
         */
        this.delayMs = input(this.config.delayMs);
        this.canRender = signal(false);
        watch([this.rootContext.imageLoadingStatus], ([value]) => {
            if (value === 'loading') {
                this.canRender.set(false);
                if (this.delayMs()) {
                    this.timeout = setTimeout(() => {
                        this.canRender.set(true);
                        clearTimeout(this.timeout);
                    }, this.delayMs());
                }
                else {
                    this.canRender.set(true);
                }
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarFallbackDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxAvatarFallbackDirective, isStandalone: true, selector: "span[rdxAvatarFallback]", inputs: { delayMs: { classPropertyName: "delayMs", publicName: "delayMs", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "style.display": "canRender() && rootContext.imageLoadingStatus() !== \"loaded\" ? null : \"none\" " } }, exportAs: ["rdxAvatarFallback"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarFallbackDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'span[rdxAvatarFallback]',
                    exportAs: 'rdxAvatarFallback',
                    host: {
                        '[style.display]': 'canRender() && rootContext.imageLoadingStatus() !== "loaded" ? null : "none" '
                    }
                }]
        }], ctorParameters: () => [] });

/**
 * @group Components
 */
class RdxAvatarImageDirective {
    constructor() {
        this.platformId = inject(PLATFORM_ID);
        this.rootContext = injectAvatarRootContext();
        /**
         * @group Props
         */
        this.src = input();
        this.referrerPolicy = input();
        /**
         * A callback providing information about the loading status of the image.
         * This is useful in case you want to control more precisely what to render as the image is loading.
         *
         * @group Emits
         */
        this.onLoadingStatusChange = output();
        this.isMounted = signal(false);
        this.loadingStatus = signal('idle');
        const updateStatus = (status) => () => {
            if (this.isMounted()) {
                this.loadingStatus.set(status);
            }
        };
        if (isPlatformBrowser(this.platformId)) {
            watch([this.src, this.referrerPolicy], ([src, referrer]) => {
                if (this.isMounted()) {
                    if (!src) {
                        this.loadingStatus.set('error');
                    }
                    else {
                        const image = new window.Image();
                        this.loadingStatus.set('loading');
                        image.onload = updateStatus('loaded');
                        image.onerror = updateStatus('error');
                        image.src = src;
                        if (referrer) {
                            image.referrerPolicy = referrer;
                        }
                    }
                }
            });
            watch([this.loadingStatus], ([value]) => {
                this.onLoadingStatusChange.emit(value);
                if (value !== 'idle') {
                    this.rootContext.imageLoadingStatus.set(value);
                }
            });
        }
        else {
            this.loadingStatus.set('idle');
        }
    }
    ngOnInit() {
        this.isMounted.set(true);
    }
    ngOnDestroy() {
        this.isMounted.set(false);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarImageDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxAvatarImageDirective, isStandalone: true, selector: "img[rdxAvatarImage]", inputs: { src: { classPropertyName: "src", publicName: "src", isSignal: true, isRequired: false, transformFunction: null }, referrerPolicy: { classPropertyName: "referrerPolicy", publicName: "referrerPolicy", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { onLoadingStatusChange: "onLoadingStatusChange" }, host: { attributes: { "role": "img" }, properties: { "attr.src": "src()", "attr.referrer-policy": "referrerPolicy()", "style.display": "(rootContext.imageLoadingStatus() === \"loaded\") ? null : \"none\"" } }, exportAs: ["rdxAvatarImage"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarImageDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'img[rdxAvatarImage]',
                    exportAs: 'rdxAvatarImage',
                    host: {
                        role: 'img',
                        '[attr.src]': 'src()',
                        '[attr.referrer-policy]': 'referrerPolicy()',
                        '[style.display]': '(rootContext.imageLoadingStatus() === "loaded") ? null : "none"'
                    }
                }]
        }], ctorParameters: () => [] });

class RdxAvatarRootDirective {
    constructor() {
        this.imageLoadingStatus = signal('loading');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxAvatarRootDirective, isStandalone: true, selector: "span[rdxAvatarRoot]", providers: [provideToken(AVATAR_ROOT_CONTEXT, RdxAvatarRootDirective)], exportAs: ["rdxAvatarRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxAvatarRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'span[rdxAvatarRoot]',
                    exportAs: 'rdxAvatarRoot',
                    providers: [provideToken(AVATAR_ROOT_CONTEXT, RdxAvatarRootDirective)]
                }]
        }] });

const _imports = [RdxAvatarRootDirective, RdxAvatarFallbackDirective, RdxAvatarImageDirective];
class RdxCheckboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, imports: [RdxAvatarRootDirective, RdxAvatarFallbackDirective, RdxAvatarImageDirective], exports: [RdxAvatarRootDirective, RdxAvatarFallbackDirective, RdxAvatarImageDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxAvatarConfigToken, RdxAvatarFallbackDirective, RdxAvatarImageDirective, RdxAvatarRootDirective, RdxCheckboxModule, defaultAvatarConfig, injectAvatarConfig, provideRdxAvatarConfig };
//# sourceMappingURL=radix-ng-primitives-avatar.mjs.map
