import * as i0 from '@angular/core';
import { InjectionToken, inject, input, computed, Directive, EventEmitter, booleanAttribute, Output, Input, NgModule } from '@angular/core';
import * as i1 from '@radix-ng/primitives/visually-hidden';
import { RdxVisuallyHiddenInputDirective } from '@radix-ng/primitives/visually-hidden';
import { provideToken, provideValueAccessor } from '@radix-ng/primitives/core';

const RdxCheckboxToken = new InjectionToken('RdxCheckboxToken');
function injectCheckbox() {
    return inject(RdxCheckboxToken);
}

class RdxCheckboxButtonDirective {
    constructor() {
        this.checkbox = injectCheckbox();
        this.id = input(null);
        this.elementId = computed(() => (this.id() ? this.id() : `rdx-checkbox-${this.id()}`));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxButtonDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxCheckboxButtonDirective, isStandalone: true, selector: "button[rdxCheckboxButton]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "type": "button", "role": "checkbox", "tabindex": "-1" }, properties: { "checked": "checkbox.checked", "disabled": "checkbox.disabled", "required": "checkbox.required", "attr.id": "elementId()", "attr.aria-checked": "checkbox.indeterminate ? \"mixed\" : checkbox.checked", "attr.aria-required": "checkbox.required ? \"\" : null", "attr.data-state": "checkbox.state", "attr.data-disabled": "checkbox.disabled ? \"\" : null" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'button[rdxCheckboxButton]',
                    host: {
                        type: 'button',
                        role: 'checkbox',
                        tabindex: '-1',
                        '[checked]': 'checkbox.checked',
                        '[disabled]': 'checkbox.disabled',
                        '[required]': 'checkbox.required',
                        '[attr.id]': 'elementId()',
                        '[attr.aria-checked]': 'checkbox.indeterminate ? "mixed" : checkbox.checked',
                        '[attr.aria-required]': 'checkbox.required ? "" : null',
                        '[attr.data-state]': 'checkbox.state',
                        '[attr.data-disabled]': 'checkbox.disabled ? "" : null'
                    }
                }]
        }] });

class RdxCheckboxIndicatorDirective {
    constructor() {
        this.checkbox = injectCheckbox();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxIndicatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxCheckboxIndicatorDirective, isStandalone: true, selector: "[rdxCheckboxIndicator]", host: { properties: { "style.pointer-events": "\"none\"", "attr.aria-checked": "checkbox.indeterminate ? \"mixed\" : checkbox.checked", "attr.data-state": "checkbox.state", "attr.data-disabled": "checkbox.disabled ? \"\" : null" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxIndicatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxCheckboxIndicator]',
                    host: {
                        '[style.pointer-events]': '"none"',
                        '[attr.aria-checked]': 'checkbox.indeterminate ? "mixed" : checkbox.checked',
                        '[attr.data-state]': 'checkbox.state',
                        '[attr.data-disabled]': 'checkbox.disabled ? "" : null'
                    }
                }]
        }] });

class RdxCheckboxInputDirective {
    constructor() {
        this.checkbox = injectCheckbox();
        this.id = input();
        this.elementId = computed(() => (this.id() ? this.id() : `rdx-checkbox-${this.id()}`));
        this.value = computed(() => {
            const state = this.checkbox.state;
            if (state === 'indeterminate') {
                return '';
            }
            return state ? 'on' : 'off';
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxCheckboxInputDirective, isStandalone: true, selector: "input[rdxCheckboxInput]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "type": "checkbox", "tabindex": "-1" }, properties: { "checked": "checkbox.checked", "disabled": "checkbox.disabled", "required": "checkbox.required", "attr.id": "elementId()", "attr.aria-hidden": "true", "attr.aria-checked": "checkbox.indeterminate ? \"mixed\" : checkbox.checked", "attr.aria-required": "checkbox.required ? \"\" : null", "attr.data-state": "checkbox.state", "attr.data-disabled": "checkbox.disabled ? \"\" : null", "attr.value": "value()" } }, hostDirectives: [{ directive: i1.RdxVisuallyHiddenInputDirective, inputs: ["feature", "\"fully-hidden\""] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[rdxCheckboxInput]',
                    hostDirectives: [{ directive: RdxVisuallyHiddenInputDirective, inputs: ['feature: "fully-hidden"'] }],
                    host: {
                        type: 'checkbox',
                        tabindex: '-1',
                        '[checked]': 'checkbox.checked',
                        '[disabled]': 'checkbox.disabled',
                        '[required]': 'checkbox.required',
                        '[attr.id]': 'elementId()',
                        '[attr.aria-hidden]': 'true',
                        '[attr.aria-checked]': 'checkbox.indeterminate ? "mixed" : checkbox.checked',
                        '[attr.aria-required]': 'checkbox.required ? "" : null',
                        '[attr.data-state]': 'checkbox.state',
                        '[attr.data-disabled]': 'checkbox.disabled ? "" : null',
                        '[attr.value]': 'value()'
                    }
                }]
        }] });

/**
 * @group Components
 */
class RdxCheckboxRootDirective {
    constructor() {
        /**
         * The controlled checked state of the checkbox. Must be used in conjunction with onCheckedChange.
         * @group Props
         */
        this.checked = false;
        /**
         * Defines whether the checkbox is indeterminate.
         * @group Props
         */
        this.indeterminate = false;
        /**
         * Defines whether the checkbox is disabled.
         * @group Props
         */
        this.disabled = false;
        /**
         * @group Props
         */
        this.required = false;
        /**
         * Event emitted when the checkbox checked state changes.
         * @group Emits
         */
        this.checkedChange = new EventEmitter();
        /**
         * Event emitted when the indeterminate state changes.
         * @group Emits
         */
        this.indeterminateChange = new EventEmitter();
    }
    /**
     * Determine the state
     */
    get state() {
        if (this.indeterminate) {
            return 'indeterminate';
        }
        return this.checked ? 'checked' : 'unchecked';
    }
    onKeyDown(event) {
        // According to WAI ARIA, Checkboxes don't activate on enter keypress
        if (event.key === 'Enter') {
            event.preventDefault();
        }
    }
    onClick($event) {
        if (this.disabled) {
            return;
        }
        this.checked = this.indeterminate ? true : !this.checked;
        this.checkedChange.emit(this.checked);
        this.onChange?.(this.checked);
        if (this.indeterminate) {
            this.indeterminate = false;
            this.indeterminateChange.emit(this.indeterminate);
        }
        $event.preventDefault();
    }
    onBlur() {
        this.onTouched?.();
    }
    ngOnChanges(changes) {
        if (changes['checked'] && !changes['checked'].isFirstChange()) {
            this.checkedChange.emit(this.checked);
        }
        if (changes['indeterminate'] && !changes['indeterminate'].isFirstChange()) {
            this.indeterminateChange.emit(this.indeterminate);
        }
    }
    /**
     * Sets the checked state of the checkbox.
     * @param checked The checked state of the checkbox.
     * @internal
     */
    writeValue(checked) {
        this.checked = checked;
    }
    /**
     * Registers a callback function that should be called when the checkbox checked state changes.
     * @param fn The callback function.
     * @internal
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * Registers a callback function that should be called when the checkbox is blurred.
     * @param fn The callback function.
     * @internal
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Sets the disabled state of the checkbox.
     * @param isDisabled The disabled state of the checkbox.
     * @internal
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.4", type: RdxCheckboxRootDirective, isStandalone: true, selector: "[rdxCheckboxRoot]", inputs: { checked: ["checked", "checked", booleanAttribute], indeterminate: ["indeterminate", "indeterminate", booleanAttribute], disabled: ["disabled", "disabled", booleanAttribute], required: ["required", "required", booleanAttribute] }, outputs: { checkedChange: "checkedChange", indeterminateChange: "indeterminateChange" }, host: { listeners: { "keydown": "onKeyDown($event)", "click": "onClick($event)", "blur": "onBlur()" }, properties: { "disabled": "disabled", "attr.data-disabled": "disabled ? \"\" : null", "attr.data-state": "state" } }, providers: [
            provideToken(RdxCheckboxToken, RdxCheckboxRootDirective),
            provideValueAccessor(RdxCheckboxRootDirective)
        ], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxCheckboxRoot]',
                    providers: [
                        provideToken(RdxCheckboxToken, RdxCheckboxRootDirective),
                        provideValueAccessor(RdxCheckboxRootDirective)
                    ],
                    host: {
                        '[disabled]': 'disabled',
                        '[attr.data-disabled]': 'disabled ? "" : null',
                        '[attr.data-state]': 'state',
                        '(keydown)': 'onKeyDown($event)',
                        '(click)': 'onClick($event)',
                        '(blur)': 'onBlur()'
                    }
                }]
        }], propDecorators: { checked: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], indeterminate: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], required: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], checkedChange: [{
                type: Output
            }], indeterminateChange: [{
                type: Output
            }] } });

const _imports = [
    RdxCheckboxInputDirective,
    RdxCheckboxRootDirective,
    RdxCheckboxButtonDirective,
    RdxCheckboxIndicatorDirective
];
class RdxCheckboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, imports: [RdxCheckboxInputDirective,
            RdxCheckboxRootDirective,
            RdxCheckboxButtonDirective,
            RdxCheckboxIndicatorDirective], exports: [RdxCheckboxInputDirective,
            RdxCheckboxRootDirective,
            RdxCheckboxButtonDirective,
            RdxCheckboxIndicatorDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCheckboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxCheckboxButtonDirective, RdxCheckboxIndicatorDirective, RdxCheckboxInputDirective, RdxCheckboxModule, RdxCheckboxRootDirective, RdxCheckboxToken, injectCheckbox };
//# sourceMappingURL=radix-ng-primitives-checkbox.mjs.map
