import * as i0 from '@angular/core';
import { inject, untracked, model, input, booleanAttribute, linkedSignal, computed, output, Directive, ElementRef, PLATFORM_ID, signal, effect, afterNextRender, NgModule } from '@angular/core';
import * as i1 from '@radix-ng/primitives/presence';
import { provideRdxPresenceContext, RdxPresenceDirective } from '@radix-ng/primitives/presence';
import { createContext } from '@radix-ng/primitives/core';
import { isPlatformBrowser } from '@angular/common';

const [injectCollapsibleRootContext, provideCollapsibleRootContext] = createContext('CollapsibleRootContext');
const rootContext = () => {
    const instance = inject(RdxCollapsibleRootDirective);
    return {
        contentId: instance.contentId,
        disabled: instance.isDisabled,
        open: instance.open,
        toggle: () => {
            if (instance.isDisabled()) {
                return;
            }
            untracked(() => {
                instance.open.set(!instance.open());
            });
            instance.onOpenChange.emit(instance.open());
        }
    };
};
/**
 * @group Components
 */
class RdxCollapsibleRootDirective {
    constructor() {
        /**
         * The controlled open state of the collapsible.
         * Sets the state of the directive. `true` - expanded, `false` - collapsed
         *
         * @group Props
         * @defaultValue false
         */
        this.open = model(false);
        this.contentId = input('');
        /**
         * Determines whether a directive is available for interaction.
         * When true, prevents the user from interacting with the collapsible.
         *
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        this._disabled = linkedSignal(this.disabled);
        this.isDisabled = this._disabled.asReadonly();
        this.isOpen = computed(() => this.open());
        /**
         * Emitted with new value when directive state changed.
         * Event handler called when the open state of the collapsible changes.
         *
         * @group Emits
         */
        this.onOpenChange = output();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxCollapsibleRootDirective, isStandalone: true, selector: "[rdxCollapsibleRoot]", inputs: { open: { classPropertyName: "open", publicName: "open", isSignal: true, isRequired: false, transformFunction: null }, contentId: { classPropertyName: "contentId", publicName: "contentId", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { open: "openChange", onOpenChange: "onOpenChange" }, host: { properties: { "attr.data-state": "open() ? \"open\" : \"closed\"", "attr.data-disabled": "disabled() ? \"\" : undefined" } }, providers: [provideCollapsibleRootContext(rootContext)], exportAs: ["rdxCollapsibleRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxCollapsibleRoot]',
                    exportAs: 'rdxCollapsibleRoot',
                    providers: [provideCollapsibleRootContext(rootContext)],
                    host: {
                        '[attr.data-state]': 'open() ? "open" : "closed"',
                        '[attr.data-disabled]': 'disabled() ? "" : undefined'
                    }
                }]
        }] });

class RdxCollapsibleContentPresenceDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleContentPresenceDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxCollapsibleContentPresenceDirective, isStandalone: true, selector: "ng-template[rdxCollapsibleContentPresence]", providers: [
            provideRdxPresenceContext(() => ({
                present: injectCollapsibleRootContext().open
            }))
        ], hostDirectives: [{ directive: i1.RdxPresenceDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleContentPresenceDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[rdxCollapsibleContentPresence]',
                    providers: [
                        provideRdxPresenceContext(() => ({
                            present: injectCollapsibleRootContext().open
                        }))
                    ],
                    hostDirectives: [RdxPresenceDirective]
                }]
        }] });

class RdxCollapsibleContentDirective {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.platformId = inject(PLATFORM_ID);
        this.rootContext = injectCollapsibleRootContext();
        this.isOpen = computed(() => this.rootContext.open());
        this.height = signal(null);
        this.width = signal(null);
        this.shouldHide = signal(true);
        this.isMountAnimationPrevented = signal(true);
        this.currentStyle = signal(null);
        this.firstRender = true;
        effect(() => {
            const isOpen = this.isOpen();
            if (!isPlatformBrowser(this.platformId)) {
                return;
            }
            requestAnimationFrame(() => {
                this.updateDimensions(isOpen);
            });
        });
        afterNextRender(() => {
            requestAnimationFrame(() => {
                this.isMountAnimationPrevented.set(false);
            });
        });
    }
    onAnimationEnd() {
        if (!this.isOpen()) {
            this.shouldHide.set(true);
        }
    }
    async updateDimensions(isOpen) {
        const node = this.elementRef.nativeElement;
        if (!node)
            return;
        if (!this.currentStyle()) {
            this.currentStyle.set({
                transitionDuration: node.style.transitionDuration,
                animationName: node.style.animationName
            });
        }
        if (isOpen) {
            this.shouldHide.set(false);
            node.hidden = false;
        }
        node.style.transitionDuration = '0s';
        node.style.animationName = 'none';
        const rect = node.getBoundingClientRect();
        this.height.set(rect.height);
        this.width.set(rect.width);
        if (!this.isMountAnimationPrevented() && !this.firstRender) {
            node.style.transitionDuration = this.currentStyle()?.transitionDuration || '';
            node.style.animationName = this.currentStyle()?.animationName || '';
        }
        this.firstRender = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxCollapsibleContentDirective, isStandalone: true, selector: "[rdxCollapsibleContent]", host: { listeners: { "animationend": "onAnimationEnd()" }, properties: { "id": "rootContext.contentId()", "attr.data-state": "rootContext.open() ? \"open\" : \"closed\"", "attr.data-disabled": "rootContext.disabled() ? \"true\" : undefined", "attr.hidden": "shouldHide() ? \"until-found\" : undefined", "style.--radix-collapsible-content-width.px": "width()", "style.--radix-collapsible-content-height.px": "height()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxCollapsibleContent]',
                    host: {
                        '[id]': 'rootContext.contentId()',
                        '[attr.data-state]': 'rootContext.open() ? "open" : "closed"',
                        '[attr.data-disabled]': 'rootContext.disabled() ? "true" : undefined',
                        '[attr.hidden]': 'shouldHide() ? "until-found" : undefined',
                        '[style.--radix-collapsible-content-width.px]': 'width()',
                        '[style.--radix-collapsible-content-height.px]': 'height()',
                        '(animationend)': 'onAnimationEnd()'
                    }
                }]
        }], ctorParameters: () => [] });

class RdxCollapsibleTriggerDirective {
    constructor() {
        this.rootContext = injectCollapsibleRootContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxCollapsibleTriggerDirective, isStandalone: true, selector: "[rdxCollapsibleTrigger]", host: { listeners: { "click": "rootContext.toggle()" }, properties: { "attr.aria-controls": "rootContext.contentId()", "attr.aria-expanded": "rootContext.open()", "attr.data-state": "rootContext.open() ? \"open\" : \"closed\"", "attr.data-disabled": "rootContext.disabled() ? \"true\" : undefined", "attr.disabled": "rootContext.disabled() || undefined" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxCollapsibleTrigger]',
                    host: {
                        '[attr.aria-controls]': 'rootContext.contentId()',
                        '[attr.aria-expanded]': 'rootContext.open()',
                        '[attr.data-state]': 'rootContext.open() ? "open" : "closed"',
                        '[attr.data-disabled]': 'rootContext.disabled() ? "true" : undefined',
                        '[attr.disabled]': 'rootContext.disabled() || undefined',
                        '(click)': 'rootContext.toggle()'
                    }
                }]
        }] });

const _imports = [
    RdxCollapsibleContentDirective,
    RdxCollapsibleRootDirective,
    RdxCollapsibleTriggerDirective,
    RdxCollapsibleContentPresenceDirective
];
class RdxCollapsibleModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleModule, imports: [RdxCollapsibleContentDirective,
            RdxCollapsibleRootDirective,
            RdxCollapsibleTriggerDirective,
            RdxCollapsibleContentPresenceDirective], exports: [RdxCollapsibleContentDirective,
            RdxCollapsibleRootDirective,
            RdxCollapsibleTriggerDirective,
            RdxCollapsibleContentPresenceDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCollapsibleModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxCollapsibleContentDirective, RdxCollapsibleContentPresenceDirective, RdxCollapsibleModule, RdxCollapsibleRootDirective, RdxCollapsibleTriggerDirective, injectCollapsibleRootContext, provideCollapsibleRootContext };
//# sourceMappingURL=radix-ng-primitives-collapsible.mjs.map
