import * as i0 from '@angular/core';
import { signal, Injectable, InjectionToken, provideAppInitializer, inject, makeEnvironmentProviders } from '@angular/core';

class RadixNG {
    constructor() {
        this.dir = signal('ltr');
        this.locale = signal('en');
    }
    setConfig(config) {
        const { dir, locale } = config || {};
        if (dir)
            this.dir.set(dir);
        if (locale)
            this.locale.set(locale);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RadixNG, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RadixNG, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RadixNG, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

const RADIX_NG_CONFIG = new InjectionToken('RADIX_NG_CONFIG');
/**
 * Provides RadixNG configuration as environment providers.
 *
 * @param features One or more RadixNG configuration objects.
 * @returns A set of environment providers that register the RadixNG configs.
 */
function provideRadixNG(...features) {
    const providers = features?.map((feature) => ({
        provide: RADIX_NG_CONFIG,
        useValue: feature,
        multi: false
    }));
    /**
     * Creates an AppInitializer to load and apply each RadixNG configuration
     * to the global RadixNG service before the app starts.
     */
    const initializer = provideAppInitializer(() => {
        const config = inject(RadixNG);
        features?.forEach((feature) => config.setConfig(feature));
        return;
    });
    return makeEnvironmentProviders([...providers, initializer]);
}

/**
 * Generated bundle index. Do not edit.
 */

export { RADIX_NG_CONFIG, RadixNG, provideRadixNG };
//# sourceMappingURL=radix-ng-primitives-config.mjs.map
