import * as i0 from '@angular/core';
import { InjectionToken, inject, input, computed, signal, effect, Directive, ElementRef, model, booleanAttribute, NgModule } from '@angular/core';
import { useDateField, normalizeDateStep, getDefaultDate, hasTime, isBefore, createContent, watch, isNullish, createFormatter, normalizeHourCycle, initializeSegmentValues, syncSegmentValues, getSegmentElements, ARROW_LEFT, ARROW_RIGHT, isSegmentNavigationKey, provideToken } from '@radix-ng/primitives/core';

const DATE_FIELDS_ROOT_CONTEXT = new InjectionToken('DATE_FIELDS_ROOT_CONTEXT');
function injectDateFieldsRootContext() {
    return inject(DATE_FIELDS_ROOT_CONTEXT);
}

class RdxDateFieldInputDirective {
    constructor(el) {
        this.el = el;
        this.rootContext = injectDateFieldsRootContext();
        /**
         * The part of the date to render
         * `'day' | 'month' | 'year' | 'hour' | 'minute' | 'second' | 'dayPeriod' | 'literal' | 'timeZoneName'`
         */
        this.part = input();
        /**
         * @ignore
         */
        this.disabled = computed(() => this.rootContext.disabled());
        /**
         * @ignore
         */
        this.readonly = computed(() => this.rootContext.readonly());
        /**
         * @ignore
         */
        this.isInvalid = computed(() => this.rootContext.isInvalid());
        /**
         * @ignore
         */
        this.hasLeftFocus = signal(true);
        /**
         * @ignore
         */
        this.lastKeyZero = signal(false);
        this.fieldData = computed(() => {
            return useDateField({
                hasLeftFocus: this.hasLeftFocus,
                lastKeyZero: this.lastKeyZero,
                placeholder: this.rootContext.placeholder,
                hourCycle: this.rootContext.hourCycle(),
                segmentValues: this.rootContext.segmentValues,
                formatter: this.rootContext.formatter,
                part: this.part(),
                disabled: this.rootContext.disabled,
                readonly: this.rootContext.readonly,
                step: this.rootContext.step$,
                modelValue: this.rootContext.value,
                focusNext: this.rootContext.focusNext
            });
        });
        this.attributes = computed(() => this.fieldData().attributes());
        effect(() => {
            const { handleSegmentClick, handleSegmentKeydown } = this.fieldData();
            this.handleSegmentKeydown = handleSegmentKeydown;
            this.handleSegmentClick = handleSegmentClick;
        });
        effect(() => {
            const attrs = this.attributes();
            Object.entries(attrs).forEach(([attr, value]) => {
                this.el.nativeElement.setAttribute(attr, String(value));
            });
        });
    }
    /**
     * @ignore
     */
    onFocus(e) {
        this.rootContext.setFocusedElement(e.target);
    }
    /**
     * @ignore
     */
    onFocusOut() {
        this.hasLeftFocus.set(true);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldInputDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxDateFieldInputDirective, isStandalone: true, selector: "[rdxDateFieldInput]", inputs: { part: { classPropertyName: "part", publicName: "part", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "mousedown": "part() !== \"literal\" && handleSegmentClick($event)", "keydown": "part() !== \"literal\" && handleSegmentKeydown($event)", "focus": "part() !== \"literal\" && onFocus($event)", "focusout": "part() !== \"literal\" && onFocusOut()" }, properties: { "attr.contenteditable": "disabled() || readonly() ? false : part() !== \"literal\"", "attr.data-rdx-date-field-segment": "part()", "attr.aria-disabled": "disabled() ? \"\" : undefined", "attr.data-disabled": "disabled() ? \"\" : undefined", "attr.data-invalid": "isInvalid() ? \"\" : undefined", "attr.aria-invalid": "isInvalid() ? true : undefined" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDateFieldInput]',
                    host: {
                        '[attr.contenteditable]': 'disabled() || readonly() ? false : part() !== "literal"',
                        '[attr.data-rdx-date-field-segment]': 'part()',
                        '[attr.aria-disabled]': 'disabled() ? "" : undefined',
                        '[attr.data-disabled]': 'disabled() ? "" : undefined',
                        '[attr.data-invalid]': 'isInvalid() ? "" : undefined',
                        '[attr.aria-invalid]': 'isInvalid() ? true : undefined',
                        '(mousedown)': 'part() !== "literal" && handleSegmentClick($event)',
                        '(keydown)': 'part() !== "literal" && handleSegmentKeydown($event)',
                        '(focus)': 'part() !== "literal" && onFocus($event)',
                        '(focusout)': 'part() !== "literal" && onFocusOut()'
                    }
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class RdxDateFieldRootDirective {
    constructor() {
        this.elementRef = inject((ElementRef));
        /**
         * The controlled checked state of the calendar.
         */
        this.value = model();
        /**
         * A callback fired when the date field's value is invalid.
         */
        this.isDateUnavailable = input(undefined);
        /**
         * The hour cycle to use for formatting times. Defaults to the locale preference
         */
        this.hourCycle = input();
        /**
         * The granularity to use for formatting the field. Defaults to 'day' if a CalendarDate is provided, otherwise defaults to 'minute'.
         * The field will render segments for each part of the date up to and including the specified granularity.
         */
        this.granularity = input();
        /**
         * The locale to use for formatting dates.
         */
        this.locale = input('en');
        this.dir = input('ltr');
        /**
         * The minimum valid date that can be entered.
         */
        this.minValue = input();
        /**
         * The maximum valid date that can be entered.
         */
        this.maxValue = input();
        /**
         * Whether or not to hide the time zone segment of the field.
         */
        this.hideTimeZone = input(false, { transform: booleanAttribute });
        this.disabled = input(false, { transform: booleanAttribute });
        /**
         * Whether or not the field is readonly.
         */
        this.readonly = input(false, { transform: booleanAttribute });
        /**
         * The stepping interval for the time fields. Defaults to 1
         */
        this.step = input();
        this.step$ = computed(() => normalizeDateStep(this.step()));
        /**
         * @ignore
         */
        this.defaultDate = computed(() => getDefaultDate({
            defaultPlaceholder: undefined,
            granularity: this.granularity(),
            defaultValue: this.value(),
            locale: this.locale()
        }));
        /**
         * The placeholder date, which is used to determine what month to display when no date is selected. This updates as the user navigates the calendar and can be used to programmatically control the calendar view
         */
        this.placeholder = model(this.defaultDate().copy());
        // Internal state
        /**
         * @ignore
         */
        this.segmentElements = signal(new Set());
        /**
         * @ignore
         */
        this.currentFocusedElement = signal(null);
        /**
         * @ignore
         */
        this.segmentValues = signal({
            year: null,
            month: null,
            day: null,
            hour: null,
            minute: null,
            second: null,
            dayPeriod: null
        });
        /**
         * @ignore
         */
        this.inferredGranularity = computed(() => {
            const placeholder = this.placeholder();
            if (this.granularity())
                return placeholder && !hasTime(placeholder) ? 'day' : this.granularity();
            return placeholder && hasTime(placeholder) ? 'minute' : 'day';
        });
        /**
         * @ignore
         */
        this.isInvalid = computed(() => {
            if (!this.value())
                return false;
            if (this.isDateUnavailable()?.(this.value()))
                return true;
            if (this.minValue() && isBefore(this.value(), this.minValue()))
                return true;
            if (this.maxValue() && isBefore(this.maxValue(), this.value()))
                return true;
            return false;
        });
        /**
         * @ignore
         */
        this.allSegmentContent = computed(() => createContent({
            granularity: this.inferredGranularity(),
            dateRef: this.placeholder(),
            formatter: this.formatter,
            hideTimeZone: this.hideTimeZone(),
            hourCycle: this.hourCycle(),
            segmentValues: this.segmentValues(),
            locale: this.locale
        }));
        /**
         * An array of segments that should be readonly, which prevent user input on them.
         */
        this.segmentContents = computed(() => this.allSegmentContent().arr);
        /**
         * @ignore
         */
        this.currentSegmentIndex = computed(() => Array.from(this.segmentElements()).findIndex((el) => el.getAttribute('data-rdx-date-field-segment') ===
            this.currentFocusedElement()?.getAttribute('data-rdx-date-field-segment')));
        /**
         * @ignore
         */
        this.prevFocusableSegment = computed(() => {
            const sign = this.dir() === 'rtl' ? -1 : 1;
            const prevCondition = sign > 0 ? this.currentSegmentIndex() < 0 : this.currentSegmentIndex() > this.segmentElements().size - 1;
            if (prevCondition)
                return null;
            const segmentToFocus = Array.from(this.segmentElements())[this.currentSegmentIndex() - sign];
            return segmentToFocus;
        });
        /**
         * @ignore
         */
        this.nextFocusableSegment = computed(() => {
            const sign = this.dir() === 'rtl' ? -1 : 1;
            const nextCondition = sign < 0 ? this.currentSegmentIndex() < 0 : this.currentSegmentIndex() > this.segmentElements().size - 1;
            if (nextCondition)
                return null;
            const segmentToFocus = Array.from(this.segmentElements())[this.currentSegmentIndex() + sign];
            return segmentToFocus;
        });
        /**
         * @ignore
         */
        this.focusNext = () => {
            this.nextFocusableSegment()?.focus();
        };
        watch([this.value], ([modelValue]) => {
            if (!isNullish(modelValue) && this.placeholder()?.compare(modelValue) !== 0) {
                this.placeholder.set(modelValue.copy());
            }
        });
    }
    ngOnInit() {
        const defDate = getDefaultDate({
            defaultPlaceholder: undefined,
            granularity: this.granularity(),
            defaultValue: this.value(),
            locale: this.locale()
        });
        this.placeholder.set(defDate.copy());
        this.formatter = createFormatter(this.locale(), {
            hourCycle: normalizeHourCycle(this.hourCycle())
        });
        const initialSegments = initializeSegmentValues(this.inferredGranularity());
        this.segmentValues.set(this.value()
            ? { ...syncSegmentValues({ value: this.value(), formatter: this.formatter }) }
            : { ...initialSegments });
    }
    ngAfterViewInit() {
        getSegmentElements(this.elementRef.nativeElement).forEach((item) => this.segmentElements().add(item));
    }
    /**
     * @ignore
     */
    onKeydown(event) {
        const code = event.code;
        if ([ARROW_LEFT, ARROW_RIGHT].includes(code)) {
            if (!isSegmentNavigationKey(event.key))
                return;
            if (code === ARROW_LEFT) {
                this.prevFocusableSegment()?.focus();
            }
            if (code === ARROW_RIGHT) {
                this.nextFocusableSegment()?.focus();
            }
        }
    }
    /**
     * @ignore
     */
    setFocusedElement(el) {
        this.currentFocusedElement.set(el);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxDateFieldRootDirective, isStandalone: true, selector: "[rdxDateFieldRoot]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, isDateUnavailable: { classPropertyName: "isDateUnavailable", publicName: "isDateUnavailable", isSignal: true, isRequired: false, transformFunction: null }, hourCycle: { classPropertyName: "hourCycle", publicName: "hourCycle", isSignal: true, isRequired: false, transformFunction: null }, granularity: { classPropertyName: "granularity", publicName: "granularity", isSignal: true, isRequired: false, transformFunction: null }, locale: { classPropertyName: "locale", publicName: "locale", isSignal: true, isRequired: false, transformFunction: null }, dir: { classPropertyName: "dir", publicName: "dir", isSignal: true, isRequired: false, transformFunction: null }, minValue: { classPropertyName: "minValue", publicName: "minValue", isSignal: true, isRequired: false, transformFunction: null }, maxValue: { classPropertyName: "maxValue", publicName: "maxValue", isSignal: true, isRequired: false, transformFunction: null }, hideTimeZone: { classPropertyName: "hideTimeZone", publicName: "hideTimeZone", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, readonly: { classPropertyName: "readonly", publicName: "readonly", isSignal: true, isRequired: false, transformFunction: null }, step: { classPropertyName: "step", publicName: "step", isSignal: true, isRequired: false, transformFunction: null }, placeholder: { classPropertyName: "placeholder", publicName: "placeholder", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", placeholder: "placeholderChange" }, host: { attributes: { "role": "group" }, listeners: { "keydown": "onKeydown($event)" }, properties: { "attr.aria-disabled": "disabled() ? \"\" : undefined", "attr.data-disabled": "disabled() ? \"\" : undefined", "attr.data-readonly": "readonly() ? \"\" : undefined", "attr.data-invalid": "isInvalid() ? \"\" : undefined", "attr.dir": "dir()" } }, providers: [provideToken(DATE_FIELDS_ROOT_CONTEXT, RdxDateFieldRootDirective)], exportAs: ["rdxDateFieldRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDateFieldRoot]',
                    exportAs: 'rdxDateFieldRoot',
                    providers: [provideToken(DATE_FIELDS_ROOT_CONTEXT, RdxDateFieldRootDirective)],
                    host: {
                        role: 'group',
                        '[attr.aria-disabled]': 'disabled() ? "" : undefined',
                        '[attr.data-disabled]': 'disabled() ? "" : undefined',
                        '[attr.data-readonly]': 'readonly() ? "" : undefined',
                        '[attr.data-invalid]': 'isInvalid() ? "" : undefined',
                        '[attr.dir]': 'dir()',
                        '(keydown)': 'onKeydown($event)'
                    }
                }]
        }], ctorParameters: () => [] });

const _imports = [RdxDateFieldRootDirective, RdxDateFieldInputDirective];
class RdxDateFieldModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldModule, imports: [RdxDateFieldRootDirective, RdxDateFieldInputDirective], exports: [RdxDateFieldRootDirective, RdxDateFieldInputDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDateFieldModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DATE_FIELDS_ROOT_CONTEXT, RdxDateFieldInputDirective, RdxDateFieldModule, RdxDateFieldRootDirective, injectDateFieldsRootContext };
//# sourceMappingURL=radix-ng-primitives-date-field.mjs.map
