import * as i0 from '@angular/core';
import { input, booleanAttribute, numberAttribute, Input, Directive, inject, ElementRef, EventEmitter, Output, NgModule } from '@angular/core';
import { CdkMenuTrigger, MENU_TRIGGER, PARENT_OR_NEW_MENU_STACK_PROVIDER, CdkMenu, CdkMenuItem, CDK_MENU } from '@angular/cdk/menu';
import { Subject, startWith, pairwise } from 'rxjs';
import { outputFromObservable, takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { UniqueSelectionDispatcher } from '@angular/cdk/collections';
import * as i1 from '@radix-ng/primitives/menu';
import { RdxMenuLabelDirective, RdxMenuSeparatorDirective } from '@radix-ng/primitives/menu';

var DropdownSide;
(function (DropdownSide) {
    DropdownSide["Top"] = "top";
    DropdownSide["Right"] = "right";
    DropdownSide["Bottom"] = "bottom";
    DropdownSide["Left"] = "left";
})(DropdownSide || (DropdownSide = {}));
var DropdownAlign;
(function (DropdownAlign) {
    DropdownAlign["Start"] = "start";
    DropdownAlign["Center"] = "center";
    DropdownAlign["End"] = "end";
})(DropdownAlign || (DropdownAlign = {}));
const mapRdxAlignToCdkPosition = {
    start: 'top',
    center: 'center',
    end: 'bottom'
};
const dropdownPositions = {
    top: {
        originX: 'start',
        originY: 'top',
        overlayX: 'start',
        overlayY: 'bottom',
        offsetX: 0,
        offsetY: 0
    },
    right: {
        originX: 'end',
        originY: 'top',
        overlayX: 'start',
        overlayY: 'top',
        offsetX: 0,
        offsetY: 0
    },
    bottom: {
        originX: 'start',
        originY: 'bottom',
        overlayX: 'start',
        overlayY: 'top',
        offsetX: 0,
        offsetY: 0
    },
    left: {
        originX: 'start',
        originY: 'top',
        overlayX: 'end',
        overlayY: 'top',
        offsetX: 0,
        offsetY: 0
    }
};
/**
 * @group Components
 */
class RdxDropdownMenuTriggerDirective extends CdkMenuTrigger {
    set rdxDropdownMenuTrigger(value) {
        this.menuTemplateRef = value;
    }
    /**
     * The preferred side of the trigger to render against when open.
     * Will be reversed when collisions occur and `avoidCollisions` is enabled.
     *
     * @group Props
     * @defaultValue 'bottom'
     */
    set side(value) {
        if (!Object.values(DropdownSide).includes(value)) {
            throw new Error(`Unknown side: ${value}`);
        }
        this._side = value;
        this.menuPosition[0] = dropdownPositions[value];
    }
    get side() {
        return this._side;
    }
    /**
     * The preferred alignment against the trigger. May change when collisions occur.
     *
     * @group Props
     * @defaultValue 'center'
     */
    set align(value) {
        if (!Object.values(DropdownAlign).includes(value)) {
            throw new Error(`Unknown align: ${value}`);
        }
        this._align = value;
        if (this.isVertical) {
            this.defaultPosition.overlayX = this.defaultPosition.originX = value;
        }
        else {
            this.defaultPosition.overlayY = this.defaultPosition.originY = mapRdxAlignToCdkPosition[value];
        }
    }
    get align() {
        return this._align;
    }
    /**
     * The distance in pixels from the trigger.
     * @group Props
     * @defaultValue 0
     */
    set sideOffset(value) {
        // todo need invert value for top and left
        if (this.isVertical) {
            this.defaultPosition.offsetY = value;
        }
        else {
            this.defaultPosition.offsetX = value;
        }
    }
    get sideOffset() {
        return this._sideOffset;
    }
    /**
     * An offset in pixels from the "start" or "end" alignment options.
     * @group Props
     * @defaultValue 0
     */
    set alignOffset(value) {
        // todo need invert value for top and left
        if (this.isVertical) {
            this.defaultPosition.offsetX = value;
        }
        else {
            this.defaultPosition.offsetY = value;
        }
    }
    get alignOffset() {
        return this._alignOffset;
    }
    get isVertical() {
        return this._side === DropdownSide.Top || this._side === DropdownSide.Bottom;
    }
    get defaultPosition() {
        return this.menuPosition[0];
    }
    constructor() {
        super();
        this.disabled = input(false, {
            transform: booleanAttribute
        });
        this._side = DropdownSide.Bottom;
        this._align = DropdownAlign.Start;
        this._sideOffset = 0;
        this._alignOffset = 0;
        this.onOpenChange = outputFromObservable(this.opened);
        // todo priority
        this.menuPosition = [{ ...dropdownPositions[DropdownSide.Bottom] }];
    }
    onPointerDown($event) {
        // only call handler if it's the left button (mousedown gets triggered by all mouse buttons)
        // but not when the control key is pressed (avoiding MacOS right click)
        if (!this.disabled() && $event.button === 0 && !$event.ctrlKey) {
            /* empty */
            if (!this.isOpen()) {
                // prevent trigger focusing when opening
                // this allows the content to be given focus without competition
                $event.preventDefault();
            }
        }
    }
    getOverlayRef() {
        return this.overlayRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxDropdownMenuTriggerDirective, isStandalone: true, selector: "[rdxDropdownMenuTrigger]", inputs: { disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, rdxDropdownMenuTrigger: { classPropertyName: "rdxDropdownMenuTrigger", publicName: "rdxDropdownMenuTrigger", isSignal: false, isRequired: false, transformFunction: null }, side: { classPropertyName: "side", publicName: "side", isSignal: false, isRequired: false, transformFunction: null }, align: { classPropertyName: "align", publicName: "align", isSignal: false, isRequired: false, transformFunction: null }, sideOffset: { classPropertyName: "sideOffset", publicName: "sideOffset", isSignal: false, isRequired: false, transformFunction: numberAttribute }, alignOffset: { classPropertyName: "alignOffset", publicName: "alignOffset", isSignal: false, isRequired: false, transformFunction: numberAttribute } }, outputs: { onOpenChange: "onOpenChange" }, host: { attributes: { "type": "button" }, listeners: { "pointerdown": "onPointerDown($event)" }, properties: { "attr.aria-haspopup": "'menu'", "attr.aria-expanded": "isOpen()", "attr.data-state": "isOpen() ? 'open': 'closed'", "attr.data-disabled": "disabled() ? '' : undefined", "disabled": "disabled()" } }, providers: [
            { provide: CdkMenuTrigger, useExisting: RdxDropdownMenuTriggerDirective },
            { provide: MENU_TRIGGER, useExisting: CdkMenuTrigger },
            PARENT_OR_NEW_MENU_STACK_PROVIDER
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuTrigger]',
                    standalone: true,
                    host: {
                        type: 'button',
                        '[attr.aria-haspopup]': "'menu'",
                        '[attr.aria-expanded]': 'isOpen()',
                        '[attr.data-state]': "isOpen() ? 'open': 'closed'",
                        '[attr.data-disabled]': "disabled() ? '' : undefined",
                        '[disabled]': 'disabled()',
                        '(pointerdown)': 'onPointerDown($event)'
                    },
                    providers: [
                        { provide: CdkMenuTrigger, useExisting: RdxDropdownMenuTriggerDirective },
                        { provide: MENU_TRIGGER, useExisting: CdkMenuTrigger },
                        PARENT_OR_NEW_MENU_STACK_PROVIDER
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { rdxDropdownMenuTrigger: [{
                type: Input
            }], side: [{
                type: Input
            }], align: [{
                type: Input
            }], sideOffset: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], alignOffset: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }] } });

class RdxDropdownMenuContentDirective extends CdkMenu {
    constructor() {
        super();
        this.highlighted = new Subject();
        this.menuTrigger = inject(RdxDropdownMenuTriggerDirective, { optional: true });
        this.onEscapeKeyDown = () => undefined;
        this.closeOnEscape = true;
        this.highlighted.pipe(startWith(null), pairwise()).subscribe(([prev, item]) => {
            if (prev) {
                prev.highlighted = false;
            }
            if (item) {
                item.highlighted = true;
            }
        });
    }
    updateActiveItem(item) {
        this.keyManager.updateActiveItem(item);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuContentDirective, isStandalone: true, selector: "[rdxDropdownMenuContent]", inputs: { onEscapeKeyDown: "onEscapeKeyDown", closeOnEscape: "closeOnEscape" }, host: { properties: { "attr.data-state": "menuTrigger.isOpen() ? 'open': 'closed'", "attr.data-align": "menuTrigger!.align", "attr.data-side": "menuTrigger!.side", "attr.data-orientation": "orientation" } }, providers: [
            {
                provide: CdkMenu,
                useExisting: RdxDropdownMenuContentDirective
            }
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuContent]',
                    standalone: true,
                    host: {
                        '[attr.data-state]': "menuTrigger.isOpen() ? 'open': 'closed'",
                        '[attr.data-align]': 'menuTrigger!.align',
                        '[attr.data-side]': 'menuTrigger!.side',
                        '[attr.data-orientation]': 'orientation'
                    },
                    providers: [
                        {
                            provide: CdkMenu,
                            useExisting: RdxDropdownMenuContentDirective
                        }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { onEscapeKeyDown: [{
                type: Input
            }], closeOnEscape: [{
                type: Input
            }] } });

class RdxDropdownMenuItemDirective extends CdkMenuItem {
    constructor() {
        super();
        this.menu = inject(RdxDropdownMenuContentDirective);
        this.nativeElement = inject(ElementRef).nativeElement;
        this.highlighted = false;
        this.disabled = false;
        this.onSelect = new EventEmitter();
        this.menu.highlighted.pipe(takeUntilDestroyed()).subscribe((value) => {
            if (value !== this) {
                this.highlighted = false;
            }
        });
        this.triggered.subscribe(this.onSelect);
    }
    onPointerMove() {
        if (!this.highlighted) {
            this.nativeElement.focus({ preventScroll: true });
            this.menu.updateActiveItem(this);
        }
    }
    onKeydown(event) {
        if (this.nativeElement.tagName !== 'BUTTON' && ['Enter', ' '].includes(event.key)) {
            event.preventDefault();
        }
        if (event.key === 'Escape') {
            if (!this.menu.closeOnEscape) {
                event.stopPropagation();
            }
            else {
                this.menu.onEscapeKeyDown(event);
            }
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.4", type: RdxDropdownMenuItemDirective, isStandalone: true, selector: "[rdxDropdownMenuItem]", inputs: { disabled: ["disabled", "disabled", booleanAttribute] }, outputs: { onSelect: "onSelect" }, host: { attributes: { "type": "button" }, listeners: { "pointermove": "onPointerMove()", "focus": "menu.highlighted.next(this)", "keydown": "onKeydown($event)" }, properties: { "attr.data-orientation": "\"vertical\"", "attr.data-highlighted": "highlighted ? \"\" : null", "attr.data-disabled": "disabled ? \"\" : null", "attr.disabled": "disabled ? \"\" : null" } }, providers: [
            { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
            { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuItem]',
                    standalone: true,
                    host: {
                        type: 'button',
                        // todo horizontal ?
                        '[attr.data-orientation]': '"vertical"',
                        '[attr.data-highlighted]': 'highlighted ? "" : null',
                        '[attr.data-disabled]': 'disabled ? "" : null',
                        '[attr.disabled]': 'disabled ? "" : null',
                        '(pointermove)': 'onPointerMove()',
                        '(focus)': 'menu.highlighted.next(this)',
                        '(keydown)': 'onKeydown($event)'
                    },
                    providers: [
                        { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
                        { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], onSelect: [{
                type: Output
            }] } });

/** Base class providing checked state for selectable DropdownMenuItems. */
class RdxDropdownMenuSelectable extends RdxDropdownMenuItemDirective {
    constructor() {
        super(...arguments);
        /** Whether the element is checked */
        this.checked = false;
        this.checkedChange = new EventEmitter();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuSelectable, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.2.4", type: RdxDropdownMenuSelectable, isStandalone: true, inputs: { checked: ["checked", "checked", booleanAttribute] }, outputs: { checkedChange: "checkedChange" }, host: { properties: { "attr.aria-checked": "!!checked", "attr.aria-disabled": "disabled || null", "attr.data-state": "checked ? \"checked\" : \"unchecked\"" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuSelectable, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    host: {
                        '[attr.aria-checked]': '!!checked',
                        '[attr.aria-disabled]': 'disabled || null',
                        '[attr.data-state]': 'checked ? "checked" : "unchecked"'
                    }
                }]
        }], propDecorators: { checked: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], checkedChange: [{
                type: Output
            }] } });

class RdxDropdownMenuItemCheckboxDirective extends RdxDropdownMenuSelectable {
    trigger(options) {
        if (!this.disabled) {
            this.checked = !this.checked;
            this.checkedChange.emit(this.checked);
        }
        super.trigger(options);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemCheckboxDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuItemCheckboxDirective, isStandalone: true, selector: "[rdxDropdownMenuItemCheckbox]", host: { attributes: { "role": "menuitemcheckbox" } }, providers: [
            { provide: RdxDropdownMenuSelectable, useExisting: RdxDropdownMenuItemCheckboxDirective },
            { provide: RdxDropdownMenuItemDirective, useExisting: RdxDropdownMenuSelectable },
            { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
            { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemCheckboxDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuItemCheckbox]',
                    standalone: true,
                    host: {
                        role: 'menuitemcheckbox'
                    },
                    providers: [
                        { provide: RdxDropdownMenuSelectable, useExisting: RdxDropdownMenuItemCheckboxDirective },
                        { provide: RdxDropdownMenuItemDirective, useExisting: RdxDropdownMenuSelectable },
                        { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
                        { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
                    ]
                }]
        }] });

class RdxDropdownMenuItemIndicatorDirective {
    constructor() {
        this.item = inject(RdxDropdownMenuSelectable);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemIndicatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuItemIndicatorDirective, isStandalone: true, selector: "[rdxDropdownMenuItemIndicator]", host: { properties: { "style.display": "item.checked ? 'block' : 'none'", "attr.data-state": "item.checked ? 'checked' : 'unchecked'" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemIndicatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuItemIndicator]',
                    standalone: true,
                    host: {
                        '[style.display]': "item.checked ? 'block' : 'none'",
                        '[attr.data-state]': "item.checked ? 'checked' : 'unchecked'"
                    }
                }]
        }] });

class RdxDropdownMenuItemRadioGroupDirective {
    constructor() {
        this.selectionDispatcher = inject(UniqueSelectionDispatcher);
        this._value = null;
        this.valueChange = new EventEmitter();
    }
    set value(id) {
        this._value = id;
    }
    get value() {
        return this._value;
    }
    ngAfterContentInit() {
        this.selectionDispatcher.notify(this.value, '');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemRadioGroupDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuItemRadioGroupDirective, isStandalone: true, selector: "[rdxDropdownMenuItemRadioGroup]", inputs: { value: "value" }, outputs: { valueChange: "valueChange" }, host: { attributes: { "role": "group" } }, providers: [{ provide: UniqueSelectionDispatcher, useClass: UniqueSelectionDispatcher }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemRadioGroupDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuItemRadioGroup]',
                    standalone: true,
                    host: {
                        role: 'group'
                    },
                    providers: [{ provide: UniqueSelectionDispatcher, useClass: UniqueSelectionDispatcher }]
                }]
        }], propDecorators: { value: [{
                type: Input
            }], valueChange: [{
                type: Output
            }] } });

/** Counter used to set a unique id and name for a selectable item */
let nextId = 0;
class RdxDropdownMenuItemRadioDirective extends RdxDropdownMenuSelectable {
    get value() {
        return this._value || this.id;
    }
    set value(value) {
        this._value = value;
    }
    constructor() {
        super();
        /** The unique selection dispatcher for this radio's `RdxDropdownMenuItemRadioGroupDirective`. */
        this.selectionDispatcher = inject(UniqueSelectionDispatcher);
        this.group = inject(RdxDropdownMenuItemRadioGroupDirective);
        /** An ID to identify this radio item to the `UniqueSelectionDispatcher`. */
        this.id = `${nextId++}`;
        this.triggered.subscribe(() => {
            if (!this.disabled) {
                this.selectionDispatcher.notify(this.value, '');
                this.group.valueChange.emit(this.value);
            }
        });
    }
    ngAfterContentInit() {
        this.removeDispatcherListener = this.selectionDispatcher.listen((id) => {
            this.checked = this.value === id;
        });
    }
    ngOnDestroy() {
        super.ngOnDestroy();
        this.removeDispatcherListener();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemRadioDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuItemRadioDirective, isStandalone: true, selector: "[rdxDropdownMenuItemRadio]", inputs: { value: "value" }, host: { attributes: { "role": "menuitemradio" } }, providers: [
            { provide: RdxDropdownMenuSelectable, useExisting: RdxDropdownMenuItemRadioDirective },
            { provide: RdxDropdownMenuItemDirective, useExisting: RdxDropdownMenuSelectable },
            { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
            { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuItemRadioDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuItemRadio]',
                    standalone: true,
                    host: {
                        role: 'menuitemradio'
                    },
                    providers: [
                        { provide: RdxDropdownMenuSelectable, useExisting: RdxDropdownMenuItemRadioDirective },
                        { provide: RdxDropdownMenuItemDirective, useExisting: RdxDropdownMenuSelectable },
                        { provide: CdkMenuItem, useExisting: RdxDropdownMenuItemDirective },
                        { provide: CDK_MENU, useExisting: RdxDropdownMenuContentDirective }
                    ]
                }]
        }], ctorParameters: () => [], propDecorators: { value: [{
                type: Input
            }] } });

class RdxDropdownMenuLabelDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuLabelDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuLabelDirective, isStandalone: true, selector: "[rdxDropdownMenuLabel]", hostDirectives: [{ directive: i1.RdxMenuLabelDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuLabelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuLabel]',
                    hostDirectives: [RdxMenuLabelDirective]
                }]
        }] });

class RdxDropdownMenuSeparatorDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuSeparatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxDropdownMenuSeparatorDirective, isStandalone: true, selector: "[rdxDropdownMenuSeparator]", hostDirectives: [{ directive: i1.RdxMenuSeparatorDirective }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxDropdownMenuSeparatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxDropdownMenuSeparator]',
                    hostDirectives: [RdxMenuSeparatorDirective]
                }]
        }] });

const _imports = [
    RdxDropdownMenuTriggerDirective,
    RdxDropdownMenuContentDirective,
    RdxDropdownMenuItemCheckboxDirective,
    RdxDropdownMenuItemIndicatorDirective,
    RdxDropdownMenuItemRadioGroupDirective,
    RdxDropdownMenuItemRadioDirective,
    RdxDropdownMenuSelectable,
    RdxDropdownMenuItemDirective,
    RdxDropdownMenuLabelDirective,
    RdxDropdownMenuSeparatorDirective,
    RdxDropdownMenuTriggerDirective
];
class Rdx {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: Rdx, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: Rdx, imports: [RdxDropdownMenuTriggerDirective,
            RdxDropdownMenuContentDirective,
            RdxDropdownMenuItemCheckboxDirective,
            RdxDropdownMenuItemIndicatorDirective,
            RdxDropdownMenuItemRadioGroupDirective,
            RdxDropdownMenuItemRadioDirective,
            RdxDropdownMenuSelectable,
            RdxDropdownMenuItemDirective,
            RdxDropdownMenuLabelDirective,
            RdxDropdownMenuSeparatorDirective,
            RdxDropdownMenuTriggerDirective], exports: [RdxDropdownMenuTriggerDirective,
            RdxDropdownMenuContentDirective,
            RdxDropdownMenuItemCheckboxDirective,
            RdxDropdownMenuItemIndicatorDirective,
            RdxDropdownMenuItemRadioGroupDirective,
            RdxDropdownMenuItemRadioDirective,
            RdxDropdownMenuSelectable,
            RdxDropdownMenuItemDirective,
            RdxDropdownMenuLabelDirective,
            RdxDropdownMenuSeparatorDirective,
            RdxDropdownMenuTriggerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: Rdx }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: Rdx, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DropdownAlign, DropdownSide, Rdx, RdxDropdownMenuContentDirective, RdxDropdownMenuItemCheckboxDirective, RdxDropdownMenuItemDirective, RdxDropdownMenuItemIndicatorDirective, RdxDropdownMenuItemRadioDirective, RdxDropdownMenuItemRadioGroupDirective, RdxDropdownMenuLabelDirective, RdxDropdownMenuSelectable, RdxDropdownMenuSeparatorDirective, RdxDropdownMenuTriggerDirective, mapRdxAlignToCdkPosition };
//# sourceMappingURL=radix-ng-primitives-dropdown-menu.mjs.map
