import * as i0 from '@angular/core';
import { inject, ElementRef, input, computed, Directive } from '@angular/core';

let idIterator = 0;
/**
 * @group Components
 */
class RdxLabelDirective {
    constructor() {
        this.elementRef = inject((ElementRef));
        /**
         * @default 'rdx-label-{idIterator}'
         */
        this.id = input(`rdx-label-${idIterator++}`);
        /**
         * The id of the element the label is associated with.
         * @group Props
         * @defaultValue false
         */
        this.htmlFor = input();
        this.elementId = computed(() => (this.id() ? this.id() : null));
    }
    // prevent text selection when double-clicking label
    // The main problem with double-clicks in a web app is that
    // you will have to create special code to handle this on touch enabled devices.
    /**
     * @ignore
     */
    onMouseDown(event) {
        const target = event.target;
        // only prevent text selection if clicking inside the label itself
        if (['BUTTON', 'INPUT', 'SELECT', 'TEXTAREA'].includes(target.tagName)) {
            return;
        }
        // prevent text selection when double-clicking label
        if (this.elementRef.nativeElement.contains(target) && !event.defaultPrevented && event.detail > 1) {
            event.preventDefault();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxLabelDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxLabelDirective, isStandalone: true, selector: "label[rdxLabel]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, htmlFor: { classPropertyName: "htmlFor", publicName: "htmlFor", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "mousedown": "onMouseDown($event)" }, properties: { "attr.id": "this.elementId()", "attr.for": "htmlFor ? htmlFor() : null" } }, exportAs: ["rdxLabel"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxLabelDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'label[rdxLabel]',
                    exportAs: 'rdxLabel',
                    host: {
                        '[attr.id]': 'this.elementId()',
                        '[attr.for]': 'htmlFor ? htmlFor() : null',
                        '(mousedown)': 'onMouseDown($event)'
                    }
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxLabelDirective };
//# sourceMappingURL=radix-ng-primitives-label.mjs.map
