import * as i0 from '@angular/core';
import { InjectionToken, inject, TemplateRef, DestroyRef, computed, input, numberAttribute, booleanAttribute, output, effect, untracked, SimpleChange, Directive, ElementRef, NgZone, Renderer2, isDevMode, VERSION, Injectable, makeEnvironmentProviders, signal, contentChild, ViewContainerRef, afterNextRender, assertInInjectionContext, forwardRef, ContentChild, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/cdk/overlay';
import { Overlay, CdkConnectedOverlay, CdkOverlayOrigin } from '@angular/cdk/overlay';
import { RdxPositionSide, RdxPositionAlign, RDX_POSITIONING_DEFAULTS, getContentPosition, getAllPossibleConnectedPositions, injectDocument, injectWindow, getArrowPositionParams, getSideAndAlignFromAllPossibleConnectedPositions, RdxFocusInitialDirective } from '@radix-ng/primitives/core';
import { takeUntilDestroyed, toSignal } from '@angular/core/rxjs-interop';
import { filter, tap } from 'rxjs';
import * as i1$1 from '@angular/cdk/a11y';
import { CdkTrapFocus } from '@angular/cdk/a11y';

const RdxPopoverAnchorToken = new InjectionToken('RdxPopoverAnchorToken');

const RdxPopoverArrowToken = new InjectionToken('RdxPopoverArrowToken');

const RdxPopoverCloseToken = new InjectionToken('RdxPopoverCloseToken');

const RdxPopoverContentAttributesToken = new InjectionToken('RdxPopoverContentAttributesToken');

var RdxPopoverState;
(function (RdxPopoverState) {
    RdxPopoverState["OPEN"] = "open";
    RdxPopoverState["CLOSED"] = "closed";
})(RdxPopoverState || (RdxPopoverState = {}));
var RdxPopoverAttachDetachEvent;
(function (RdxPopoverAttachDetachEvent) {
    RdxPopoverAttachDetachEvent["ATTACH"] = "attach";
    RdxPopoverAttachDetachEvent["DETACH"] = "detach";
})(RdxPopoverAttachDetachEvent || (RdxPopoverAttachDetachEvent = {}));
var RdxPopoverAnimationStatus;
(function (RdxPopoverAnimationStatus) {
    RdxPopoverAnimationStatus["OPEN_STARTED"] = "open_started";
    RdxPopoverAnimationStatus["OPEN_ENDED"] = "open_ended";
    RdxPopoverAnimationStatus["CLOSED_STARTED"] = "closed_started";
    RdxPopoverAnimationStatus["CLOSED_ENDED"] = "closed_ended";
})(RdxPopoverAnimationStatus || (RdxPopoverAnimationStatus = {}));

class RdxPopoverContentDirective {
    constructor() {
        /** @ignore */
        this.popoverRoot = injectPopoverRoot();
        /** @ignore */
        this.templateRef = inject(TemplateRef);
        /** @ignore */
        this.overlay = inject(Overlay);
        /** @ignore */
        this.destroyRef = inject(DestroyRef);
        /** @ignore */
        this.connectedOverlay = inject(CdkConnectedOverlay);
        /** @ignore */
        this.name = computed(() => `rdx-popover-trigger-${this.popoverRoot.uniqueId()}`);
        /**
         * @description The preferred side of the trigger to render against when open. Will be reversed when collisions occur and avoidCollisions is enabled.
         * @default top
         */
        this.side = input(RdxPositionSide.Top);
        /**
         * @description The distance in pixels from the trigger.
         * @default undefined
         */
        this.sideOffset = input(NaN, {
            transform: numberAttribute
        });
        /**
         * @description The preferred alignment against the trigger. May change when collisions occur.
         * @default center
         */
        this.align = input(RdxPositionAlign.Center);
        /**
         * @description An offset in pixels from the "start" or "end" alignment options.
         * @default undefined
         */
        this.alignOffset = input(NaN, {
            transform: numberAttribute
        });
        /**
         * @description Whether to add some alternate positions of the content.
         * @default false
         */
        this.alternatePositionsDisabled = input(false, { transform: booleanAttribute });
        /** @description Whether to prevent `onOverlayEscapeKeyDown` handler from calling. */
        this.onOverlayEscapeKeyDownDisabled = input(false, { transform: booleanAttribute });
        /** @description Whether to prevent `onOverlayOutsideClick` handler from calling. */
        this.onOverlayOutsideClickDisabled = input(false, { transform: booleanAttribute });
        /**
         * @description Event handler called when the escape key is down.
         * It can be prevented by setting `onOverlayEscapeKeyDownDisabled` input to `true`.
         */
        this.onOverlayEscapeKeyDown = output();
        /**
         * @description Event handler called when a pointer event occurs outside the bounds of the component.
         * It can be prevented by setting `onOverlayOutsideClickDisabled` input to `true`.
         */
        this.onOverlayOutsideClick = output();
        /**
         * @description Event handler called after the overlay is open
         */
        this.onOpen = output();
        /**
         * @description Event handler called after the overlay is closed
         */
        this.onClosed = output();
        /** @ingore */
        this.positions = computed(() => this.computePositions());
        this.onOriginChangeEffect();
        this.onPositionChangeEffect();
    }
    /** @ignore */
    ngOnInit() {
        this.setScrollStrategy();
        this.setHasBackdrop();
        this.setDisableClose();
        this.onAttach();
        this.onDetach();
        this.connectKeydownEscape();
        this.connectOutsideClick();
    }
    /** @ignore */
    open() {
        if (this.connectedOverlay.open) {
            return;
        }
        const prevOpen = this.connectedOverlay.open;
        this.connectedOverlay.open = true;
        this.fireOverlayNgOnChanges('open', this.connectedOverlay.open, prevOpen);
    }
    /** @ignore */
    close() {
        if (!this.connectedOverlay.open) {
            return;
        }
        const prevOpen = this.connectedOverlay.open;
        this.connectedOverlay.open = false;
        this.fireOverlayNgOnChanges('open', this.connectedOverlay.open, prevOpen);
    }
    /** @ignore */
    positionChange() {
        return this.connectedOverlay.positionChange.asObservable();
    }
    /** @ignore */
    connectKeydownEscape() {
        this.connectedOverlay.overlayKeydown
            .asObservable()
            .pipe(filter(() => !this.onOverlayEscapeKeyDownDisabled() &&
            !this.popoverRoot.rdxCdkEventService?.primitivePreventedFromCdkEvent(this.popoverRoot, 'cdkOverlayEscapeKeyDown')), filter((event) => event.key === 'Escape'), tap((event) => {
            this.onOverlayEscapeKeyDown.emit(event);
        }), filter(() => !this.popoverRoot.firstDefaultOpen()), tap(() => {
            this.popoverRoot.handleClose();
        }), takeUntilDestroyed(this.destroyRef))
            .subscribe();
    }
    /** @ignore */
    connectOutsideClick() {
        this.connectedOverlay.overlayOutsideClick
            .asObservable()
            .pipe(filter(() => !this.onOverlayOutsideClickDisabled() &&
            !this.popoverRoot.rdxCdkEventService?.primitivePreventedFromCdkEvent(this.popoverRoot, 'cdkOverlayOutsideClick')), 
        /**
         * Handle the situation when an anchor is added and the anchor becomes the origin of the overlay
         * hence  the trigger will be considered the outside element
         */
        filter((event) => {
            return (!this.popoverRoot.popoverAnchorDirective() ||
                !this.popoverRoot
                    .popoverTriggerDirective()
                    .elementRef.nativeElement.contains(event.target));
        }), tap((event) => {
            this.onOverlayOutsideClick.emit(event);
        }), filter(() => !this.popoverRoot.firstDefaultOpen()), tap(() => {
            this.popoverRoot.handleClose();
        }), takeUntilDestroyed(this.destroyRef))
            .subscribe();
    }
    /** @ignore */
    onAttach() {
        this.connectedOverlay.attach
            .asObservable()
            .pipe(tap(() => {
            /**
             * `this.onOpen.emit();` is being delegated to the root directive due to the opening animation
             */
            this.popoverRoot.attachDetachEvent.set(RdxPopoverAttachDetachEvent.ATTACH);
        }), takeUntilDestroyed(this.destroyRef))
            .subscribe();
    }
    /** @ignore */
    onDetach() {
        this.connectedOverlay.detach
            .asObservable()
            .pipe(tap(() => {
            /**
             * `this.onClosed.emit();` is being delegated to the root directive due to the closing animation
             */
            this.popoverRoot.attachDetachEvent.set(RdxPopoverAttachDetachEvent.DETACH);
        }), takeUntilDestroyed(this.destroyRef))
            .subscribe();
    }
    /** @ignore */
    setScrollStrategy() {
        const prevScrollStrategy = this.connectedOverlay.scrollStrategy;
        this.connectedOverlay.scrollStrategy = this.overlay.scrollStrategies.reposition();
        this.fireOverlayNgOnChanges('scrollStrategy', this.connectedOverlay.scrollStrategy, prevScrollStrategy);
    }
    /** @ignore */
    setHasBackdrop() {
        const prevHasBackdrop = this.connectedOverlay.hasBackdrop;
        this.connectedOverlay.hasBackdrop = false;
        this.fireOverlayNgOnChanges('hasBackdrop', this.connectedOverlay.hasBackdrop, prevHasBackdrop);
    }
    /** @ignore */
    setDisableClose() {
        const prevDisableClose = this.connectedOverlay.disableClose;
        this.connectedOverlay.disableClose = true;
        this.fireOverlayNgOnChanges('disableClose', this.connectedOverlay.disableClose, prevDisableClose);
    }
    /** @ignore */
    setOrigin(origin) {
        const prevOrigin = this.connectedOverlay.origin;
        this.connectedOverlay.origin = origin;
        this.fireOverlayNgOnChanges('origin', this.connectedOverlay.origin, prevOrigin);
    }
    /** @ignore */
    setPositions(positions) {
        const prevPositions = this.connectedOverlay.positions;
        this.connectedOverlay.positions = positions;
        this.fireOverlayNgOnChanges('positions', this.connectedOverlay.positions, prevPositions);
        this.connectedOverlay.overlayRef?.updatePosition();
    }
    /** @ignore */
    computePositions() {
        const arrowHeight = this.popoverRoot.popoverArrowDirective()?.height() ?? 0;
        const offsets = {
            sideOffset: arrowHeight + (isNaN(this.sideOffset()) ? RDX_POSITIONING_DEFAULTS.offsets.side : this.sideOffset()),
            alignOffset: isNaN(this.alignOffset()) ? RDX_POSITIONING_DEFAULTS.offsets.align : this.alignOffset()
        };
        const basePosition = getContentPosition({
            side: this.side(),
            align: this.align(),
            sideOffset: offsets.sideOffset,
            alignOffset: offsets.alignOffset
        });
        const positions = [basePosition];
        if (!this.alternatePositionsDisabled()) {
            /**
             * Alternate positions for better user experience along the X/Y axis (e.g. vertical/horizontal scrolling)
             */
            const allPossibleConnectedPositions = getAllPossibleConnectedPositions();
            allPossibleConnectedPositions.forEach((_, key) => {
                const sideAndAlignArray = key.split('|');
                if (sideAndAlignArray[0] !== this.side() ||
                    sideAndAlignArray[1] !== this.align()) {
                    positions.push(getContentPosition({
                        side: sideAndAlignArray[0],
                        align: sideAndAlignArray[1],
                        sideOffset: offsets.sideOffset,
                        alignOffset: offsets.alignOffset
                    }));
                }
            });
        }
        return positions;
    }
    onOriginChangeEffect() {
        effect(() => {
            const origin = (this.popoverRoot.popoverAnchorDirective() ?? this.popoverRoot.popoverTriggerDirective())
                .overlayOrigin;
            untracked(() => {
                this.setOrigin(origin);
            });
        });
    }
    /** @ignore */
    onPositionChangeEffect() {
        effect(() => {
            const positions = this.positions();
            this.alternatePositionsDisabled();
            untracked(() => {
                this.setPositions(positions);
            });
        });
    }
    /** @ignore */
    fireOverlayNgOnChanges(input, currentValue, previousValue, firstChange = false) {
        this.connectedOverlay.ngOnChanges({
            [input]: new SimpleChange(previousValue, currentValue, firstChange)
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxPopoverContentDirective, isStandalone: true, selector: "[rdxPopoverContent]", inputs: { side: { classPropertyName: "side", publicName: "side", isSignal: true, isRequired: false, transformFunction: null }, sideOffset: { classPropertyName: "sideOffset", publicName: "sideOffset", isSignal: true, isRequired: false, transformFunction: null }, align: { classPropertyName: "align", publicName: "align", isSignal: true, isRequired: false, transformFunction: null }, alignOffset: { classPropertyName: "alignOffset", publicName: "alignOffset", isSignal: true, isRequired: false, transformFunction: null }, alternatePositionsDisabled: { classPropertyName: "alternatePositionsDisabled", publicName: "alternatePositionsDisabled", isSignal: true, isRequired: false, transformFunction: null }, onOverlayEscapeKeyDownDisabled: { classPropertyName: "onOverlayEscapeKeyDownDisabled", publicName: "onOverlayEscapeKeyDownDisabled", isSignal: true, isRequired: false, transformFunction: null }, onOverlayOutsideClickDisabled: { classPropertyName: "onOverlayOutsideClickDisabled", publicName: "onOverlayOutsideClickDisabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { onOverlayEscapeKeyDown: "onOverlayEscapeKeyDown", onOverlayOutsideClick: "onOverlayOutsideClick", onOpen: "onOpen", onClosed: "onClosed" }, hostDirectives: [{ directive: i1.CdkConnectedOverlay }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverContent]',
                    hostDirectives: [CdkConnectedOverlay]
                }]
        }], ctorParameters: () => [] });

class RdxPopoverTriggerDirective {
    constructor() {
        /** @ignore */
        this.popoverRoot = injectPopoverRoot();
        /** @ignore */
        this.elementRef = inject(ElementRef);
        /** @ignore */
        this.overlayOrigin = inject(CdkOverlayOrigin);
        /** @ignore */
        this.name = computed(() => `rdx-popover-trigger-${this.popoverRoot.uniqueId()}`);
    }
    /** @ignore */
    click() {
        this.popoverRoot.handleToggle();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxPopoverTriggerDirective, isStandalone: true, selector: "[rdxPopoverTrigger]", host: { attributes: { "type": "button" }, listeners: { "click": "click()" }, properties: { "attr.id": "name()", "attr.aria-haspopup": "\"dialog\"", "attr.aria-expanded": "popoverRoot.isOpen()", "attr.aria-controls": "popoverRoot.popoverContentDirective().name()", "attr.data-state": "popoverRoot.state()" } }, hostDirectives: [{ directive: i1.CdkOverlayOrigin }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverTrigger]',
                    hostDirectives: [CdkOverlayOrigin],
                    host: {
                        type: 'button',
                        '[attr.id]': 'name()',
                        '[attr.aria-haspopup]': '"dialog"',
                        '[attr.aria-expanded]': 'popoverRoot.isOpen()',
                        '[attr.aria-controls]': 'popoverRoot.popoverContentDirective().name()',
                        '[attr.data-state]': 'popoverRoot.state()',
                        '(click)': 'click()'
                    }
                }]
        }] });

const RdxCdkEventServiceWindowKey = Symbol('__RdxCdkEventService__');

function eventTypeAsPrimitiveConfigKey(eventType) {
    return `prevent${eventType[0].toUpperCase()}${eventType.slice(1)}`;
}
class RdxCdkEventService {
    #clickDomRootEventCallbacks;
    constructor() {
        this.document = injectDocument();
        this.destroyRef = inject(DestroyRef);
        this.ngZone = inject(NgZone);
        this.renderer2 = inject(Renderer2);
        this.window = injectWindow();
        this.onDestroyCallbacks = new Set([() => deleteRdxCdkEventServiceWindowKey(this.window)]);
        this.#clickDomRootEventCallbacks = new Set();
        this.#listenToClickDomRootEvent();
        this.#registerOnDestroyCallbacks();
    }
    registerPrimitive(primitiveInstance) {
        if (!this.primitiveConfigs) {
            this.primitiveConfigs = new Map();
        }
        if (!this.primitiveConfigs.has(primitiveInstance)) {
            this.primitiveConfigs.set(primitiveInstance, {});
        }
    }
    deregisterPrimitive(primitiveInstance) {
        if (this.primitiveConfigs?.has(primitiveInstance)) {
            this.primitiveConfigs.delete(primitiveInstance);
        }
    }
    preventPrimitiveFromCdkEvent(primitiveInstance, eventType) {
        this.#setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, true);
    }
    allowPrimitiveForCdkEvent(primitiveInstance, eventType) {
        this.#setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, false);
    }
    preventPrimitiveFromCdkMultiEvents(primitiveInstance, eventTypes) {
        eventTypes.forEach((eventType) => {
            this.#setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, true);
        });
    }
    allowPrimitiveForCdkMultiEvents(primitiveInstance, eventTypes) {
        eventTypes.forEach((eventType) => {
            this.#setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, false);
        });
    }
    setPreventPrimitiveFromCdkMixEvents(primitiveInstance, eventTypes) {
        Object.keys(eventTypes).forEach((eventType) => {
            this.#setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, eventTypes[eventTypeAsPrimitiveConfigKey(eventType)]);
        });
    }
    primitivePreventedFromCdkEvent(primitiveInstance, eventType) {
        return this.primitiveConfigs?.get(primitiveInstance)?.[eventTypeAsPrimitiveConfigKey(eventType)];
    }
    addClickDomRootEventCallback(callback) {
        this.#clickDomRootEventCallbacks.add(callback);
    }
    removeClickDomRootEventCallback(callback) {
        return this.#clickDomRootEventCallbacks.delete(callback);
    }
    #setPreventPrimitiveFromCdkEvent(primitiveInstance, eventType, value) {
        if (!this.primitiveConfigs?.has(primitiveInstance)) {
            isDevMode() &&
                console.error('[RdxCdkEventService.preventPrimitiveFromCdkEvent] RDX Primitive instance has not been registered!', primitiveInstance);
            return;
        }
        switch (eventType) {
            case 'cdkOverlayOutsideClick':
                this.primitiveConfigs.get(primitiveInstance).preventCdkOverlayOutsideClick = value;
                break;
            case 'cdkOverlayEscapeKeyDown':
                this.primitiveConfigs.get(primitiveInstance).preventCdkOverlayEscapeKeyDown = value;
                break;
        }
    }
    #registerOnDestroyCallbacks() {
        this.destroyRef.onDestroy(() => {
            this.onDestroyCallbacks.forEach((onDestroyCallback) => onDestroyCallback());
            this.onDestroyCallbacks.clear();
        });
    }
    #listenToClickDomRootEvent() {
        const target = this.document;
        const eventName = 'click';
        const options = { capture: true };
        const callback = (event) => {
            this.#clickDomRootEventCallbacks.forEach((clickDomRootEventCallback) => clickDomRootEventCallback(event));
        };
        const major = parseInt(VERSION.major);
        const minor = parseInt(VERSION.minor);
        let destroyClickDomRootEventListener;
        /**
         * @see src/cdk/platform/features/backwards-compatibility.ts in @angular/cdk
         */
        if (major > 19 || (major === 19 && minor > 0) || (major === 0 && minor === 0)) {
            destroyClickDomRootEventListener = this.ngZone.runOutsideAngular(() => {
                const destroyClickDomRootEventListenerInternal = this.renderer2.listen(target, eventName, callback, options);
                return () => {
                    destroyClickDomRootEventListenerInternal();
                    this.#clickDomRootEventCallbacks.clear();
                };
            });
        }
        else {
            /**
             * This part can get removed when v19.1 or higher is on the board
             */
            destroyClickDomRootEventListener = this.ngZone.runOutsideAngular(() => {
                target.addEventListener(eventName, callback, options);
                return () => {
                    this.ngZone.runOutsideAngular(() => target.removeEventListener(eventName, callback, options));
                    this.#clickDomRootEventCallbacks.clear();
                };
            });
        }
        this.onDestroyCallbacks.add(destroyClickDomRootEventListener);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCdkEventService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCdkEventService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxCdkEventService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [] });
const RdxCdkEventServiceToken = new InjectionToken('RdxCdkEventServiceToken');
const existsErrorMessage = 'RdxCdkEventService should be provided only once!';
const deleteRdxCdkEventServiceWindowKey = (window) => {
    delete window[RdxCdkEventServiceWindowKey];
};
const getProvider = (throwWhenExists = true) => ({
    provide: RdxCdkEventServiceToken,
    useFactory: () => {
        isDevMode() && console.log('providing RdxCdkEventService...');
        const window = injectWindow();
        if (window[RdxCdkEventServiceWindowKey]) {
            if (throwWhenExists) {
                throw Error(existsErrorMessage);
            }
            else {
                isDevMode() && console.warn(existsErrorMessage);
            }
        }
        window[RdxCdkEventServiceWindowKey] ??= new RdxCdkEventService();
        return window[RdxCdkEventServiceWindowKey];
    }
});
const provideRdxCdkEventServiceInRoot = () => makeEnvironmentProviders([getProvider()]);
const provideRdxCdkEventService = () => getProvider(false);
const injectRdxCdkEventService = () => inject(RdxCdkEventServiceToken, { optional: true });

let nextId = 0;
class RdxPopoverRootDirective {
    constructor() {
        /** @ignore */
        this.uniqueId = signal(++nextId);
        /** @ignore */
        this.name = computed(() => `rdx-popover-root-${this.uniqueId()}`);
        /**
         * @description The anchor directive that comes form outside the popover root
         * @default undefined
         */
        this.anchor = input(void 0);
        /**
         * @description The open state of the popover when it is initially rendered. Use when you do not need to control its open state.
         * @default false
         */
        this.defaultOpen = input(false, { transform: booleanAttribute });
        /**
         * @description The controlled state of the popover. `open` input take precedence of `defaultOpen` input.
         * @default undefined
         */
        this.open = input(void 0, { transform: booleanAttribute });
        /**
         * @description Whether to control the state of the popover from external. Use in conjunction with `open` input.
         * @default undefined
         */
        this.externalControl = input(void 0, { transform: booleanAttribute });
        /**
         * @description Whether to take into account CSS opening/closing animations.
         * @default false
         */
        this.cssAnimation = input(false, { transform: booleanAttribute });
        /**
         * @description Whether to take into account CSS opening animations. `cssAnimation` input must be set to 'true'
         * @default false
         */
        this.cssOpeningAnimation = input(false, { transform: booleanAttribute });
        /**
         * @description Whether to take into account CSS closing animations. `cssAnimation` input must be set to 'true'
         * @default false
         */
        this.cssClosingAnimation = input(false, { transform: booleanAttribute });
        /** @ignore */
        this.cssAnimationStatus = signal(null);
        /** @ignore */
        this.popoverContentDirective = contentChild.required(RdxPopoverContentDirective);
        /** @ignore */
        this.popoverTriggerDirective = contentChild.required(RdxPopoverTriggerDirective);
        /** @ignore */
        this.popoverArrowDirective = contentChild(RdxPopoverArrowToken);
        /** @ignore */
        this.popoverCloseDirective = contentChild(RdxPopoverCloseToken);
        /** @ignore */
        this.popoverContentAttributesComponent = contentChild(RdxPopoverContentAttributesToken);
        /** @ignore */
        this.internalPopoverAnchorDirective = contentChild(RdxPopoverAnchorToken);
        /** @ignore */
        this.viewContainerRef = inject(ViewContainerRef);
        /** @ignore */
        this.rdxCdkEventService = injectRdxCdkEventService();
        /** @ignore */
        this.destroyRef = inject(DestroyRef);
        /** @ignore */
        this.state = signal(RdxPopoverState.CLOSED);
        /** @ignore */
        this.attachDetachEvent = signal(RdxPopoverAttachDetachEvent.DETACH);
        /** @ignore */
        this.isFirstDefaultOpen = signal(false);
        /** @ignore */
        this.popoverAnchorDirective = computed(() => this.internalPopoverAnchorDirective() ?? this.anchor());
        /** @ignore */
        this.onAnchorChangeEffect = () => {
            effect(() => {
                const anchor = this.anchor();
                untracked(() => {
                    if (anchor) {
                        anchor.setPopoverRoot(this);
                    }
                });
            });
        };
        this.rdxCdkEventService?.registerPrimitive(this);
        this.destroyRef.onDestroy(() => this.rdxCdkEventService?.deregisterPrimitive(this));
        this.onStateChangeEffect();
        this.onCssAnimationStatusChangeChangeEffect();
        this.onOpenChangeEffect();
        this.onIsFirstDefaultOpenChangeEffect();
        this.onAnchorChangeEffect();
        this.emitOpenOrClosedEventEffect();
        afterNextRender({
            write: () => {
                if (this.defaultOpen() && !this.open()) {
                    this.isFirstDefaultOpen.set(true);
                }
            }
        });
    }
    /** @ignore */
    getAnimationParamsSnapshot() {
        return {
            cssAnimation: this.cssAnimation(),
            cssOpeningAnimation: this.cssOpeningAnimation(),
            cssClosingAnimation: this.cssClosingAnimation(),
            cssAnimationStatus: this.cssAnimationStatus(),
            attachDetachEvent: this.attachDetachEvent(),
            state: this.state(),
            canEmitOnOpenOrOnClosed: this.canEmitOnOpenOrOnClosed()
        };
    }
    /** @ignore */
    controlledExternally() {
        return this.externalControl;
    }
    /** @ignore */
    firstDefaultOpen() {
        return this.isFirstDefaultOpen();
    }
    /** @ignore */
    handleOpen() {
        if (this.externalControl()) {
            return;
        }
        this.setState(RdxPopoverState.OPEN);
    }
    /** @ignore */
    handleClose() {
        if (this.isFirstDefaultOpen()) {
            this.isFirstDefaultOpen.set(false);
        }
        if (this.externalControl()) {
            return;
        }
        this.setState(RdxPopoverState.CLOSED);
    }
    /** @ignore */
    handleToggle() {
        if (this.externalControl()) {
            return;
        }
        this.isOpen() ? this.handleClose() : this.handleOpen();
    }
    /** @ignore */
    isOpen(state) {
        return (state ?? this.state()) === RdxPopoverState.OPEN;
    }
    /** @ignore */
    setState(state = RdxPopoverState.CLOSED) {
        if (state === this.state()) {
            return;
        }
        this.state.set(state);
    }
    /** @ignore */
    openContent() {
        this.popoverContentDirective().open();
        if (!this.cssAnimation() || !this.cssOpeningAnimation()) {
            this.cssAnimationStatus.set(null);
        }
    }
    /** @ignore */
    closeContent() {
        this.popoverContentDirective().close();
        if (!this.cssAnimation() || !this.cssClosingAnimation()) {
            this.cssAnimationStatus.set(null);
        }
    }
    /** @ignore */
    emitOnOpen() {
        this.popoverContentDirective().onOpen.emit();
    }
    /** @ignore */
    emitOnClosed() {
        this.popoverContentDirective().onClosed.emit();
    }
    /** @ignore */
    ifOpenOrCloseWithoutAnimations(state) {
        return (!this.popoverContentAttributesComponent() ||
            !this.cssAnimation() ||
            (this.cssAnimation() && !this.cssClosingAnimation() && state === RdxPopoverState.CLOSED) ||
            (this.cssAnimation() && !this.cssOpeningAnimation() && state === RdxPopoverState.OPEN) ||
            // !this.cssAnimationStatus() ||
            (this.cssOpeningAnimation() &&
                state === RdxPopoverState.OPEN &&
                [RdxPopoverAnimationStatus.OPEN_STARTED].includes(this.cssAnimationStatus())) ||
            (this.cssClosingAnimation() &&
                state === RdxPopoverState.CLOSED &&
                [RdxPopoverAnimationStatus.CLOSED_STARTED].includes(this.cssAnimationStatus())));
    }
    /** @ignore */
    ifOpenOrCloseWithAnimations(cssAnimationStatus) {
        return (this.popoverContentAttributesComponent() &&
            this.cssAnimation() &&
            cssAnimationStatus &&
            ((this.cssOpeningAnimation() &&
                this.state() === RdxPopoverState.OPEN &&
                [RdxPopoverAnimationStatus.OPEN_ENDED].includes(cssAnimationStatus)) ||
                (this.cssClosingAnimation() &&
                    this.state() === RdxPopoverState.CLOSED &&
                    [RdxPopoverAnimationStatus.CLOSED_ENDED].includes(cssAnimationStatus))));
    }
    /** @ignore */
    openOrClose(state) {
        const isOpen = this.isOpen(state);
        isOpen ? this.openContent() : this.closeContent();
    }
    /** @ignore */
    emitOnOpenOrOnClosed(state) {
        this.isOpen(state)
            ? this.attachDetachEvent() === RdxPopoverAttachDetachEvent.ATTACH && this.emitOnOpen()
            : this.attachDetachEvent() === RdxPopoverAttachDetachEvent.DETACH && this.emitOnClosed();
    }
    /** @ignore */
    canEmitOnOpenOrOnClosed() {
        return (!this.cssAnimation() ||
            (!this.cssOpeningAnimation() && this.state() === RdxPopoverState.OPEN) ||
            (this.cssOpeningAnimation() &&
                this.state() === RdxPopoverState.OPEN &&
                this.cssAnimationStatus() === RdxPopoverAnimationStatus.OPEN_ENDED) ||
            (!this.cssClosingAnimation() && this.state() === RdxPopoverState.CLOSED) ||
            (this.cssClosingAnimation() &&
                this.state() === RdxPopoverState.CLOSED &&
                this.cssAnimationStatus() === RdxPopoverAnimationStatus.CLOSED_ENDED));
    }
    /** @ignore */
    onStateChangeEffect() {
        let isFirst = true;
        effect(() => {
            const state = this.state();
            untracked(() => {
                if (isFirst) {
                    isFirst = false;
                    return;
                }
                if (!this.ifOpenOrCloseWithoutAnimations(state)) {
                    return;
                }
                this.openOrClose(state);
            });
        }, {});
    }
    /** @ignore */
    onCssAnimationStatusChangeChangeEffect() {
        let isFirst = true;
        effect(() => {
            const cssAnimationStatus = this.cssAnimationStatus();
            untracked(() => {
                if (isFirst) {
                    isFirst = false;
                    return;
                }
                if (!this.ifOpenOrCloseWithAnimations(cssAnimationStatus)) {
                    return;
                }
                this.openOrClose(this.state());
            });
        });
    }
    /** @ignore */
    emitOpenOrClosedEventEffect() {
        let isFirst = true;
        effect(() => {
            this.attachDetachEvent();
            this.cssAnimationStatus();
            untracked(() => {
                if (isFirst) {
                    isFirst = false;
                    return;
                }
                const canEmitOpenClose = untracked(() => this.canEmitOnOpenOrOnClosed());
                if (!canEmitOpenClose) {
                    return;
                }
                this.emitOnOpenOrOnClosed(this.state());
            });
        });
    }
    /** @ignore */
    onOpenChangeEffect() {
        effect(() => {
            const open = this.open();
            untracked(() => {
                this.setState(open ? RdxPopoverState.OPEN : RdxPopoverState.CLOSED);
            });
        });
    }
    /** @ignore */
    onIsFirstDefaultOpenChangeEffect() {
        const effectRef = effect(() => {
            const defaultOpen = this.defaultOpen();
            untracked(() => {
                if (!defaultOpen || this.open()) {
                    effectRef.destroy();
                    return;
                }
                this.handleOpen();
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.2.0", version: "19.2.4", type: RdxPopoverRootDirective, isStandalone: true, selector: "[rdxPopoverRoot]", inputs: { anchor: { classPropertyName: "anchor", publicName: "anchor", isSignal: true, isRequired: false, transformFunction: null }, defaultOpen: { classPropertyName: "defaultOpen", publicName: "defaultOpen", isSignal: true, isRequired: false, transformFunction: null }, open: { classPropertyName: "open", publicName: "open", isSignal: true, isRequired: false, transformFunction: null }, externalControl: { classPropertyName: "externalControl", publicName: "externalControl", isSignal: true, isRequired: false, transformFunction: null }, cssAnimation: { classPropertyName: "cssAnimation", publicName: "cssAnimation", isSignal: true, isRequired: false, transformFunction: null }, cssOpeningAnimation: { classPropertyName: "cssOpeningAnimation", publicName: "cssOpeningAnimation", isSignal: true, isRequired: false, transformFunction: null }, cssClosingAnimation: { classPropertyName: "cssClosingAnimation", publicName: "cssClosingAnimation", isSignal: true, isRequired: false, transformFunction: null } }, queries: [{ propertyName: "popoverContentDirective", first: true, predicate: RdxPopoverContentDirective, descendants: true, isSignal: true }, { propertyName: "popoverTriggerDirective", first: true, predicate: RdxPopoverTriggerDirective, descendants: true, isSignal: true }, { propertyName: "popoverArrowDirective", first: true, predicate: RdxPopoverArrowToken, descendants: true, isSignal: true }, { propertyName: "popoverCloseDirective", first: true, predicate: RdxPopoverCloseToken, descendants: true, isSignal: true }, { propertyName: "popoverContentAttributesComponent", first: true, predicate: RdxPopoverContentAttributesToken, descendants: true, isSignal: true }, { propertyName: "internalPopoverAnchorDirective", first: true, predicate: RdxPopoverAnchorToken, descendants: true, isSignal: true }], exportAs: ["rdxPopoverRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverRoot]',
                    exportAs: 'rdxPopoverRoot'
                }]
        }], ctorParameters: () => [] });

function injectPopoverRoot(optional = false) {
    isDevMode() && assertInInjectionContext(injectPopoverRoot);
    return inject(RdxPopoverRootDirective, { optional });
}

class RdxPopoverAnchorDirective {
    constructor() {
        /**
         * @ignore
         * If outside the root then null, otherwise the root directive - with optional `true` passed in as the first param.
         * If outside the root and non-null value that means the html structure is wrong - popover inside popover.
         * */
        this.popoverRoot = injectPopoverRoot(true);
        /** @ignore */
        this.elementRef = inject(ElementRef);
        /** @ignore */
        this.overlayOrigin = inject(CdkOverlayOrigin);
        /** @ignore */
        this.document = injectDocument();
        /** @ignore */
        this.name = computed(() => `rdx-popover-external-anchor-${this.popoverRoot?.uniqueId()}`);
    }
    /** @ignore */
    click() {
        this.emitOutsideClick();
    }
    /** @ignore */
    setPopoverRoot(popoverRoot) {
        this.popoverRoot = popoverRoot;
    }
    emitOutsideClick() {
        if (!this.popoverRoot?.isOpen() ||
            this.popoverRoot?.popoverContentDirective().onOverlayOutsideClickDisabled()) {
            return;
        }
        const clickEvent = new MouseEvent('click', {
            view: this.document.defaultView,
            bubbles: true,
            cancelable: true,
            relatedTarget: this.elementRef.nativeElement
        });
        this.popoverRoot?.popoverTriggerDirective().elementRef.nativeElement.dispatchEvent(clickEvent);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverAnchorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxPopoverAnchorDirective, isStandalone: true, selector: "[rdxPopoverAnchor]", host: { attributes: { "type": "button" }, listeners: { "click": "click()" }, properties: { "attr.id": "name()", "attr.aria-haspopup": "\"dialog\"" } }, providers: [
            {
                provide: RdxPopoverAnchorToken,
                useExisting: forwardRef(() => RdxPopoverAnchorDirective)
            }
        ], exportAs: ["rdxPopoverAnchor"], hostDirectives: [{ directive: i1.CdkOverlayOrigin }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverAnchorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverAnchor]',
                    exportAs: 'rdxPopoverAnchor',
                    hostDirectives: [CdkOverlayOrigin],
                    host: {
                        type: 'button',
                        '[attr.id]': 'name()',
                        '[attr.aria-haspopup]': '"dialog"',
                        '(click)': 'click()'
                    },
                    providers: [
                        {
                            provide: RdxPopoverAnchorToken,
                            useExisting: forwardRef(() => RdxPopoverAnchorDirective)
                        }
                    ]
                }]
        }] });

class RdxPopoverArrowDirective {
    constructor() {
        /** @ignore */
        this.renderer = inject(Renderer2);
        /** @ignore */
        this.popoverRoot = injectPopoverRoot();
        /** @ignore */
        this.elementRef = inject(ElementRef);
        /**
         * @description The width of the arrow in pixels.
         * @default 10
         */
        this.width = input(RDX_POSITIONING_DEFAULTS.arrow.width, { transform: numberAttribute });
        /**
         * @description The height of the arrow in pixels.
         * @default 5
         */
        this.height = input(RDX_POSITIONING_DEFAULTS.arrow.height, { transform: numberAttribute });
        /** @ignore */
        this.arrowSvgElement = computed(() => {
            const width = this.width();
            const height = this.height();
            const svgElement = this.renderer.createElement('svg', 'svg');
            this.renderer.setAttribute(svgElement, 'viewBox', '0 0 30 10');
            this.renderer.setAttribute(svgElement, 'width', String(width));
            this.renderer.setAttribute(svgElement, 'height', String(height));
            const polygonElement = this.renderer.createElement('polygon', 'svg');
            this.renderer.setAttribute(polygonElement, 'points', '0,0 30,0 15,10');
            this.renderer.setAttribute(svgElement, 'preserveAspectRatio', 'none');
            this.renderer.appendChild(svgElement, polygonElement);
            return svgElement;
        });
        /** @ignore */
        this.currentArrowSvgElement = signal(void 0);
        /** @ignore */
        this.position = toSignal(this.popoverRoot.popoverContentDirective().positionChange());
        afterNextRender({
            write: () => {
                if (this.elementRef.nativeElement.parentElement) {
                    this.renderer.setStyle(this.elementRef.nativeElement.parentElement, 'position', 'relative');
                }
                this.renderer.setStyle(this.elementRef.nativeElement, 'position', 'absolute');
                this.renderer.setStyle(this.elementRef.nativeElement, 'boxSizing', '');
                this.renderer.setStyle(this.elementRef.nativeElement, 'fontSize', '0px');
            }
        });
        this.onArrowSvgElementChangeEffect();
        this.onContentPositionAndArrowDimensionsChangeEffect();
    }
    /** @ignore */
    setAnchorOrTriggerRect() {
        this.anchorOrTriggerRect = (this.popoverRoot.popoverAnchorDirective() ?? this.popoverRoot.popoverTriggerDirective()).elementRef.nativeElement.getBoundingClientRect();
    }
    /** @ignore */
    setPosition(position, arrowDimensions) {
        this.setAnchorOrTriggerRect();
        const posParams = getArrowPositionParams(getSideAndAlignFromAllPossibleConnectedPositions(position.connectionPair), { width: arrowDimensions.width, height: arrowDimensions.height }, { width: this.anchorOrTriggerRect.width, height: this.anchorOrTriggerRect.height });
        this.renderer.setStyle(this.elementRef.nativeElement, 'top', posParams.top);
        this.renderer.setStyle(this.elementRef.nativeElement, 'bottom', '');
        this.renderer.setStyle(this.elementRef.nativeElement, 'left', posParams.left);
        this.renderer.setStyle(this.elementRef.nativeElement, 'right', '');
        this.renderer.setStyle(this.elementRef.nativeElement, 'transform', posParams.transform);
        this.renderer.setStyle(this.elementRef.nativeElement, 'transformOrigin', posParams.transformOrigin);
    }
    /** @ignore */
    onArrowSvgElementChangeEffect() {
        effect(() => {
            const arrowElement = this.arrowSvgElement();
            untracked(() => {
                const currentArrowSvgElement = this.currentArrowSvgElement();
                if (currentArrowSvgElement) {
                    this.renderer.removeChild(this.elementRef.nativeElement, currentArrowSvgElement);
                }
                this.currentArrowSvgElement.set(arrowElement);
                this.renderer.setStyle(this.elementRef.nativeElement, 'width', `${this.width()}px`);
                this.renderer.setStyle(this.elementRef.nativeElement, 'height', `${this.height()}px`);
                this.renderer.appendChild(this.elementRef.nativeElement, this.currentArrowSvgElement());
            });
        });
    }
    /** @ignore */
    onContentPositionAndArrowDimensionsChangeEffect() {
        effect(() => {
            const position = this.position();
            const arrowDimensions = { width: this.width(), height: this.height() };
            untracked(() => {
                if (!position) {
                    return;
                }
                this.setPosition(position, arrowDimensions);
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverArrowDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxPopoverArrowDirective, isStandalone: true, selector: "[rdxPopoverArrow]", inputs: { width: { classPropertyName: "width", publicName: "width", isSignal: true, isRequired: false, transformFunction: null }, height: { classPropertyName: "height", publicName: "height", isSignal: true, isRequired: false, transformFunction: null } }, providers: [
            {
                provide: RdxPopoverArrowToken,
                useExisting: forwardRef(() => RdxPopoverArrowDirective)
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverArrowDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverArrow]',
                    providers: [
                        {
                            provide: RdxPopoverArrowToken,
                            useExisting: forwardRef(() => RdxPopoverArrowDirective)
                        }
                    ]
                }]
        }], ctorParameters: () => [] });

class RdxPopoverCloseDirective {
    constructor() {
        /** @ignore */
        this.popoverRoot = injectPopoverRoot();
        /** @ignore */
        this.elementRef = inject(ElementRef);
        /** @ignore */
        this.renderer = inject(Renderer2);
        this.onIsControlledExternallyEffect();
    }
    /** @ignore */
    onIsControlledExternallyEffect() {
        effect(() => {
            const isControlledExternally = this.popoverRoot.controlledExternally()();
            untracked(() => {
                this.renderer.setStyle(this.elementRef.nativeElement, 'display', isControlledExternally ? 'none' : null);
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverCloseDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxPopoverCloseDirective, isStandalone: true, selector: "[rdxPopoverClose]", host: { attributes: { "type": "button" }, listeners: { "click": "popoverRoot.handleClose()" } }, providers: [
            {
                provide: RdxPopoverCloseToken,
                useExisting: forwardRef(() => RdxPopoverCloseDirective)
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverCloseDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxPopoverClose]',
                    host: {
                        type: 'button',
                        '(click)': 'popoverRoot.handleClose()'
                    },
                    providers: [
                        {
                            provide: RdxPopoverCloseToken,
                            useExisting: forwardRef(() => RdxPopoverCloseDirective)
                        }
                    ]
                }]
        }], ctorParameters: () => [] });

class RdxPopoverContentAttributesComponent {
    constructor() {
        /** @ignore */
        this.focusTrapDirective = inject(CdkTrapFocus, { self: true });
        /** @ignore */
        this.popoverRoot = injectPopoverRoot();
        /** @ignore */
        this.name = computed(() => `rdx-popover-content-attributes-${this.popoverRoot.uniqueId()}`);
        /** @ignore */
        this.disableAnimation = computed(() => !this.canAnimate());
        afterNextRender({
            write: () => {
                if (this.focusInitialDirective) {
                    return this.focusInitialDirective.focus();
                }
                this.focusTrapDirective.focusTrap.focusFirstTabbableElement();
            }
        });
    }
    /** @ignore */
    onAnimationStart(_) {
        this.popoverRoot.cssAnimationStatus.set(this.popoverRoot.state() === RdxPopoverState.OPEN
            ? RdxPopoverAnimationStatus.OPEN_STARTED
            : RdxPopoverAnimationStatus.CLOSED_STARTED);
    }
    /** @ignore */
    onAnimationEnd(_) {
        this.popoverRoot.cssAnimationStatus.set(this.popoverRoot.state() === RdxPopoverState.OPEN
            ? RdxPopoverAnimationStatus.OPEN_ENDED
            : RdxPopoverAnimationStatus.CLOSED_ENDED);
    }
    /** @ignore */
    canAnimate() {
        return (this.popoverRoot.cssAnimation() &&
            ((this.popoverRoot.cssOpeningAnimation() && this.popoverRoot.state() === RdxPopoverState.OPEN) ||
                (this.popoverRoot.cssClosingAnimation() && this.popoverRoot.state() === RdxPopoverState.CLOSED)));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverContentAttributesComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.4", type: RdxPopoverContentAttributesComponent, isStandalone: true, selector: "[rdxPopoverContentAttributes]", host: { listeners: { "animationstart": "onAnimationStart($event)", "animationend": "onAnimationEnd($event)" }, properties: { "attr.role": "\"dialog\"", "attr.id": "name()", "attr.data-state": "popoverRoot.state()", "attr.data-side": "popoverRoot.popoverContentDirective().side()", "attr.data-align": "popoverRoot.popoverContentDirective().align()", "style": "disableAnimation() ? {animation: \"none !important\"} : null" } }, providers: [
            {
                provide: RdxPopoverContentAttributesToken,
                useExisting: forwardRef(() => RdxPopoverContentAttributesComponent)
            }
        ], queries: [{ propertyName: "focusInitialDirective", first: true, predicate: RdxFocusInitialDirective, descendants: true }], hostDirectives: [{ directive: i1$1.CdkTrapFocus }], ngImport: i0, template: `
        <ng-content />
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverContentAttributesComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[rdxPopoverContentAttributes]',
                    template: `
        <ng-content />
    `,
                    host: {
                        '[attr.role]': '"dialog"',
                        '[attr.id]': 'name()',
                        '[attr.data-state]': 'popoverRoot.state()',
                        '[attr.data-side]': 'popoverRoot.popoverContentDirective().side()',
                        '[attr.data-align]': 'popoverRoot.popoverContentDirective().align()',
                        '[style]': 'disableAnimation() ? {animation: "none !important"} : null',
                        '(animationstart)': 'onAnimationStart($event)',
                        '(animationend)': 'onAnimationEnd($event)'
                    },
                    hostDirectives: [CdkTrapFocus],
                    providers: [
                        {
                            provide: RdxPopoverContentAttributesToken,
                            useExisting: forwardRef(() => RdxPopoverContentAttributesComponent)
                        }
                    ],
                    changeDetection: ChangeDetectionStrategy.OnPush
                }]
        }], ctorParameters: () => [], propDecorators: { focusInitialDirective: [{
                type: ContentChild,
                args: [RdxFocusInitialDirective, { descendants: true }]
            }] } });

const _imports = [
    RdxPopoverArrowDirective,
    RdxPopoverCloseDirective,
    RdxPopoverContentDirective,
    RdxPopoverTriggerDirective,
    RdxPopoverRootDirective,
    RdxPopoverAnchorDirective,
    RdxPopoverContentAttributesComponent
];
class RdxPopoverModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverModule, imports: [RdxPopoverArrowDirective,
            RdxPopoverCloseDirective,
            RdxPopoverContentDirective,
            RdxPopoverTriggerDirective,
            RdxPopoverRootDirective,
            RdxPopoverAnchorDirective,
            RdxPopoverContentAttributesComponent], exports: [RdxPopoverArrowDirective,
            RdxPopoverCloseDirective,
            RdxPopoverContentDirective,
            RdxPopoverTriggerDirective,
            RdxPopoverRootDirective,
            RdxPopoverAnchorDirective,
            RdxPopoverContentAttributesComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxPopoverModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxPopoverAnchorDirective, RdxPopoverArrowDirective, RdxPopoverCloseDirective, RdxPopoverContentAttributesComponent, RdxPopoverContentDirective, RdxPopoverModule, RdxPopoverRootDirective, RdxPopoverTriggerDirective };
//# sourceMappingURL=radix-ng-primitives-popover.mjs.map
