import * as i0 from '@angular/core';
import { InjectionToken, model, input, booleanAttribute, output, signal, computed, Input, Directive, inject, ElementRef } from '@angular/core';
import { provideValueAccessor, provideToken } from '@radix-ng/primitives/core';
import * as i1 from '@radix-ng/primitives/roving-focus';
import { RdxRovingFocusGroupDirective, RdxRovingFocusItemDirective } from '@radix-ng/primitives/roving-focus';
import * as i1$1 from '@radix-ng/primitives/visually-hidden';
import { RdxVisuallyHiddenDirective } from '@radix-ng/primitives/visually-hidden';

const RDX_RADIO_GROUP = new InjectionToken('RdxRadioGroup');

class RdxRadioGroupDirective {
    constructor() {
        this.value = model(null);
        this.disabled = input(false, { transform: booleanAttribute });
        this.required = input(false, { transform: booleanAttribute });
        this.orientation = input();
        /**
         * Event handler called when the value changes.
         */
        this.onValueChange = output();
        this.disable = signal(this.disabled());
        this.disableState = computed(() => this.disable() || this.disabled());
        /**
         * The callback function to call when the value of the radio group changes.
         */
        this.onChange = () => {
            /* Empty */
        };
        /**
         * The callback function to call when the radio group is touched.
         * @ignore
         */
        this.onTouched = () => {
            /* Empty */
        };
    }
    /**
     * Select a radio item.
     * @param value The value of the radio item to select.
     * @ignore
     */
    select(value) {
        this.value.set(value);
        this.onValueChange.emit(value);
        this.onChange?.(value);
        this.onTouched();
    }
    /**
     * Update the value of the radio group.
     * @param value The new value of the radio group.
     * @ignore
     */
    writeValue(value) {
        this.value.set(value);
    }
    /**
     * Register a callback function to call when the value of the radio group changes.
     * @param fn The callback function to call when the value of the radio group changes.
     * @ignore
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /** @ignore */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Set the disabled state of the radio group.
     * @param isDisabled Whether the radio group is disabled.
     * @ignore
     */
    setDisabledState(isDisabled) {
        this.disable.set(isDisabled);
    }
    onKeydown() {
        if (this.disableState())
            return;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioGroupDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxRadioGroupDirective, isStandalone: true, selector: "[rdxRadioRoot]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, defaultValue: { classPropertyName: "defaultValue", publicName: "defaultValue", isSignal: false, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, orientation: { classPropertyName: "orientation", publicName: "orientation", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { attributes: { "role": "radiogroup" }, listeners: { "keydown": "onKeydown()" }, properties: { "attr.aria-orientation": "orientation()", "attr.aria-required": "required()", "attr.data-disabled": "disableState() ? \"\" : null" } }, providers: [
            provideValueAccessor(RdxRadioGroupDirective),
            { provide: RDX_RADIO_GROUP, useExisting: RdxRadioGroupDirective }
        ], exportAs: ["rdxRadioRoot"], hostDirectives: [{ directive: i1.RdxRovingFocusGroupDirective, inputs: ["dir", "dir", "orientation", "orientation", "loop", "loop"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioGroupDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxRadioRoot]',
                    exportAs: 'rdxRadioRoot',
                    providers: [
                        provideValueAccessor(RdxRadioGroupDirective),
                        { provide: RDX_RADIO_GROUP, useExisting: RdxRadioGroupDirective }
                    ],
                    hostDirectives: [{ directive: RdxRovingFocusGroupDirective, inputs: ['dir', 'orientation', 'loop'] }],
                    host: {
                        role: 'radiogroup',
                        '[attr.aria-orientation]': 'orientation()',
                        '[attr.aria-required]': 'required()',
                        '[attr.data-disabled]': 'disableState() ? "" : null',
                        '(keydown)': 'onKeydown()'
                    }
                }]
        }], propDecorators: { defaultValue: [{
                type: Input
            }] } });

const RdxRadioItemToken = new InjectionToken('RadioItemToken');
function injectRadioItem() {
    return inject(RdxRadioItemToken);
}
class RdxRadioItemDirective {
    constructor() {
        this.radioGroup = inject(RDX_RADIO_GROUP);
        this.elementRef = inject(ElementRef);
        this.value = input.required();
        this.id = input();
        this.required = input();
        this.disabled = input(false, { transform: booleanAttribute });
        this.disabledState = computed(() => this.radioGroup.disableState() || this.disabled());
        this.checkedState = computed(() => this.radioGroup.value() === this.value());
        this.ARROW_KEYS = ['ArrowUp', 'ArrowDown', 'ArrowLeft', 'ArrowRight'];
        this.isArrowKeyPressedSignal = signal(false);
    }
    /** @ignore */
    ngOnInit() {
        if (this.radioGroup.defaultValue === this.value()) {
            this.radioGroup.select(this.value());
        }
    }
    /** @ignore */
    onClick() {
        if (!this.disabledState()) {
            this.radioGroup.select(this.value());
            this.isArrowKeyPressedSignal.set(true);
        }
    }
    /** @ignore */
    onKeyDown(event) {
        if (this.ARROW_KEYS.includes(event.key)) {
            this.isArrowKeyPressedSignal.set(true);
        }
    }
    /** @ignore */
    onKeyUp() {
        this.isArrowKeyPressedSignal.set(false);
    }
    /** @ignore */
    onFocus() {
        this.radioGroup.select(this.value());
        setTimeout(() => {
            /**
             * When navigating with arrow keys, focus triggers on the radio item.
             * To "check" the radio, we programmatically trigger a click event.
             */
            if (this.isArrowKeyPressedSignal()) {
                this.elementRef.nativeElement.click();
            }
        }, 0);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxRadioItemDirective, isStandalone: true, selector: "[rdxRadioItem]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null }, id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "type": "button", "role": "radio" }, listeners: { "click": "onClick()", "keydown": "onKeyDown($event)", "keyup": "onKeyUp()", "focus": "onFocus()" }, properties: { "attr.aria-checked": "checkedState()", "attr.data-disabled": "disabledState() ? \"\" : null", "attr.data-state": "checkedState() ? \"checked\" : \"unchecked\"", "disabled": "disabledState()" } }, providers: [provideToken(RdxRadioItemToken, RdxRadioItemDirective)], exportAs: ["rdxRadioItem"], hostDirectives: [{ directive: i1.RdxRovingFocusItemDirective, inputs: ["tabStopId", "id", "focusable", "focusable", "active", "active", "allowShiftKey", "allowShiftKey"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxRadioItem]',
                    exportAs: 'rdxRadioItem',
                    providers: [provideToken(RdxRadioItemToken, RdxRadioItemDirective)],
                    hostDirectives: [
                        { directive: RdxRovingFocusItemDirective, inputs: ['tabStopId: id', 'focusable', 'active', 'allowShiftKey'] }
                    ],
                    host: {
                        type: 'button',
                        role: 'radio',
                        '[attr.aria-checked]': 'checkedState()',
                        '[attr.data-disabled]': 'disabledState() ? "" : null',
                        '[attr.data-state]': 'checkedState() ? "checked" : "unchecked"',
                        '[disabled]': 'disabledState()',
                        '(click)': 'onClick()',
                        '(keydown)': 'onKeyDown($event)',
                        '(keyup)': 'onKeyUp()',
                        '(focus)': 'onFocus()'
                    }
                }]
        }] });

class RdxRadioIndicatorDirective {
    constructor() {
        this.radioGroup = inject(RDX_RADIO_GROUP);
        this.radioItem = inject(RdxRadioItemDirective);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioIndicatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxRadioIndicatorDirective, isStandalone: true, selector: "[rdxRadioIndicator]", host: { properties: { "attr.data-state": "radioItem.checkedState() ? \"checked\" : \"unchecked\"", "attr.data-disabled": "radioItem.disabled() ? \"\" : undefined" } }, exportAs: ["rdxRadioIndicator"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioIndicatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxRadioIndicator]',
                    exportAs: 'rdxRadioIndicator',
                    host: {
                        '[attr.data-state]': 'radioItem.checkedState() ? "checked" : "unchecked"',
                        '[attr.data-disabled]': 'radioItem.disabled() ? "" : undefined'
                    }
                }]
        }] });

class RdxRadioItemInputDirective {
    constructor() {
        this.radioItem = injectRadioItem();
        this.name = input();
        this.value = computed(() => this.radioItem.value() || undefined);
        this.checked = computed(() => this.radioItem.checkedState() || undefined);
        this.required = input(this.radioItem.required());
        this.disabled = input(this.radioItem.disabled());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioItemInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxRadioItemInputDirective, isStandalone: true, selector: "[rdxRadioItemInput]", inputs: { name: { classPropertyName: "name", publicName: "name", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "type": "radio" }, properties: { "attr.name": "name()", "attr.required": "required()", "attr.disabled": "disabled() ? disabled() : undefined", "attr.checked": "checked()", "value": "value()" } }, exportAs: ["rdxRadioItemInput"], hostDirectives: [{ directive: i1$1.RdxVisuallyHiddenDirective, inputs: ["feature", "feature"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxRadioItemInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxRadioItemInput]',
                    exportAs: 'rdxRadioItemInput',
                    hostDirectives: [{ directive: RdxVisuallyHiddenDirective, inputs: ['feature'] }],
                    host: {
                        type: 'radio',
                        '[attr.name]': 'name()',
                        '[attr.required]': 'required()',
                        '[attr.disabled]': 'disabled() ? disabled() : undefined',
                        '[attr.checked]': 'checked()',
                        '[value]': 'value()'
                    }
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxRadioGroupDirective, RdxRadioIndicatorDirective, RdxRadioItemDirective, RdxRadioItemInputDirective, RdxRadioItemToken, injectRadioItem };
//# sourceMappingURL=radix-ng-primitives-radio.mjs.map
