import * as i0 from '@angular/core';
import { input, booleanAttribute, linkedSignal, computed, Directive } from '@angular/core';

const DEFAULT_ORIENTATION = 'horizontal';
// eslint-disable-next-line @typescript-eslint/no-unused-vars
const ORIENTATIONS = ['horizontal', 'vertical'];
/**
 * Directive that adds accessible and configurable separator element to the DOM.
 * This can be either horizontal or vertical and optionally decorative (which removes
 * it from the accessibility tree).
 *
 * @group Components
 */
class RdxSeparatorRootDirective {
    constructor() {
        /**
         * Orientation of the separator, can be either 'horizontal' or 'vertical'.
         *
         * @defaultValue 'horizontal'
         * @group Props
         */
        this.orientation = input(DEFAULT_ORIENTATION);
        /**
         * If true, the separator will be considered decorative and removed from
         * the accessibility tree. Defaults to false.
         *
         * @defaultValue false
         * @group Props
         */
        this.decorative = input(false, { transform: booleanAttribute });
        /**
         * Computes the `role` attribute for the separator. If `decorative` is true,
         * the role is set to "none", otherwise it is "separator".
         *
         * @ignore
         */
        this.decorativeEffect = linkedSignal({
            source: this.decorative,
            computation: (value) => value
        });
        this.orientationEffect = linkedSignal({
            source: this.orientation,
            computation: (value) => value
        });
        /**
         * Computes the `aria-orientation` attribute. It is set to "vertical" only if
         * the separator is not decorative and the orientation is set to "vertical".
         * For horizontal orientation, the attribute is omitted.
         *
         * @ignore
         */
        this.computedAriaOrientation = computed(() => !this.decorativeEffect() && this.orientationEffect() === 'vertical' ? 'vertical' : undefined);
    }
    updateOrientation(value) {
        this.orientationEffect.set(value);
    }
    updateDecorative(value) {
        this.decorativeEffect.set(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSeparatorRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxSeparatorRootDirective, isStandalone: true, selector: "div[rdxSeparatorRoot]", inputs: { orientation: { classPropertyName: "orientation", publicName: "orientation", isSignal: true, isRequired: false, transformFunction: null }, decorative: { classPropertyName: "decorative", publicName: "decorative", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.role": "decorativeEffect() ? \"none\" : \"separator\"", "attr.aria-orientation": "computedAriaOrientation()", "attr.data-orientation": "orientationEffect()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSeparatorRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'div[rdxSeparatorRoot]',
                    host: {
                        '[attr.role]': 'decorativeEffect() ? "none" : "separator"',
                        '[attr.aria-orientation]': 'computedAriaOrientation()',
                        '[attr.data-orientation]': 'orientationEffect()'
                    }
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxSeparatorRootDirective };
//# sourceMappingURL=radix-ng-primitives-separator.mjs.map
