import * as i0 from '@angular/core';
import { InjectionToken, inject, Directive, input, numberAttribute, booleanAttribute, computed, forwardRef, model, output, signal, effect, ElementRef, NgModule } from '@angular/core';
import * as kbd from '@radix-ng/primitives/core';
import { _IdGenerator, useArrowNavigation, getActiveElement } from '@radix-ng/primitives/core';
import { LiveAnnouncer } from '@angular/cdk/a11y';
import * as i1 from '@radix-ng/primitives/separator';
import { RdxSeparatorRootDirective } from '@radix-ng/primitives/separator';

const STEPPER_ITEM_CONTEXT = new InjectionToken('StepperItemContext');
function injectStepperItemContext() {
    return inject(STEPPER_ITEM_CONTEXT);
}

class RdxStepperDescriptionDirective {
    constructor() {
        this.itemContext = injectStepperItemContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperDescriptionDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxStepperDescriptionDirective, isStandalone: true, selector: "[rdxStepperDescription]", host: { properties: { "attr.id": "itemContext.descriptionId" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperDescriptionDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperDescription]',
                    host: {
                        '[attr.id]': 'itemContext.descriptionId'
                    }
                }]
        }] });

class RdxStepperIndicatorDirective {
    constructor() {
        this.itemContext = injectStepperItemContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperIndicatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxStepperIndicatorDirective, isStandalone: true, selector: "[rdxStepperIndicator]", exportAs: ["rdxStepperIndicator"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperIndicatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperIndicator]',
                    exportAs: 'rdxStepperIndicator'
                }]
        }] });

const STEPPER_ROOT_CONTEXT = new InjectionToken('StepperRootContext');
function injectStepperRootContext() {
    return inject(STEPPER_ROOT_CONTEXT);
}

class RdxStepperItemDirective {
    constructor() {
        this.rootContext = injectStepperRootContext();
        /** @ignore */
        this.titleId = inject(_IdGenerator).getId('rdx-stepper-item-title');
        /** @ignore */
        this.descriptionId = inject(_IdGenerator).getId('rdx-stepper-item-description');
        this.step = input(NaN, { transform: numberAttribute });
        this.disabled = input(false, { transform: booleanAttribute });
        /** @ignore */
        this.completed = input(false, { transform: booleanAttribute });
        /** @ignore */
        this.itemState = computed(() => {
            if (this.completed())
                return 'completed';
            if (this.rootContext.value() === this.step())
                return 'active';
            const step = this.step() ?? 1;
            if (this.rootContext.value() > step) {
                return 'completed';
            }
            return 'inactive';
        });
        /** @ignore */
        this.isFocusable = computed(() => {
            if (this.disabled())
                return false;
            const step = this.step() ?? 1;
            if (this.rootContext.linear()) {
                return step <= this.rootContext.value() || step === this.rootContext.value() + 1;
            }
            return true;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxStepperItemDirective, isStandalone: true, selector: "[rdxStepperItem]", inputs: { step: { classPropertyName: "step", publicName: "step", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, completed: { classPropertyName: "completed", publicName: "completed", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.aria-current": "itemState() === \"active\" ? true : undefined", "attr.data-state": "itemState()", "attr.disabled": "disabled() || !isFocusable() ? \"\" : undefined", "attr.data-disabled": "disabled() || !isFocusable() ? \"\" : undefined", "attr.data-orientation": "rootContext.orientation()" } }, providers: [
            {
                provide: STEPPER_ITEM_CONTEXT,
                useExisting: forwardRef(() => RdxStepperItemDirective)
            }
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperItem]',
                    providers: [
                        {
                            provide: STEPPER_ITEM_CONTEXT,
                            useExisting: forwardRef(() => RdxStepperItemDirective)
                        }
                    ],
                    host: {
                        '[attr.aria-current]': 'itemState() === "active" ? true : undefined',
                        '[attr.data-state]': 'itemState()',
                        '[attr.disabled]': 'disabled() || !isFocusable() ? "" : undefined',
                        '[attr.data-disabled]': 'disabled() || !isFocusable() ? "" : undefined',
                        '[attr.data-orientation]': 'rootContext.orientation()'
                    }
                }]
        }] });

class RdxStepperRootDirective {
    constructor() {
        this.liveAnnouncer = inject(LiveAnnouncer);
        this.defaultValue = input(undefined, { transform: numberAttribute });
        this.value = model(this.defaultValue());
        this.linear = input(true, { transform: booleanAttribute });
        this.dir = input('ltr');
        this.orientation = input('horizontal');
        /** @ignore */
        this.totalStepperItemsArray = computed(() => Array.from(this.totalStepperItems()));
        this.onValueChange = output();
        /** @ignore */
        this.isFirstStep = computed(() => this.value() === 1);
        /** @ignore */
        this.isLastStep = computed(() => this.value() === this.totalStepperItemsArray().length);
        /** @ignore */
        this.totalSteps = computed(() => this.totalStepperItems().length);
        /** @ignore */
        this.isNextDisabled = computed(() => {
            const item = this.nextStepperItem();
            return item ? item.hasAttribute('disabled') : true;
        });
        /** @ignore */
        this.isPrevDisabled = computed(() => {
            const item = this.prevStepperItem();
            return item ? item.hasAttribute('disabled') : true;
        });
        /** @ignore */
        this.totalStepperItems = signal([]);
        this.nextStepperItem = signal(null);
        this.prevStepperItem = signal(null);
        effect(() => {
            const items = this.totalStepperItemsArray();
            const currentValue = this.value();
            if (currentValue) {
                if (items.length && currentValue < items.length) {
                    this.nextStepperItem.set(items[currentValue]);
                }
                else {
                    this.nextStepperItem.set(null);
                }
                if (items.length && currentValue > 1) {
                    this.prevStepperItem.set(items[currentValue - 2]);
                }
                else {
                    this.prevStepperItem.set(null);
                }
                this.onValueChange.emit(currentValue);
                this.liveAnnouncer.announce(`Step ${currentValue} of ${items.length}`);
            }
        });
    }
    goToStep(step) {
        if (step > this.totalSteps()) {
            return;
        }
        if (step < 1) {
            return;
        }
        if (this.totalStepperItems().length &&
            !!this.totalStepperItemsArray()[step] &&
            this.totalStepperItemsArray()[step].hasAttribute('disabled')) {
            return;
        }
        if (this.linear()) {
            const currentValue = this.value() ?? 1;
            if (step > currentValue + 1) {
                return;
            }
        }
        this.value.set(step);
        this.onValueChange.emit(step);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxStepperRootDirective, isStandalone: true, selector: "[rdxStepperRoot]", inputs: { defaultValue: { classPropertyName: "defaultValue", publicName: "defaultValue", isSignal: true, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, linear: { classPropertyName: "linear", publicName: "linear", isSignal: true, isRequired: false, transformFunction: null }, dir: { classPropertyName: "dir", publicName: "dir", isSignal: true, isRequired: false, transformFunction: null }, orientation: { classPropertyName: "orientation", publicName: "orientation", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { attributes: { "role": "group" }, properties: { "attr.aria-label": "\"progress\"", "attr.data-linear": "linear() ? \"\" : undefined", "attr.data-orientation": "orientation()" } }, providers: [
            {
                provide: STEPPER_ROOT_CONTEXT,
                useExisting: forwardRef(() => RdxStepperRootDirective)
            }
        ], exportAs: ["rdxStepperRoot"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperRoot]',
                    exportAs: 'rdxStepperRoot',
                    providers: [
                        {
                            provide: STEPPER_ROOT_CONTEXT,
                            useExisting: forwardRef(() => RdxStepperRootDirective)
                        }
                    ],
                    host: {
                        role: 'group',
                        '[attr.aria-label]': '"progress"',
                        '[attr.data-linear]': 'linear() ? "" : undefined',
                        '[attr.data-orientation]': 'orientation()'
                    }
                }]
        }], ctorParameters: () => [] });

class RdxStepperSeparatorDirective {
    constructor() {
        this.rootContext = injectStepperRootContext();
        this.itemContext = injectStepperItemContext();
        this.rdxSeparator = inject(RdxSeparatorRootDirective, { host: true });
        effect(() => {
            this.rdxSeparator.updateDecorative(true);
            this.rdxSeparator.updateOrientation(this.rootContext.orientation());
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperSeparatorDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxStepperSeparatorDirective, isStandalone: true, selector: "[rdxStepperSeparator]", host: { properties: { "attr.data-state": "itemContext.itemState()" } }, hostDirectives: [{ directive: i1.RdxSeparatorRootDirective, inputs: ["orientation", "orientation", "decorative", "decorative"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperSeparatorDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperSeparator]',
                    hostDirectives: [{ directive: RdxSeparatorRootDirective, inputs: ['orientation', 'decorative'] }],
                    host: {
                        '[attr.data-state]': 'itemContext.itemState()'
                    }
                }]
        }], ctorParameters: () => [] });

class RdxStepperTitleDirective {
    constructor() {
        this.itemContext = injectStepperItemContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxStepperTitleDirective, isStandalone: true, selector: "[rdxStepperTitle]", host: { properties: { "attr.id": "itemContext.titleId" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxStepperTitle]',
                    host: {
                        '[attr.id]': 'itemContext.titleId'
                    }
                }]
        }] });

// as button
class RdxStepperTriggerDirective {
    constructor() {
        this.rootContext = injectStepperRootContext();
        this.itemContext = injectStepperItemContext();
        this.elementRef = inject(ElementRef);
        this.stepperItems = computed(() => Array.from(this.rootContext.totalStepperItems()));
    }
    ngOnInit() {
        const current = this.rootContext.totalStepperItems();
        this.rootContext.totalStepperItems.set([...current, this.elementRef.nativeElement]);
    }
    ngOnDestroy() {
        const current = this.rootContext.totalStepperItems();
        const updated = current.filter((el) => el !== this.elementRef.nativeElement);
        this.rootContext.totalStepperItems.set(updated);
    }
    handleMouseDown(event) {
        if (this.itemContext.disabled()) {
            return;
        }
        // handler only left mouse click
        if (event.button !== 0) {
            return;
        }
        if (this.rootContext.linear()) {
            if (this.itemContext.step() <= this.rootContext.value() ||
                this.itemContext.step() === this.rootContext.value() + 1) {
                if (!event.ctrlKey) {
                    this.rootContext.value.set(this.itemContext.step());
                    return;
                }
            }
        }
        else {
            if (!event.ctrlKey) {
                this.rootContext.value.set(this.itemContext.step());
                return;
            }
        }
        // prevent focus to avoid accidental activation
        event.preventDefault();
    }
    handleKeyDown(event) {
        event.preventDefault();
        if (this.itemContext.disabled()) {
            return;
        }
        if ((event.key === kbd.ENTER || event.key === kbd.SPACE) && !event.ctrlKey && !event.shiftKey)
            this.rootContext.value.set(this.itemContext.step());
        if ([kbd.ARROW_LEFT, kbd.ARROW_RIGHT, kbd.ARROW_UP, kbd.ARROW_DOWN].includes(event.key)) {
            useArrowNavigation(event, getActiveElement(), undefined, {
                itemsArray: this.stepperItems(),
                focus: true,
                loop: false,
                arrowKeyOptions: this.rootContext.orientation(),
                dir: this.rootContext.dir()
            });
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxStepperTriggerDirective, isStandalone: true, selector: "button[rdxStepperTrigger]", host: { listeners: { "mousedown": "handleMouseDown($event)", "keydown.Enter": "handleKeyDown($event)", "keydown.Space": "handleKeyDown($event)", "keydown.ArrowLeft": "handleKeyDown($event)", "keydown.ArrowRight": "handleKeyDown($event)", "keydown.ArrowUp": "handleKeyDown($event)", "keydown.ArrowDown": "handleKeyDown($event)" }, properties: { "attr.tabindex": "itemContext.isFocusable() ? 0 : -1", "attr.aria-describedby": "itemContext.descriptionId", "attr.aria-labelledby": "itemContext.titleId", "attr.data-state": "itemContext.itemState()", "attr.data-orientation": "rootContext.orientation()", "attr.disabled": "itemContext.disabled() || !itemContext.isFocusable() ? \"\" : undefined", "attr.data-disabled": "itemContext.disabled() || !itemContext.isFocusable() ? \"\" : undefined" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'button[rdxStepperTrigger]',
                    host: {
                        '[attr.tabindex]': 'itemContext.isFocusable() ? 0 : -1',
                        '[attr.aria-describedby]': 'itemContext.descriptionId',
                        '[attr.aria-labelledby]': 'itemContext.titleId',
                        '[attr.data-state]': 'itemContext.itemState()',
                        '[attr.data-orientation]': 'rootContext.orientation()',
                        '[attr.disabled]': 'itemContext.disabled() || !itemContext.isFocusable() ? "" : undefined',
                        '[attr.data-disabled]': 'itemContext.disabled() || !itemContext.isFocusable() ? "" : undefined',
                        '(mousedown)': 'handleMouseDown($event)',
                        '(keydown.Enter)': 'handleKeyDown($event)',
                        '(keydown.Space)': 'handleKeyDown($event)',
                        '(keydown.ArrowLeft)': 'handleKeyDown($event)',
                        '(keydown.ArrowRight)': 'handleKeyDown($event)',
                        '(keydown.ArrowUp)': 'handleKeyDown($event)',
                        '(keydown.ArrowDown)': 'handleKeyDown($event)'
                    }
                }]
        }] });

const _imports = [
    RdxStepperDescriptionDirective,
    RdxStepperTitleDirective,
    RdxStepperSeparatorDirective,
    RdxStepperItemDirective,
    RdxStepperIndicatorDirective,
    RdxStepperRootDirective,
    RdxStepperTriggerDirective
];
class RdxStepperModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperModule, imports: [RdxStepperDescriptionDirective,
            RdxStepperTitleDirective,
            RdxStepperSeparatorDirective,
            RdxStepperItemDirective,
            RdxStepperIndicatorDirective,
            RdxStepperRootDirective,
            RdxStepperTriggerDirective], exports: [RdxStepperDescriptionDirective,
            RdxStepperTitleDirective,
            RdxStepperSeparatorDirective,
            RdxStepperItemDirective,
            RdxStepperIndicatorDirective,
            RdxStepperRootDirective,
            RdxStepperTriggerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxStepperModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [..._imports],
                    exports: [..._imports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxStepperDescriptionDirective, RdxStepperIndicatorDirective, RdxStepperItemDirective, RdxStepperModule, RdxStepperRootDirective, RdxStepperSeparatorDirective, RdxStepperTitleDirective, RdxStepperTriggerDirective, STEPPER_ROOT_CONTEXT, injectStepperRootContext };
//# sourceMappingURL=radix-ng-primitives-stepper.mjs.map
