import * as i0 from '@angular/core';
import { inject, input, booleanAttribute, model, Directive, NgModule } from '@angular/core';
import { _IdGenerator } from '@angular/cdk/a11y';
import { outputFromObservable, outputToObservable } from '@angular/core/rxjs-interop';
import * as i1 from '@radix-ng/primitives/core';
import { createContext, injectControlValueAccessor, RdxControlValueAccessor } from '@radix-ng/primitives/core';

const [injectSwitchRootContext, provideSwitchRootContext] = createContext('Switch');
const rootContext = () => {
    const instance = inject(RdxSwitchRootDirective);
    const cva = injectControlValueAccessor();
    return {
        required: instance.required,
        value: instance.checked,
        checked: cva.value,
        disabled: cva.disabled,
        ariaLabel: instance.ariaLabel,
        ariaLabelledBy: instance.ariaLabelledBy,
        markAsTouched: () => cva.markAsTouched(),
        toggle: () => instance.toggle()
    };
};
/**
 * @group Components
 */
class RdxSwitchRootDirective {
    constructor() {
        this.cva = injectControlValueAccessor();
        this.id = input(inject(_IdGenerator).getId('rdx-switch-'));
        /**
         * When true, indicates that the user must check the switch before the owning form can be submitted.
         *
         * @default false
         * @group Props
         */
        this.required = input(false, {
            transform: booleanAttribute
        });
        /**
         * Establishes relationships between the component and label(s) where its value should be one or more element IDs.
         * @default null
         * @group Props
         */
        this.ariaLabelledBy = input(undefined, {
            alias: 'aria-labelledby'
        });
        /**
         * Used to define a string that autocomplete attribute the current element.
         * @default null
         * @group Props
         */
        this.ariaLabel = input(undefined, {
            alias: 'aria-label'
        });
        /**
         * The state of the switch when it is initially rendered. Use when you do not need to control its state.
         * @default false
         * @group Props
         */
        this.defaultChecked = input(false, { transform: booleanAttribute });
        /**
         * The controlled state of the switch. Must be used in conjunction with onCheckedChange.
         * @defaultValue false
         * @group Props
         */
        this.checked = model(this.defaultChecked());
        /**
         * When `true`, prevents the user from interacting with the switch.
         * @default false
         * @group Props
         */
        this.disabled = input(false, {
            transform: booleanAttribute
        });
        /**
         * Event handler called when the state of the switch changes.
         *
         * @param {boolean} value - Boolean value indicates that the option is changed.
         * @group Emits
         */
        this.onCheckedChange = outputFromObservable(outputToObservable(this.cva.valueChange));
    }
    /**
     * Toggles the checked state of the switch.
     * If the switch is disabled, the function returns early.
     * @ignore
     */
    toggle() {
        if (!this.disabled()) {
            this.checked.set(!this.checked());
            this.cva.setValue(this.checked());
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxSwitchRootDirective, isStandalone: true, selector: "button[rdxSwitchRoot]", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, ariaLabelledBy: { classPropertyName: "ariaLabelledBy", publicName: "aria-labelledby", isSignal: true, isRequired: false, transformFunction: null }, ariaLabel: { classPropertyName: "ariaLabel", publicName: "aria-label", isSignal: true, isRequired: false, transformFunction: null }, defaultChecked: { classPropertyName: "defaultChecked", publicName: "defaultChecked", isSignal: true, isRequired: false, transformFunction: null }, checked: { classPropertyName: "checked", publicName: "checked", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { checked: "checkedChange", onCheckedChange: "onCheckedChange" }, host: { attributes: { "role": "switch", "type": "button" }, listeners: { "click": "toggle()", "keydown.enter": "$event.preventDefault()" }, properties: { "id": "id()", "attr.aria-checked": "cva.value()", "attr.aria-required": "required()", "attr.data-state": "cva.value() ? \"checked\" : \"unchecked\"", "attr.data-disabled": "cva.disabled() ? \"true\" : undefined", "attr.disabled": "cva.disabled() ? cva.disabled() : undefined", "value": "cva.value()" } }, providers: [provideSwitchRootContext(rootContext)], exportAs: ["rdxSwitchRoot"], hostDirectives: [{ directive: i1.RdxControlValueAccessor, inputs: ["value", "checked", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'button[rdxSwitchRoot]',
                    exportAs: 'rdxSwitchRoot',
                    providers: [provideSwitchRootContext(rootContext)],
                    hostDirectives: [
                        {
                            directive: RdxControlValueAccessor,
                            inputs: ['value: checked', 'disabled']
                        }
                    ],
                    host: {
                        role: 'switch',
                        type: 'button',
                        '[id]': 'id()',
                        '[attr.aria-checked]': 'cva.value()',
                        '[attr.aria-required]': 'required()',
                        '[attr.data-state]': 'cva.value() ? "checked" : "unchecked"',
                        '[attr.data-disabled]': 'cva.disabled() ? "true" : undefined',
                        '[attr.disabled]': 'cva.disabled() ? cva.disabled() : undefined',
                        '[value]': 'cva.value()',
                        '(click)': 'toggle()',
                        '(keydown.enter)': '$event.preventDefault()'
                    }
                }]
        }] });

/**
 * @group Components
 */
class RdxSwitchInputDirective {
    constructor() {
        this.rootContext = injectSwitchRootContext();
    }
    /** @ignore */
    onBlur() {
        this.rootContext?.markAsTouched();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxSwitchInputDirective, isStandalone: true, selector: "input[rdxSwitchInput]", host: { attributes: { "type": "checkbox", "tabindex": "-1" }, listeners: { "blur": "onBlur()" }, properties: { "attr.defaultChecked": "rootContext.checked()", "attr.aria-checked": "rootContext.checked()", "attr.aria-hidden": "true", "attr.aria-label": "rootContext.ariaLabel()", "attr.aria-labelledby": "rootContext.ariaLabelledBy()", "attr.aria-required": "rootContext.required()", "attr.data-state": "rootContext.checked() ? \"checked\" : \"unchecked\"", "attr.data-disabled": "rootContext.disabled() ? \"true\" : null", "attr.disabled": "rootContext.disabled() ? rootContext.disabled() : undefined", "attr.value": "rootContext.checked() ? \"on\" : \"off\"" }, styleAttribute: "transform: translateX(-100%); position: absolute; overflow: hidden; pointerEvents: none; opacity: 0; margin: 0;" }, exportAs: ["rdxSwitchInput"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[rdxSwitchInput]',
                    exportAs: 'rdxSwitchInput',
                    host: {
                        type: 'checkbox',
                        tabindex: '-1',
                        '[attr.defaultChecked]': 'rootContext.checked()',
                        '[attr.aria-checked]': 'rootContext.checked()',
                        '[attr.aria-hidden]': 'true',
                        '[attr.aria-label]': 'rootContext.ariaLabel()',
                        '[attr.aria-labelledby]': 'rootContext.ariaLabelledBy()',
                        '[attr.aria-required]': 'rootContext.required()',
                        '[attr.data-state]': 'rootContext.checked() ? "checked" : "unchecked"',
                        '[attr.data-disabled]': 'rootContext.disabled() ? "true" : null',
                        '[attr.disabled]': 'rootContext.disabled() ? rootContext.disabled() : undefined',
                        '[attr.value]': 'rootContext.checked() ? "on" : "off"',
                        style: 'transform: translateX(-100%); position: absolute; overflow: hidden; pointerEvents: none; opacity: 0; margin: 0;',
                        '(blur)': 'onBlur()'
                    }
                }]
        }] });

/**
 * @group Components
 */
class RdxSwitchThumbDirective {
    constructor() {
        this.rootContext = injectSwitchRootContext();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchThumbDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxSwitchThumbDirective, isStandalone: true, selector: "span[rdxSwitchThumb]", host: { properties: { "attr.data-disabled": "rootContext?.disabled() ? \"\" : undefined", "attr.data-state": "rootContext?.checked() ? \"checked\" : \"unchecked\"" } }, exportAs: ["rdxSwitchThumb"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchThumbDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'span[rdxSwitchThumb]',
                    exportAs: 'rdxSwitchThumb',
                    host: {
                        '[attr.data-disabled]': 'rootContext?.disabled() ? "" : undefined',
                        '[attr.data-state]': 'rootContext?.checked() ? "checked" : "unchecked"'
                    }
                }]
        }] });

const switchImports = [RdxSwitchRootDirective, RdxSwitchInputDirective, RdxSwitchThumbDirective];
class RdxSwitchModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchModule, imports: [RdxSwitchRootDirective, RdxSwitchInputDirective, RdxSwitchThumbDirective], exports: [RdxSwitchRootDirective, RdxSwitchInputDirective, RdxSwitchThumbDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxSwitchModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...switchImports],
                    exports: [...switchImports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxSwitchInputDirective, RdxSwitchModule, RdxSwitchRootDirective, RdxSwitchThumbDirective, injectSwitchRootContext, provideSwitchRootContext };
//# sourceMappingURL=radix-ng-primitives-switch.mjs.map
