import * as i0 from '@angular/core';
import { InjectionToken, model, input, output, Directive, inject, computed, booleanAttribute, effect, NgModule } from '@angular/core';
import { provideToken } from '@radix-ng/primitives/core';
import * as i1 from '@radix-ng/primitives/roving-focus';
import { RdxRovingFocusGroupDirective, RdxRovingFocusItemDirective } from '@radix-ng/primitives/roving-focus';

const RDX_TABS_ROOT_TOKEN = new InjectionToken('RdxTabsRootDirective');
class RdxTabsRootDirective {
    constructor() {
        /**
         * The controlled value of the tab to activate. Should be used in conjunction with `onValueChange`.
         */
        this.value = model();
        this.defaultValue = input();
        /**
         * When automatic, tabs are activated when receiving focus. When manual, tabs are activated when clicked.
         */
        this.activationMode = input('automatic');
        /**
         * The orientation of the component.
         */
        this.orientation = input('horizontal');
        this.dir = input('ltr');
        /**
         * Event handler called when the value changes.
         */
        this.onValueChange = output();
    }
    ngOnInit() {
        if (this.defaultValue()) {
            this.value.set(this.defaultValue());
        }
    }
    select(value) {
        this.value.set(value);
        this.onValueChange.emit(value);
    }
    /** @ignore */
    getBaseId() {
        return `tabs-${Math.random().toString(36).substr(2, 9)}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsRootDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxTabsRootDirective, isStandalone: true, selector: "[rdxTabsRoot]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, defaultValue: { classPropertyName: "defaultValue", publicName: "defaultValue", isSignal: true, isRequired: false, transformFunction: null }, activationMode: { classPropertyName: "activationMode", publicName: "activationMode", isSignal: true, isRequired: false, transformFunction: null }, orientation: { classPropertyName: "orientation", publicName: "orientation", isSignal: true, isRequired: false, transformFunction: null }, dir: { classPropertyName: "dir", publicName: "dir", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { properties: { "attr.data-orientation": "orientation()", "attr.dir": "dir()" } }, providers: [provideToken(RDX_TABS_ROOT_TOKEN, RdxTabsRootDirective)], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsRootDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxTabsRoot]',
                    providers: [provideToken(RDX_TABS_ROOT_TOKEN, RdxTabsRootDirective)],
                    host: {
                        '[attr.data-orientation]': 'orientation()',
                        '[attr.dir]': 'dir()'
                    }
                }]
        }] });

function makeTriggerId(baseId, value) {
    return `${baseId}-trigger-${value}`;
}
function makeContentId(baseId, value) {
    return `${baseId}-content-${value}`;
}

class RdxTabsContentDirective {
    constructor() {
        this.tabsContext = inject(RDX_TABS_ROOT_TOKEN);
        /**
         * A unique value that associates the content with a trigger.
         */
        this.value = input.required();
        this.contentId = computed(() => makeContentId(this.tabsContext.getBaseId(), this.value()));
        this.triggerId = computed(() => makeTriggerId(this.tabsContext.getBaseId(), this.value()));
        this.selected = computed(() => this.tabsContext.value() === this.value());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsContentDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxTabsContentDirective, isStandalone: true, selector: "[rdxTabsContent]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null } }, host: { attributes: { "role": "tabpanel", "tabindex": "0" }, properties: { "id": "contentId()", "attr.aria-labelledby": "triggerId()", "attr.data-state": "selected() ? \"active\" : \"inactive\"", "attr.data-orientation": "tabsContext.orientation()", "hidden": "!selected()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxTabsContent]',
                    host: {
                        role: 'tabpanel',
                        tabindex: '0',
                        '[id]': 'contentId()',
                        '[attr.aria-labelledby]': 'triggerId()',
                        '[attr.data-state]': 'selected() ? "active" : "inactive"',
                        '[attr.data-orientation]': 'tabsContext.orientation()',
                        '[hidden]': '!selected()'
                    }
                }]
        }] });

class RdxTabsListDirective {
    constructor() {
        this.tabsContext = inject(RDX_TABS_ROOT_TOKEN);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsListDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxTabsListDirective, isStandalone: true, selector: "[rdxTabsList]", host: { attributes: { "role": "tablist" }, properties: { "attr.aria-orientation": "tabsContext.orientation()", "attr.data-orientation": "tabsContext.orientation()" } }, hostDirectives: [{ directive: i1.RdxRovingFocusGroupDirective, inputs: ["dir", "dir", "orientation", "orientation", "loop", "loop"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsListDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxTabsList]',
                    hostDirectives: [{ directive: RdxRovingFocusGroupDirective, inputs: ['dir', 'orientation', 'loop'] }],
                    host: {
                        role: 'tablist',
                        '[attr.aria-orientation]': 'tabsContext.orientation()',
                        '[attr.data-orientation]': 'tabsContext.orientation()'
                    }
                }]
        }] });

class RdxTabsTriggerDirective {
    constructor() {
        this.rdxRovingFocusItemDirective = inject(RdxRovingFocusItemDirective);
        this.tabsContext = inject(RDX_TABS_ROOT_TOKEN);
        /**
         * A unique value that associates the trigger with a content.
         */
        this.value = input.required();
        /**
         * When true, prevents the user from interacting with the tab.
         */
        this.disabled = input(false, {
            transform: booleanAttribute
        });
        this.contentId = computed(() => makeContentId(this.tabsContext.getBaseId(), this.value()));
        this.triggerId = computed(() => makeTriggerId(this.tabsContext.getBaseId(), this.value()));
        this.isSelected = computed(() => this.tabsContext.value() === this.value());
        effect(() => (this.rdxRovingFocusItemDirective.active = this.isSelected()));
    }
    onMouseDown(event) {
        // only call handler if it's the left button (mousedown gets triggered by all mouse buttons)
        // but not when the control key is pressed (avoiding MacOS right click)
        if (!this.disabled() && event.button === 0 && !event.ctrlKey) {
            this.tabsContext?.select(this.value());
        }
        else {
            // prevent focus to avoid accidental activation
            event.preventDefault();
        }
    }
    onKeyDown(event) {
        if ([' ', 'Enter'].includes(event.key)) {
            this.tabsContext?.select(this.value());
        }
    }
    onFocus() {
        const isAutomaticActivation = this.tabsContext.activationMode() !== 'manual';
        if (!this.isSelected() && !this.disabled() && isAutomaticActivation) {
            this.tabsContext?.select(this.value());
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsTriggerDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxTabsTriggerDirective, isStandalone: true, selector: "[rdxTabsTrigger]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { attributes: { "type": "button", "role": "tab" }, listeners: { "mousedown": "onMouseDown($event)", "keydown": "onKeyDown($event)", "focus": "onFocus()" }, properties: { "id": "triggerId()", "attr.aria-selected": "isSelected()", "attr.aria-controls": "contentId()", "attr.data-disabled": "disabled() ? '' : undefined", "disabled": "disabled()", "attr.data-state": "isSelected() ? 'active' : 'inactive'", "attr.data-orientation": "tabsContext.orientation()" } }, hostDirectives: [{ directive: i1.RdxRovingFocusItemDirective, inputs: ["focusable", "focusable", "active", "active", "allowShiftKey", "allowShiftKey"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsTriggerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxTabsTrigger]',
                    hostDirectives: [
                        {
                            directive: RdxRovingFocusItemDirective,
                            inputs: ['focusable', 'active', 'allowShiftKey']
                        }
                    ],
                    host: {
                        type: 'button',
                        role: 'tab',
                        '[id]': 'triggerId()',
                        '[attr.aria-selected]': 'isSelected()',
                        '[attr.aria-controls]': 'contentId()',
                        '[attr.data-disabled]': "disabled() ? '' : undefined",
                        '[disabled]': 'disabled()',
                        '[attr.data-state]': "isSelected() ? 'active' : 'inactive'",
                        '[attr.data-orientation]': 'tabsContext.orientation()',
                        '(mousedown)': 'onMouseDown($event)',
                        '(keydown)': 'onKeyDown($event)',
                        '(focus)': 'onFocus()'
                    }
                }]
        }], ctorParameters: () => [] });

const tabsImports = [RdxTabsRootDirective, RdxTabsContentDirective, RdxTabsListDirective, RdxTabsTriggerDirective];
class RdxTabsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsModule, imports: [RdxTabsRootDirective, RdxTabsContentDirective, RdxTabsListDirective, RdxTabsTriggerDirective], exports: [RdxTabsRootDirective, RdxTabsContentDirective, RdxTabsListDirective, RdxTabsTriggerDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxTabsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...tabsImports],
                    exports: [...tabsImports]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RDX_TABS_ROOT_TOKEN, RdxTabsContentDirective, RdxTabsListDirective, RdxTabsModule, RdxTabsRootDirective, RdxTabsTriggerDirective };
//# sourceMappingURL=radix-ng-primitives-tabs.mjs.map
