import * as i0 from '@angular/core';
import { InjectionToken, inject, input, booleanAttribute, computed, effect, Directive, model, output, signal } from '@angular/core';
import * as i1 from '@radix-ng/primitives/roving-focus';
import { RdxRovingFocusItemDirective, RdxRovingFocusGroupDirective } from '@radix-ng/primitives/roving-focus';
import * as i2 from '@radix-ng/primitives/toggle';
import { RdxToggleDirective } from '@radix-ng/primitives/toggle';
import { provideValueAccessor, isEqual, isValueEqualOrExist, provideToken } from '@radix-ng/primitives/core';

const RdxToggleGroupItemToken = new InjectionToken('RdxToggleGroupItemToken');
function injectToggleGroupItem() {
    return inject(RdxToggleGroupItemToken);
}

const RdxToggleGroupToken = new InjectionToken('RdxToggleGroupToken');
function injectToggleGroup() {
    return inject(RdxToggleGroupToken);
}

/**
 * @group Components
 */
class RdxToggleGroupItemDirective {
    constructor() {
        this.rdxToggleDirective = inject(RdxToggleDirective);
        this.rdxRovingFocusItemDirective = inject(RdxRovingFocusItemDirective);
        /**
         * Access the toggle group.
         * @ignore
         */
        this.rootContext = injectToggleGroup();
        /**
         * The value of this toggle button.
         *
         * @group Props
         */
        this.value = input.required();
        /**
         * Whether this toggle button is disabled.
         * @defaultValue false
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        this.isPressed = computed(() => {
            return this.rootContext.type() === 'single'
                ? this.rootContext.value() === this.value()
                : this.rootContext.value()?.includes(this.value());
        });
        this.isDisabled = computed(() => this.rootContext.disabled() || this.rootContext.accessorDisabled() || this.disabled());
        effect(() => {
            this.rdxToggleDirective.cva.writeValue(!!this.isPressed());
            this.rdxToggleDirective.cva.setValue(!!this.isPressed());
            this.rdxToggleDirective.cva.setDisabledState(this.isDisabled());
            this.rdxRovingFocusItemDirective.active = !!this.isPressed();
        });
    }
    /**
     * @ignore
     */
    toggle() {
        if (this.disabled()) {
            return;
        }
        this.rootContext.toggle(this.value());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupItemDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxToggleGroupItemDirective, isStandalone: true, selector: "[rdxToggleGroupItem]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: true, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "click": "toggle()" } }, providers: [{ provide: RdxToggleGroupItemToken, useExisting: RdxToggleGroupItemDirective }], exportAs: ["rdxToggleGroupItem"], hostDirectives: [{ directive: i1.RdxRovingFocusItemDirective, inputs: ["focusable", "focusable", "active", "active", "allowShiftKey", "allowShiftKey"] }, { directive: i2.RdxToggleDirective, inputs: ["pressed", "pressed", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxToggleGroupItem]',
                    exportAs: 'rdxToggleGroupItem',
                    providers: [{ provide: RdxToggleGroupItemToken, useExisting: RdxToggleGroupItemDirective }],
                    hostDirectives: [
                        {
                            directive: RdxRovingFocusItemDirective,
                            inputs: ['focusable', 'active', 'allowShiftKey']
                        },
                        {
                            directive: RdxToggleDirective,
                            inputs: ['pressed', 'disabled']
                        }
                    ],
                    host: {
                        '(click)': 'toggle()'
                    }
                }]
        }], ctorParameters: () => [] });

let nextId$1 = 0;
class RdxToggleGroupWithoutFocusDirective {
    constructor() {
        /**
         * @ignore
         */
        this.id = `rdx-toggle-group-${nextId$1++}`;
        /**
         * @group Props
         */
        this.value = model(undefined);
        /**
         * @group Props
         */
        this.type = input('single');
        /**
         * Whether the toggle group is disabled.
         * @defaultValue false
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        /**
         * Event emitted when the selected toggle button changes.
         * @group Emits
         */
        this.onValueChange = output();
        this.accessorDisabled = signal(false);
    }
    /**
     * Toggle a value.
     * @param value The value to toggle.
     * @ignore
     */
    toggle(value) {
        if (this.disabled()) {
            return;
        }
        if (this.type() === 'single') {
            this.value.set(value);
        }
        else {
            this.value.set(((currentValue) => currentValue && Array.isArray(currentValue)
                ? currentValue.includes(value)
                    ? currentValue.filter((v) => v !== value) // delete
                    : [...currentValue, value] // update
                : [value])(this.value()));
        }
        this.onValueChange.emit(this.value());
        this.onChange?.(this.value());
    }
    /**
     * Select a value from Angular forms.
     * @param value The value to select.
     * @ignore
     */
    writeValue(value) {
        this.value.set(value);
    }
    /**
     * Register a callback to be called when the value changes.
     * @param fn The callback to register.
     * @ignore
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * Register a callback to be called when the toggle group is touched.
     * @param fn The callback to register.
     * @ignore
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Set the disabled state of the toggle group.
     * @param isDisabled Whether the toggle group is disabled.
     * @ignore
     */
    setDisabledState(isDisabled) {
        this.accessorDisabled.set(isDisabled);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupWithoutFocusDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxToggleGroupWithoutFocusDirective, isStandalone: true, selector: "[rdxToggleGroupWithoutFocus]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, type: { classPropertyName: "type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { attributes: { "role": "group" }, listeners: { "focusout": "onTouched?.()" } }, providers: [
            { provide: RdxToggleGroupToken, useExisting: RdxToggleGroupWithoutFocusDirective },
            provideValueAccessor(RdxToggleGroupWithoutFocusDirective)
        ], exportAs: ["rdxToggleGroupWithoutFocus"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupWithoutFocusDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxToggleGroupWithoutFocus]',
                    exportAs: 'rdxToggleGroupWithoutFocus',
                    providers: [
                        { provide: RdxToggleGroupToken, useExisting: RdxToggleGroupWithoutFocusDirective },
                        provideValueAccessor(RdxToggleGroupWithoutFocusDirective)
                    ],
                    host: {
                        role: 'group',
                        '(focusout)': 'onTouched?.()'
                    }
                }]
        }] });

let nextId = 0;
/**
 * @group Components
 */
class RdxToggleGroupDirective {
    constructor() {
        /**
         * @ignore
         */
        this.id = `rdx-toggle-group-${nextId++}`;
        /**
         * @group Props
         */
        this.value = model(undefined);
        /**
         * @group Props
         */
        this.type = input('single');
        /**
         * Whether the toggle group is disabled.
         * @defaultValue false
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        /**
         * Event emitted when the selected toggle button changes.
         * @group Emits
         */
        this.onValueChange = output();
        this.accessorDisabled = signal(false);
    }
    /**
     * Toggle a value.
     * @param value The value to toggle.
     * @ignore
     */
    toggle(value) {
        if (this.disabled()) {
            return;
        }
        if (this.type() === 'single') {
            this.value.set(isEqual(value, this.value()) ? undefined : value);
        }
        else {
            const modelValueArray = Array.isArray(this.value())
                ? [...(this.value() || [])]
                : [this.value()].filter(Boolean);
            if (isValueEqualOrExist(modelValueArray, value)) {
                const index = modelValueArray.findIndex((i) => isEqual(i, value));
                modelValueArray.splice(index, 1);
            }
            else {
                modelValueArray.push(value);
            }
            this.value.set(modelValueArray);
        }
        this.onValueChange.emit(this.value());
        this.onChange?.(this.value());
    }
    /**
     * Select a value from Angular forms.
     * @param value The value to select.
     * @ignore
     */
    writeValue(value) {
        this.value.set(value);
    }
    /**
     * Register a callback to be called when the value changes.
     * @param fn The callback to register.
     * @ignore
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * Register a callback to be called when the toggle group is touched.
     * @param fn The callback to register.
     * @ignore
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Set the disabled state of the toggle group.
     * @param isDisabled Whether the toggle group is disabled.
     * @ignore
     */
    setDisabledState(isDisabled) {
        this.accessorDisabled.set(isDisabled);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxToggleGroupDirective, isStandalone: true, selector: "[rdxToggleGroup]", inputs: { value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, type: { classPropertyName: "type", publicName: "type", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { value: "valueChange", onValueChange: "onValueChange" }, host: { attributes: { "role": "group" }, listeners: { "focusout": "onTouched?.()" } }, providers: [
            provideToken(RdxToggleGroupToken, RdxToggleGroupDirective),
            provideValueAccessor(RdxToggleGroupDirective)
        ], exportAs: ["rdxToggleGroup"], hostDirectives: [{ directive: i1.RdxRovingFocusGroupDirective, inputs: ["dir", "dir", "orientation", "orientation", "loop", "loop"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleGroupDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxToggleGroup]',
                    exportAs: 'rdxToggleGroup',
                    providers: [
                        provideToken(RdxToggleGroupToken, RdxToggleGroupDirective),
                        provideValueAccessor(RdxToggleGroupDirective)
                    ],
                    hostDirectives: [{ directive: RdxRovingFocusGroupDirective, inputs: ['dir', 'orientation', 'loop'] }],
                    host: {
                        role: 'group',
                        '(focusout)': 'onTouched?.()'
                    }
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxToggleGroupDirective, RdxToggleGroupItemDirective, RdxToggleGroupItemToken, RdxToggleGroupToken, RdxToggleGroupWithoutFocusDirective, injectToggleGroup, injectToggleGroupItem };
//# sourceMappingURL=radix-ng-primitives-toggle-group.mjs.map
