import * as i0 from '@angular/core';
import { Directive, inject, input, booleanAttribute, model } from '@angular/core';
import * as i1 from '@radix-ng/primitives/visually-hidden';
import { RdxVisuallyHiddenInputDirective } from '@radix-ng/primitives/visually-hidden';
import { outputFromObservable, outputToObservable } from '@angular/core/rxjs-interop';
import * as i1$1 from '@radix-ng/primitives/core';
import { RdxControlValueAccessor } from '@radix-ng/primitives/core';

class RdxToggleVisuallyHiddenInputDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleVisuallyHiddenInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.4", type: RdxToggleVisuallyHiddenInputDirective, isStandalone: true, selector: "input[rdxToggleVisuallyHiddenInput]", host: { attributes: { "type": "checkbox" } }, exportAs: ["rdxToggleVisuallyHiddenInput"], hostDirectives: [{ directive: i1.RdxVisuallyHiddenInputDirective, inputs: ["name", "name", "required", "required", "value", "value", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleVisuallyHiddenInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[rdxToggleVisuallyHiddenInput]',
                    exportAs: 'rdxToggleVisuallyHiddenInput',
                    hostDirectives: [
                        {
                            directive: RdxVisuallyHiddenInputDirective,
                            inputs: ['name', 'required', 'value', 'disabled']
                        }
                    ],
                    host: {
                        type: 'checkbox'
                    }
                }]
        }] });

/**
 * @group Components
 */
class RdxToggleDirective {
    constructor() {
        /**
         * @ignore
         */
        this.cva = inject(RdxControlValueAccessor);
        /**
         * The pressed state of the toggle when it is initially rendered.
         * Use when you do not need to control its pressed state.
         *
         * @group Props
         */
        this.defaultPressed = input(false, { transform: booleanAttribute });
        /**
         * The controlled pressed state of the toggle.
         * Must be used in conjunction with `onPressedChange`.
         *
         * @group Props
         */
        this.pressed = model(this.defaultPressed());
        /**
         * When true, prevents the user from interacting with the toggle.
         *
         * @group Props
         */
        this.disabled = input(false, { transform: booleanAttribute });
        /**
         * Event handler called when the pressed state of the toggle changes.
         *
         * @group Emits
         */
        this.onPressedChange = outputFromObservable(outputToObservable(this.cva.valueChange));
    }
    onClick() {
        if (!this.disabled()) {
            this.pressed.set(!this.pressed());
            this.cva.writeValue(this.pressed());
            this.cva.setValue(this.pressed());
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxToggleDirective, isStandalone: true, selector: "[rdxToggle]", inputs: { defaultPressed: { classPropertyName: "defaultPressed", publicName: "defaultPressed", isSignal: true, isRequired: false, transformFunction: null }, pressed: { classPropertyName: "pressed", publicName: "pressed", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { pressed: "pressedChange", onPressedChange: "onPressedChange" }, host: { attributes: { "type": "button" }, listeners: { "click": "onClick()" }, properties: { "attr.aria-pressed": "cva.value()", "attr.data-state": "cva.value() ? \"on\" : \"off\"", "attr.data-disabled": "cva.disabled() ? \"\" : undefined", "disabled": "cva.disabled()" } }, exportAs: ["rdxToggle"], hostDirectives: [{ directive: i1$1.RdxControlValueAccessor, inputs: ["value", "pressed", "disabled", "disabled"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxToggleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxToggle]',
                    exportAs: 'rdxToggle',
                    hostDirectives: [
                        {
                            directive: RdxControlValueAccessor,
                            inputs: ['value: pressed', 'disabled']
                        }
                    ],
                    host: {
                        type: 'button',
                        '[attr.aria-pressed]': 'cva.value()',
                        '[attr.data-state]': 'cva.value() ? "on" : "off"',
                        '[attr.data-disabled]': 'cva.disabled() ? "" : undefined',
                        '[disabled]': 'cva.disabled()',
                        '(click)': 'onClick()'
                    }
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxToggleDirective, RdxToggleVisuallyHiddenInputDirective };
//# sourceMappingURL=radix-ng-primitives-toggle.mjs.map
