import * as i0 from '@angular/core';
import { input, linkedSignal, Directive, inject, ElementRef, effect, computed } from '@angular/core';

/**
 *
 * <span rdxVisuallyHidden [feature]="'fully-hidden'">
 *   <ng-content></ng-content>
 * </span>
 *
 * <button (click)="directiveInstance.feature.set('focusable')">Make Focusable</button>
 * <button (click)="directiveInstance.feature.set('fully-hidden')">Hide</button>
 */
class RdxVisuallyHiddenDirective {
    constructor() {
        this.feature = input('focusable');
        this.featureEffect = linkedSignal({
            source: this.feature,
            computation: (feature) => feature
        });
    }
    updateFeature(feature) {
        this.featureEffect.set(feature);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxVisuallyHiddenDirective, isStandalone: true, selector: "[rdxVisuallyHidden]", inputs: { feature: { classPropertyName: "feature", publicName: "feature", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "attr.aria-hidden": "feature() === \"focusable\" ? \"true\" : undefined", "hidden": "feature() === \"fully-hidden\" ? true : undefined", "attr.tabindex": "feature() === \"fully-hidden\" ? \"-1\" : undefined", "style.position": "\"absolute\"", "style.border": "\"0\"", "style.display": "feature() === \"focusable\" ? \"inline-block\" : \"none\"", "style.width": "\"1px\"", "style.height": "\"1px\"", "style.padding": "\"0\"", "style.margin": "\"-1px\"", "style.overflow": "\"hidden\"", "style.clip": "\"rect(0, 0, 0, 0)\"", "style.clipPath": "\"inset(50%)\"", "style.white-space": "\"nowrap\"", "style.word-wrap": "\"normal\"" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxVisuallyHidden]',
                    host: {
                        '[attr.aria-hidden]': 'feature() === "focusable" ? "true" : undefined',
                        '[hidden]': 'feature() === "fully-hidden" ? true : undefined',
                        '[attr.tabindex]': 'feature() === "fully-hidden" ? "-1" : undefined',
                        '[style.position]': '"absolute"',
                        '[style.border]': '"0"',
                        '[style.display]': 'feature() === "focusable" ? "inline-block" : "none"',
                        '[style.width]': '"1px"',
                        '[style.height]': '"1px"',
                        '[style.padding]': '"0"',
                        '[style.margin]': '"-1px"',
                        '[style.overflow]': '"hidden"',
                        '[style.clip]': '"rect(0, 0, 0, 0)"',
                        '[style.clipPath]': '"inset(50%)"',
                        '[style.white-space]': '"nowrap"',
                        '[style.word-wrap]': '"normal"'
                    }
                }]
        }] });

/**
 *
 */
class RdxVisuallyHiddenInputBubbleDirective {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.name = input('');
        this.value = input();
        this.checked = input(undefined);
        this.required = input(undefined);
        this.disabled = input(undefined);
        this.feature = input('fully-hidden');
        this.valueEffect = linkedSignal({
            source: this.value,
            computation: (value) => value
        });
        effect(() => {
            this.updateInputValue();
        });
    }
    updateValue(value) {
        this.valueEffect.set(value);
    }
    onChange() {
        this.updateInputValue();
    }
    updateInputValue() {
        let valueChanged = false;
        let checkedChanged = false;
        // Check if the value has changed before applying the update
        const currentValue = this.inputElement.value;
        const newValue = String(this.value());
        if (currentValue !== newValue) {
            this.inputElement.value = newValue;
            valueChanged = true;
        }
        if (this.inputElement.type === 'checkbox' || this.inputElement.type === 'radio') {
            const currentChecked = this.inputElement.checked;
            const newChecked = !!this.checked();
            if (currentChecked !== newChecked) {
                this.inputElement.checked = newChecked;
                checkedChanged = true;
            }
        }
        if (valueChanged || checkedChanged) {
            this.dispatchInputEvents();
        }
    }
    get inputElement() {
        return this.elementRef.nativeElement;
    }
    dispatchInputEvents() {
        const inputEvent = new Event('input', { bubbles: true });
        const changeEvent = new Event('change', { bubbles: true });
        this.inputElement.dispatchEvent(inputEvent);
        this.inputElement.dispatchEvent(changeEvent);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenInputBubbleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxVisuallyHiddenInputBubbleDirective, isStandalone: true, selector: "input[rdxVisuallyHiddenInputBubble]", inputs: { name: { classPropertyName: "name", publicName: "name", isSignal: true, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, checked: { classPropertyName: "checked", publicName: "checked", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, feature: { classPropertyName: "feature", publicName: "feature", isSignal: true, isRequired: false, transformFunction: null } }, host: { listeners: { "change": "onChange()" }, properties: { "attr.name": "name()", "attr.required": "required()", "attr.disabled": "disabled()", "attr.checked": "checked()", "value": "value()" } }, hostDirectives: [{ directive: RdxVisuallyHiddenDirective, inputs: ["feature", "feature"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenInputBubbleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'input[rdxVisuallyHiddenInputBubble]',
                    hostDirectives: [{ directive: RdxVisuallyHiddenDirective, inputs: ['feature: feature'] }],
                    host: {
                        '[attr.name]': 'name()',
                        '[attr.required]': 'required()',
                        '[attr.disabled]': 'disabled()',
                        '[attr.checked]': 'checked()',
                        '[value]': 'value()',
                        '(change)': 'onChange()'
                    }
                }]
        }], ctorParameters: () => [] });

// Implementation from https://github.com/unovue/radix-vue
class RdxVisuallyHiddenInputDirective {
    constructor() {
        this.elementRef = inject(ElementRef);
        this.name = input('');
        this.value = input();
        this.checked = input(undefined);
        this.required = input(undefined);
        this.disabled = input(undefined);
        this.feature = input('fully-hidden');
        this.parsedValue = computed(() => {
            const value = this.value();
            const name = this.name();
            if (typeof value === 'string' || typeof value === 'number' || typeof value === 'boolean') {
                return [{ name, value }];
            }
            if (Array.isArray(value)) {
                return value.flatMap((obj, index) => {
                    if (typeof obj === 'object') {
                        return Object.entries(obj).map(([key, val]) => ({
                            name: `[${name}][${index}][${key}]`,
                            value: val
                        }));
                    }
                    else {
                        return { name: `[${name}][${index}]`, value: obj };
                    }
                });
            }
            if (value !== null && typeof value === 'object') {
                return Object.entries(value).map(([key, val]) => ({
                    name: `[${name}][${key}]`,
                    value: val
                }));
            }
            return [];
        });
    }
    ngOnInit() {
        const parsedValues = this.parsedValue();
        parsedValues.forEach((parsed) => {
            const inputElement = this.elementRef.nativeElement;
            inputElement.setAttribute('name', parsed.name);
            inputElement.setAttribute('value', parsed.value);
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenInputDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.4", type: RdxVisuallyHiddenInputDirective, isStandalone: true, selector: "[rdxVisuallyHiddenInput]", inputs: { name: { classPropertyName: "name", publicName: "name", isSignal: true, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: true, isRequired: false, transformFunction: null }, checked: { classPropertyName: "checked", publicName: "checked", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, disabled: { classPropertyName: "disabled", publicName: "disabled", isSignal: true, isRequired: false, transformFunction: null }, feature: { classPropertyName: "feature", publicName: "feature", isSignal: true, isRequired: false, transformFunction: null } }, hostDirectives: [{ directive: RdxVisuallyHiddenInputBubbleDirective, inputs: ["feature", "feature", "name", "name", "value", "value", "checked", "checked", "disabled", "disabled", "required", "required"] }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.4", ngImport: i0, type: RdxVisuallyHiddenInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[rdxVisuallyHiddenInput]',
                    hostDirectives: [
                        {
                            directive: RdxVisuallyHiddenInputBubbleDirective,
                            inputs: [
                                'feature: feature',
                                'name: name ',
                                'value: value',
                                'checked: checked',
                                'disabled: disabled',
                                'required: required'
                            ]
                        }
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { RdxVisuallyHiddenDirective, RdxVisuallyHiddenInputBubbleDirective, RdxVisuallyHiddenInputDirective };
//# sourceMappingURL=radix-ng-primitives-visually-hidden.mjs.map
