import { BooleanInput, NumberInput } from '@angular/cdk/coercion';
import { DestroyRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { RdxHoverCardAnchorDirective } from './hover-card-anchor.directive';
import { RdxHoverCardContentDirective } from './hover-card-content.directive';
import { RdxHoverCardTriggerDirective } from './hover-card-trigger.directive';
import { RdxHoverCardAction, RdxHoverCardAnimationStatus, RdxHoverCardAttachDetachEvent, RdxHoverCardState } from './hover-card.types';
import * as i0 from "@angular/core";
/**
 * @group Components
 */
export declare class RdxHoverCardRootDirective {
    /** @ignore */
    readonly uniqueId: import("@angular/core").WritableSignal<number>;
    /** @ignore */
    readonly name: import("@angular/core").Signal<string>;
    /**
     * The anchor directive that comes from outside the hover-card rootDirective
     * @group Props
     * @defaultValue undefined
     */
    readonly anchor: import("@angular/core").InputSignal<RdxHoverCardAnchorDirective | undefined>;
    /**
     * The open state of the hover-card when it is initially rendered. Use when you do not need to control its open state.
     * @group Props
     * @defaultValue false
     */
    readonly defaultOpen: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The controlled state of the hover-card. `open` input takes precedence over `defaultOpen` input.
     * @group Props
     * @defaultValue undefined
     */
    readonly open: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * The delay in milliseconds before the hover-card opens.
     * @group Props
     * @defaultValue 500
     */
    readonly openDelay: import("@angular/core").InputSignalWithTransform<number, NumberInput>;
    /**
     * The delay in milliseconds before the hover-card closes.
     * @group Props
     * @defaultValue 200
     */
    readonly closeDelay: import("@angular/core").InputSignalWithTransform<number, NumberInput>;
    /**
     * Whether to control the state of the hover-card from outside. Use in conjunction with `open` input.
     * @group Props
     * @defaultValue undefined
     */
    readonly externalControl: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * Whether to take into account CSS opening/closing animations.
     * @group Props
     * @defaultValue false
     */
    readonly cssAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether to take into account CSS opening animations. `cssAnimation` input must be set to 'true'
     * @group Props
     * @defaultValue false
     */
    readonly cssOpeningAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Whether to take into account CSS closing animations. `cssAnimation` input must be set to 'true'
     * @group Props
     * @defaultValue false
     */
    readonly cssClosingAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /** @ignore */
    readonly cssAnimationStatus: import("@angular/core").WritableSignal<RdxHoverCardAnimationStatus | null>;
    /** @ignore */
    readonly contentDirective: import("@angular/core").Signal<RdxHoverCardContentDirective>;
    /** @ignore */
    readonly triggerDirective: import("@angular/core").Signal<RdxHoverCardTriggerDirective>;
    /** @ignore */
    readonly arrowDirective: import("@angular/core").Signal<import("@radix-ng/primitives/hover-card").RdxHoverCardArrowDirective | undefined>;
    /** @ignore */
    readonly closeDirective: import("@angular/core").Signal<import("@radix-ng/primitives/hover-card").RdxHoverCardCloseDirective | undefined>;
    /** @ignore */
    readonly contentAttributesComponent: import("@angular/core").Signal<import("@radix-ng/primitives/hover-card").RdxHoverCardContentAttributesComponent | undefined>;
    /** @ignore */
    private readonly internalAnchorDirective;
    /** @ignore */
    readonly viewContainerRef: ViewContainerRef;
    /** @ignore */
    readonly rdxCdkEventService: {
        document: Document;
        destroyRef: DestroyRef;
        ngZone: import("@angular/core").NgZone;
        renderer2: import("@angular/core").Renderer2;
        window: Window & typeof globalThis;
        primitiveConfigs?: import("./utils/types").PrimitiveConfigs;
        onDestroyCallbacks: Set<() => void>;
        "__#14263@#clickDomRootEventCallbacks": Set<(event: MouseEvent) => void>;
        registerPrimitive<T extends object>(primitiveInstance: T): void;
        deregisterPrimitive<T extends object>(primitiveInstance: T): void;
        preventPrimitiveFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        allowPrimitiveForCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        preventPrimitiveFromCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        allowPrimitiveForCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        setPreventPrimitiveFromCdkMixEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").PrimitiveConfig): void;
        primitivePreventedFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): boolean | undefined;
        addClickDomRootEventCallback(callback: (event: MouseEvent) => void): void;
        removeClickDomRootEventCallback(callback: (event: MouseEvent) => void): boolean;
        "__#14263@#setPreventPrimitiveFromCdkEvent"<T extends object, R extends import("./utils/types").EventType, K extends import("./utils/types").PrimitiveConfig[`prevent${Capitalize<R>}`]>(primitiveInstance: T, eventType: R, value: K): void;
        "__#14263@#registerOnDestroyCallbacks"(): void;
        "__#14263@#listenToClickDomRootEvent"(): void;
    } | null;
    /** @ignore */
    readonly destroyRef: DestroyRef;
    /** @ignore */
    readonly state: import("@angular/core").WritableSignal<RdxHoverCardState>;
    /** @ignore */
    readonly attachDetachEvent: import("@angular/core").WritableSignal<RdxHoverCardAttachDetachEvent>;
    /** @ignore */
    private readonly isFirstDefaultOpen;
    /** @ignore */
    readonly anchorDirective: import("@angular/core").Signal<RdxHoverCardAnchorDirective | undefined>;
    /** @ignore */
    readonly actionSubject$: Subject<RdxHoverCardAction>;
    constructor();
    /** @ignore */
    getAnimationParamsSnapshot(): {
        cssAnimation: boolean;
        cssOpeningAnimation: boolean;
        cssClosingAnimation: boolean;
        cssAnimationStatus: RdxHoverCardAnimationStatus | null;
        attachDetachEvent: RdxHoverCardAttachDetachEvent;
        state: RdxHoverCardState;
        canEmitOnOpenOrOnClosed: boolean;
    };
    /** @ignore */
    controlledExternally(): import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /** @ignore */
    firstDefaultOpen(): boolean;
    /** @ignore */
    handleOpen(): void;
    /** @ignore */
    handleClose(closeButton?: boolean): void;
    /** @ignore */
    handleToggle(): void;
    /** @ignore */
    isOpen(state?: RdxHoverCardState): boolean;
    /** @ignore */
    private setState;
    /** @ignore */
    private openContent;
    /** @ignore */
    private closeContent;
    /** @ignore */
    private emitOnOpen;
    /** @ignore */
    private emitOnClosed;
    /** @ignore */
    private ifOpenOrCloseWithoutAnimations;
    /** @ignore */
    private ifOpenOrCloseWithAnimations;
    /** @ignore */
    private openOrClose;
    /** @ignore */
    private emitOnOpenOrOnClosed;
    /** @ignore */
    private canEmitOnOpenOrOnClosed;
    /** @ignore */
    private onStateChangeEffect;
    /** @ignore */
    private onCssAnimationStatusChangeChangeEffect;
    /** @ignore */
    private emitOpenOrClosedEventEffect;
    /** @ignore */
    private onOpenChangeEffect;
    /** @ignore */
    private onIsFirstDefaultOpenChangeEffect;
    /** @ignore */
    private onAnchorChangeEffect;
    /** @ignore */
    private actionSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxHoverCardRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxHoverCardRootDirective, "[rdxHoverCardRoot]", ["rdxHoverCardRoot"], { "anchor": { "alias": "anchor"; "required": false; "isSignal": true; }; "defaultOpen": { "alias": "defaultOpen"; "required": false; "isSignal": true; }; "open": { "alias": "open"; "required": false; "isSignal": true; }; "openDelay": { "alias": "openDelay"; "required": false; "isSignal": true; }; "closeDelay": { "alias": "closeDelay"; "required": false; "isSignal": true; }; "externalControl": { "alias": "externalControl"; "required": false; "isSignal": true; }; "cssAnimation": { "alias": "cssAnimation"; "required": false; "isSignal": true; }; "cssOpeningAnimation": { "alias": "cssOpeningAnimation"; "required": false; "isSignal": true; }; "cssClosingAnimation": { "alias": "cssClosingAnimation"; "required": false; "isSignal": true; }; }, {}, ["contentDirective", "triggerDirective", "arrowDirective", "closeDirective", "contentAttributesComponent", "internalAnchorDirective"], never, true, never>;
}
