export type NavigationMenuOrientation = 'horizontal' | 'vertical';
export type NavigationMenuDirection = 'ltr' | 'rtl';
export type MotionAttribute = 'to-start' | 'to-end' | 'from-start' | 'from-end';
export declare const ROOT_CONTENT_DISMISS = "navigationMenu.rootContentDismiss";
/**
 * Generate a unique ID
 */
export declare function generateId(): string;
/**
 * Get the open state for data-state attribute
 */
export declare function getOpenStateLabel(open: boolean): 'open' | 'closed';
/**
 * Create a trigger ID from base ID and value
 */
export declare function makeTriggerId(baseId: string, value: string): string;
/**
 * Create a content ID from base ID and value
 */
export declare function makeContentId(baseId: string, value: string): string;
/**
 * Get the motion attribute for animations
 */
export declare function getMotionAttribute(currentValue: string | null, previousValue: string | null, itemValue: string, itemValues: string[], dir: NavigationMenuDirection): MotionAttribute | null;
/**
 * Focus the first element in a list of candidates
 * @param candidates Array of elements that can receive focus
 * @param preventScroll Whether to prevent scrolling when focusing
 * @param activateKeyboardNav Whether to dispatch a dummy keydown event to activate keyboard navigation handlers
 * @returns Whether focus was successfully moved
 */
export declare function focusFirst(candidates: HTMLElement[], preventScroll?: boolean, activateKeyboardNav?: boolean): boolean;
/**
 * Get all tabbable candidates in a container
 */
export declare function getTabbableCandidates(container: HTMLElement): HTMLElement[];
/**
 * Remove elements from tab order and return a function to restore them
 */
export declare function removeFromTabOrder(candidates: HTMLElement[]): () => void;
/**
 * Wrap array around itself at given start index
 */
export declare function wrapArray<T>(array: T[], startIndex: number): T[];
