import { BooleanInput } from '@angular/cdk/coercion';
import { DestroyRef, ViewContainerRef } from '@angular/core';
import { RdxPopoverAnchorDirective } from './popover-anchor.directive';
import { RdxPopoverContentDirective } from './popover-content.directive';
import { RdxPopoverTriggerDirective } from './popover-trigger.directive';
import { RdxPopoverAnimationStatus, RdxPopoverAttachDetachEvent, RdxPopoverState } from './popover.types';
import * as i0 from "@angular/core";
export declare class RdxPopoverRootDirective {
    /** @ignore */
    readonly uniqueId: import("@angular/core").WritableSignal<number>;
    /** @ignore */
    readonly name: import("@angular/core").Signal<string>;
    /**
     * @description The anchor directive that comes form outside the popover root
     * @default undefined
     */
    readonly anchor: import("@angular/core").InputSignal<RdxPopoverAnchorDirective | undefined>;
    /**
     * @description The open state of the popover when it is initially rendered. Use when you do not need to control its open state.
     * @default false
     */
    readonly defaultOpen: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description The controlled state of the popover. `open` input take precedence of `defaultOpen` input.
     * @default undefined
     */
    readonly open: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * @description Whether to control the state of the popover from external. Use in conjunction with `open` input.
     * @default undefined
     */
    readonly externalControl: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * @description Whether to take into account CSS opening/closing animations.
     * @default false
     */
    readonly cssAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description Whether to take into account CSS opening animations. `cssAnimation` input must be set to 'true'
     * @default false
     */
    readonly cssOpeningAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description Whether to take into account CSS closing animations. `cssAnimation` input must be set to 'true'
     * @default false
     */
    readonly cssClosingAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /** @ignore */
    readonly cssAnimationStatus: import("@angular/core").WritableSignal<RdxPopoverAnimationStatus | null>;
    /** @ignore */
    readonly popoverContentDirective: import("@angular/core").Signal<RdxPopoverContentDirective>;
    /** @ignore */
    readonly popoverTriggerDirective: import("@angular/core").Signal<RdxPopoverTriggerDirective>;
    /** @ignore */
    readonly popoverArrowDirective: import("@angular/core").Signal<import("@radix-ng/primitives/popover").RdxPopoverArrowDirective | undefined>;
    /** @ignore */
    readonly popoverCloseDirective: import("@angular/core").Signal<import("@radix-ng/primitives/popover").RdxPopoverCloseDirective | undefined>;
    /** @ignore */
    readonly popoverContentAttributesComponent: import("@angular/core").Signal<import("@radix-ng/primitives/popover").RdxPopoverContentAttributesComponent | undefined>;
    /** @ignore */
    private readonly internalPopoverAnchorDirective;
    /** @ignore */
    readonly viewContainerRef: ViewContainerRef;
    /** @ignore */
    readonly rdxCdkEventService: {
        document: Document;
        destroyRef: DestroyRef;
        ngZone: import("@angular/core").NgZone;
        renderer2: import("@angular/core").Renderer2;
        window: Window & typeof globalThis;
        primitiveConfigs?: import("./utils/types").PrimitiveConfigs;
        onDestroyCallbacks: Set<() => void>;
        "__#18641@#clickDomRootEventCallbacks": Set<(event: MouseEvent) => void>;
        registerPrimitive<T extends object>(primitiveInstance: T): void;
        deregisterPrimitive<T extends object>(primitiveInstance: T): void;
        preventPrimitiveFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        allowPrimitiveForCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        preventPrimitiveFromCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        allowPrimitiveForCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        setPreventPrimitiveFromCdkMixEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").PrimitiveConfig): void;
        primitivePreventedFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): boolean | undefined;
        addClickDomRootEventCallback(callback: (event: MouseEvent) => void): void;
        removeClickDomRootEventCallback(callback: (event: MouseEvent) => void): boolean;
        "__#18641@#setPreventPrimitiveFromCdkEvent"<T extends object, R extends import("./utils/types").EventType, K extends import("./utils/types").PrimitiveConfig[`prevent${Capitalize<R>}`]>(primitiveInstance: T, eventType: R, value: K): void;
        "__#18641@#registerOnDestroyCallbacks"(): void;
        "__#18641@#listenToClickDomRootEvent"(): void;
    } | null;
    /** @ignore */
    readonly destroyRef: DestroyRef;
    /** @ignore */
    readonly state: import("@angular/core").WritableSignal<RdxPopoverState>;
    /** @ignore */
    readonly attachDetachEvent: import("@angular/core").WritableSignal<RdxPopoverAttachDetachEvent>;
    /** @ignore */
    private readonly isFirstDefaultOpen;
    /** @ignore */
    readonly popoverAnchorDirective: import("@angular/core").Signal<RdxPopoverAnchorDirective | undefined>;
    constructor();
    /** @ignore */
    getAnimationParamsSnapshot(): {
        cssAnimation: boolean;
        cssOpeningAnimation: boolean;
        cssClosingAnimation: boolean;
        cssAnimationStatus: RdxPopoverAnimationStatus | null;
        attachDetachEvent: RdxPopoverAttachDetachEvent;
        state: RdxPopoverState;
        canEmitOnOpenOrOnClosed: boolean;
    };
    /** @ignore */
    controlledExternally(): import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /** @ignore */
    firstDefaultOpen(): boolean;
    /** @ignore */
    handleOpen(): void;
    /** @ignore */
    handleClose(): void;
    /** @ignore */
    handleToggle(): void;
    /** @ignore */
    isOpen(state?: RdxPopoverState): boolean;
    /** @ignore */
    private setState;
    /** @ignore */
    private openContent;
    /** @ignore */
    private closeContent;
    /** @ignore */
    private emitOnOpen;
    /** @ignore */
    private emitOnClosed;
    /** @ignore */
    private ifOpenOrCloseWithoutAnimations;
    /** @ignore */
    private ifOpenOrCloseWithAnimations;
    /** @ignore */
    private openOrClose;
    /** @ignore */
    private emitOnOpenOrOnClosed;
    /** @ignore */
    private canEmitOnOpenOrOnClosed;
    /** @ignore */
    private onStateChangeEffect;
    /** @ignore */
    private onCssAnimationStatusChangeChangeEffect;
    /** @ignore */
    private emitOpenOrClosedEventEffect;
    /** @ignore */
    private onOpenChangeEffect;
    /** @ignore */
    private onIsFirstDefaultOpenChangeEffect;
    /** @ignore */
    private onAnchorChangeEffect;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxPopoverRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxPopoverRootDirective, "[rdxPopoverRoot]", ["rdxPopoverRoot"], { "anchor": { "alias": "anchor"; "required": false; "isSignal": true; }; "defaultOpen": { "alias": "defaultOpen"; "required": false; "isSignal": true; }; "open": { "alias": "open"; "required": false; "isSignal": true; }; "externalControl": { "alias": "externalControl"; "required": false; "isSignal": true; }; "cssAnimation": { "alias": "cssAnimation"; "required": false; "isSignal": true; }; "cssOpeningAnimation": { "alias": "cssOpeningAnimation"; "required": false; "isSignal": true; }; "cssClosingAnimation": { "alias": "cssClosingAnimation"; "required": false; "isSignal": true; }; }, {}, ["popoverContentDirective", "popoverTriggerDirective", "popoverArrowDirective", "popoverCloseDirective", "popoverContentAttributesComponent", "internalPopoverAnchorDirective"], never, true, never>;
}
