import { InjectionToken } from '@angular/core';
import * as i0 from "@angular/core";
export declare const RdxProgressToken: InjectionToken<RdxProgressRootDirective>;
/**
 * Injects the current instance of RdxProgressRootDirective.
 * @returns The instance of RdxProgressRootDirective.
 */
export declare function injectProgress(): RdxProgressRootDirective;
export type ProgressState = 'indeterminate' | 'complete' | 'loading';
export interface ProgressProps {
    value?: number | null;
    max?: number;
    /**
     * A function to get the accessible label text representing the current value in a human-readable format.
     *
     *  If not provided, the value label will be read as the numeric value as a percentage of the max value.
     */
    getValueLabel?: (value: number, max: number) => string;
}
/**
 * Directive to manage progress bar state and attributes.
 *
 * This directive provides a way to create a progress bar with customizable value and max attributes.
 * It handles aria attributes for accessibility and provides different states like 'indeterminate', 'complete', and 'loading'.
 *
 * @group Components
 */
export declare class RdxProgressRootDirective {
    /**
     * The current value of the progress bar.
     * @group Props
     * @defaultValue 0
     */
    readonly value: import("@angular/core").ModelSignal<number>;
    /**
     * The maximum value of the progress bar.
     * @defaultValue 100
     * @group Props
     */
    readonly max: import("@angular/core").ModelSignal<number>;
    /**
     * Function to generate the value label.
     * @group Props
     */
    readonly valueLabel: import("@angular/core").InputSignal<(value: number, max: number) => string>;
    protected readonly label: import("@angular/core").Signal<string>;
    readonly progressState: import("@angular/core").Signal<ProgressState>;
    constructor();
    private validateValue;
    private validateMax;
    private defaultGetValueLabel;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxProgressRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxProgressRootDirective, "[rdxProgressRoot]", ["rdxProgressRoot"], { "value": { "alias": "value"; "required": false; "isSignal": true; }; "max": { "alias": "max"; "required": false; "isSignal": true; }; "valueLabel": { "alias": "valueLabel"; "required": false; "isSignal": true; }; }, { "value": "valueChange"; "max": "maxChange"; }, never, never, true, never>;
}
