import { ActiveDescendantKeyManager } from '@angular/cdk/a11y';
import { Directionality } from '@angular/cdk/bidi';
import { SelectionModel } from '@angular/cdk/collections';
import { CdkConnectedOverlay, ConnectedPosition, Overlay } from '@angular/cdk/overlay';
import { AfterContentInit, ChangeDetectorRef, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { RdxSelectContentDirective } from './select-content.directive';
import { RdxSelectItemChange, RdxSelectItemDirective } from './select-item.directive';
import { RdxSelectTriggerDirective } from './select-trigger.directive';
import * as i0 from "@angular/core";
export declare class RdxSelectComponent implements OnInit, AfterContentInit {
    protected overlay: Overlay;
    protected elementRef: ElementRef<any>;
    protected changeDetectorRef: ChangeDetectorRef;
    private readonly destroyRef;
    private readonly ngZone;
    protected readonly trigger: import("@angular/core").Signal<RdxSelectTriggerDirective>;
    protected readonly content: import("@angular/core").Signal<RdxSelectContentDirective>;
    readonly items: import("@angular/core").Signal<readonly RdxSelectItemDirective[]>;
    readonly overlayDir: import("@angular/core").Signal<CdkConnectedOverlay>;
    /**
     * Tuple type for the trigger element size. Set by the trigger element itself.
     * The first element is the width and the second element is the height.
     * @returns The size of the trigger element.
     */
    readonly triggerSize: import("@angular/core").WritableSignal<[number, number]>;
    /**
     * The width of the trigger element.
     * @returns The width of the trigger element.
     */
    readonly triggerWidth: import("@angular/core").Signal<number>;
    /** Deals with the selection logic. */
    selectionModel: SelectionModel<RdxSelectItemDirective>;
    /**
     * This position config ensures that the top "start" corner of the overlay
     * is aligned with the top "start" of the origin by default (overlapping
     * the trigger completely). If the panel cannot fit below the trigger, it
     * will fall back to a position above the trigger.
     */
    positions: ConnectedPosition[];
    private closeSubscription;
    /**
     * @ignore
     */
    readonly dir: Directionality | null;
    /**
     * @ignore
     */
    protected keyManager: ActiveDescendantKeyManager<RdxSelectItemDirective>;
    /**
     * @ignore
     */
    readonly id: string;
    defaultValue: string;
    name: string;
    defaultOpen: boolean;
    open: boolean;
    /** Whether the Select is disabled. */
    disabled: boolean;
    required: boolean;
    /**
     * The overlay width will be set to the trigger width if this is true.
     * Otherwise, the overlay width will be set to the width of the content.
     */
    matchTriggerWidth: boolean;
    /**
     * The controlled value of the item to expand
     */
    set value(value: string);
    get value(): string | null;
    private _value?;
    readonly onValueChange: EventEmitter<string>;
    readonly onOpenChange: EventEmitter<boolean>;
    readonly optionSelectionChanges: Observable<RdxSelectItemChange>;
    get selected(): string | null;
    ngOnInit(): void;
    ngAfterContentInit(): void;
    /**
     * Callback that is invoked when the overlay panel has been attached.
     */
    onAttached(): void;
    onDetach(): void;
    /** Toggles the overlay panel open or closed. */
    toggle(): void;
    openPanel(): void;
    close(): void;
    updateActiveItem(item: RdxSelectItemDirective): void;
    private selectDefaultValue;
    private selectValue;
    private closingActions;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxSelectComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<RdxSelectComponent, "[rdxSelect]", never, { "defaultValue": { "alias": "defaultValue"; "required": false; }; "name": { "alias": "name"; "required": false; }; "defaultOpen": { "alias": "defaultOpen"; "required": false; }; "open": { "alias": "open"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "required": { "alias": "required"; "required": false; }; "matchTriggerWidth": { "alias": "matchTriggerWidth"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, { "onValueChange": "onValueChange"; "onOpenChange": "onOpenChange"; }, ["trigger", "content", "items"], ["[rdxSelectTrigger]", "[rdxSelectContent]"], true, never>;
    static ngAcceptInputType_defaultOpen: unknown;
    static ngAcceptInputType_open: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_required: unknown;
    static ngAcceptInputType_matchTriggerWidth: unknown;
}
