import { BooleanInput } from '@angular/cdk/coercion';
import * as i0 from "@angular/core";
declare const ORIENTATIONS: readonly ["horizontal", "vertical"];
export type Orientation = (typeof ORIENTATIONS)[number];
export interface SeparatorProps {
    /**
     * Either `vertical` or `horizontal`. Defaults to `horizontal`.
     */
    orientation?: Orientation;
    /**
     * Whether the component is purely decorative. When true, accessibility-related attributes
     * are updated so that the rendered element is removed from the accessibility tree.
     */
    decorative?: boolean;
}
/**
 * Directive that adds accessible and configurable separator element to the DOM.
 * This can be either horizontal or vertical and optionally decorative (which removes
 * it from the accessibility tree).
 *
 * @group Components
 */
export declare class RdxSeparatorRootDirective {
    /**
     * Orientation of the separator, can be either 'horizontal' or 'vertical'.
     *
     * @defaultValue 'horizontal'
     * @group Props
     */
    readonly orientation: import("@angular/core").InputSignal<"horizontal" | "vertical">;
    /**
     * If true, the separator will be considered decorative and removed from
     * the accessibility tree. Defaults to false.
     *
     * @defaultValue false
     * @group Props
     */
    readonly decorative: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Computes the `role` attribute for the separator. If `decorative` is true,
     * the role is set to "none", otherwise it is "separator".
     *
     * @ignore
     */
    protected readonly decorativeEffect: import("@angular/core").WritableSignal<boolean>;
    protected readonly orientationEffect: import("@angular/core").WritableSignal<"horizontal" | "vertical">;
    /**
     * Computes the `aria-orientation` attribute. It is set to "vertical" only if
     * the separator is not decorative and the orientation is set to "vertical".
     * For horizontal orientation, the attribute is omitted.
     *
     * @ignore
     */
    protected readonly computedAriaOrientation: import("@angular/core").Signal<"vertical" | undefined>;
    updateOrientation(value: Orientation): void;
    updateDecorative(value: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxSeparatorRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxSeparatorRootDirective, "div[rdxSeparatorRoot]", never, { "orientation": { "alias": "orientation"; "required": false; "isSignal": true; }; "decorative": { "alias": "decorative"; "required": false; "isSignal": true; }; }, {}, never, never, true, never>;
}
export {};
