import { BooleanInput } from '@angular/cdk/coercion';
import { InputSignal, InputSignalWithTransform, Signal } from '@angular/core';
import { RdxControlValueAccessor } from '@radix-ng/primitives/core';
import * as i0 from "@angular/core";
import * as i1 from "@radix-ng/primitives/core";
export interface SwitchContext {
    required: InputSignalWithTransform<boolean, BooleanInput>;
    checked: Signal<boolean | undefined>;
    disabled: Signal<boolean | undefined>;
    ariaLabel: InputSignal<string | undefined>;
    ariaLabelledBy: InputSignal<string | undefined>;
    markAsTouched: () => void;
    toggle: () => void;
}
export declare const injectSwitchRootContext: (optional?: boolean) => SwitchContext | null, provideSwitchRootContext: (useFactory: () => SwitchContext) => import("@angular/core").Provider;
/**
 * @group Components
 */
export declare class RdxSwitchRootDirective {
    protected readonly cva: RdxControlValueAccessor<boolean | undefined>;
    readonly id: InputSignal<string>;
    /**
     * When true, indicates that the user must check the switch before the owning form can be submitted.
     *
     * @default false
     * @group Props
     */
    readonly required: InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Establishes relationships between the component and label(s) where its value should be one or more element IDs.
     * @default null
     * @group Props
     */
    readonly ariaLabelledBy: InputSignal<string | undefined>;
    /**
     * Used to define a string that autocomplete attribute the current element.
     * @default null
     * @group Props
     */
    readonly ariaLabel: InputSignal<string | undefined>;
    /**
     * The state of the switch when it is initially rendered. Use when you do not need to control its state.
     * @default false
     * @group Props
     */
    readonly defaultChecked: InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The controlled state of the switch. Must be used in conjunction with onCheckedChange.
     * @defaultValue false
     * @group Props
     */
    readonly checked: import("@angular/core").ModelSignal<boolean>;
    /**
     * When `true`, prevents the user from interacting with the switch.
     * @default false
     * @group Props
     */
    readonly disabled: InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Event handler called when the state of the switch changes.
     *
     * @param {boolean} value - Boolean value indicates that the option is changed.
     * @group Emits
     */
    readonly onCheckedChange: import("@angular/core").OutputRef<boolean | undefined>;
    /**
     * Toggles the checked state of the switch.
     * If the switch is disabled, the function returns early.
     * @ignore
     */
    toggle(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxSwitchRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxSwitchRootDirective, "button[rdxSwitchRoot]", ["rdxSwitchRoot"], { "id": { "alias": "id"; "required": false; "isSignal": true; }; "required": { "alias": "required"; "required": false; "isSignal": true; }; "ariaLabelledBy": { "alias": "aria-labelledby"; "required": false; "isSignal": true; }; "ariaLabel": { "alias": "aria-label"; "required": false; "isSignal": true; }; "defaultChecked": { "alias": "defaultChecked"; "required": false; "isSignal": true; }; "checked": { "alias": "checked"; "required": false; "isSignal": true; }; "disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; }, { "checked": "checkedChange"; "onCheckedChange": "onCheckedChange"; }, never, never, true, [{ directive: typeof i1.RdxControlValueAccessor; inputs: { "value": "checked"; "disabled": "disabled"; }; outputs: {}; }]>;
}
