import { InjectionToken, OnInit } from '@angular/core';
import * as i0 from "@angular/core";
export interface TabsProps {
    /** The value for the selected tab, if controlled */
    value?: string;
    /** The value of the tab to select by default, if uncontrolled */
    defaultValue?: string;
    /** A function called when a new tab is selected */
    onValueChange?: (value: string) => void;
    /**
     * The orientation the tabs are layed out.
     * Mainly so arrow navigation is done accordingly (left & right vs. up & down)
     * @defaultValue horizontal
     */
    orientation?: string;
    /**
     * The direction of navigation between toolbar items.
     */
    dir?: string;
    /**
     * Whether a tab is activated automatically or manually.
     * @defaultValue automatic
     * */
    activationMode?: 'automatic' | 'manual';
}
export type DataOrientation = 'vertical' | 'horizontal';
export declare const RDX_TABS_ROOT_TOKEN: InjectionToken<RdxTabsRootDirective>;
export declare class RdxTabsRootDirective implements OnInit {
    /**
     * The controlled value of the tab to activate. Should be used in conjunction with `onValueChange`.
     */
    readonly value: import("@angular/core").ModelSignal<string | undefined>;
    readonly defaultValue: import("@angular/core").InputSignal<string | undefined>;
    /**
     * When automatic, tabs are activated when receiving focus. When manual, tabs are activated when clicked.
     */
    readonly activationMode: import("@angular/core").InputSignal<"automatic" | "manual">;
    /**
     * The orientation of the component.
     */
    readonly orientation: import("@angular/core").InputSignal<DataOrientation>;
    readonly dir: import("@angular/core").InputSignal<string>;
    /**
     * Event handler called when the value changes.
     */
    readonly onValueChange: import("@angular/core").OutputEmitterRef<string>;
    ngOnInit(): void;
    select(value: string): void;
    /** @ignore */
    getBaseId(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxTabsRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxTabsRootDirective, "[rdxTabsRoot]", never, { "value": { "alias": "value"; "required": false; "isSignal": true; }; "defaultValue": { "alias": "defaultValue"; "required": false; "isSignal": true; }; "activationMode": { "alias": "activationMode"; "required": false; "isSignal": true; }; "orientation": { "alias": "orientation"; "required": false; "isSignal": true; }; "dir": { "alias": "dir"; "required": false; "isSignal": true; }; }, { "value": "valueChange"; "onValueChange": "onValueChange"; }, never, never, true, never>;
}
