import { BooleanInput } from '@angular/cdk/coercion';
import { OutputEmitterRef } from '@angular/core';
import { RdxControlValueAccessor } from '@radix-ng/primitives/core';
import * as i0 from "@angular/core";
import * as i1 from "@radix-ng/primitives/core";
export interface ToggleProps {
    /**
     * The controlled state of the toggle.
     */
    pressed?: boolean;
    /**
     * The state of the toggle when initially rendered. Use `defaultPressed`
     * if you do not need to control the state of the toggle.
     * @defaultValue false
     */
    defaultPressed?: boolean;
    /**
     * The callback that fires when the state of the toggle changes.
     */
    onPressedChange?: OutputEmitterRef<boolean>;
    /**
     * Whether the toggle is disabled.
     * @defaultValue false
     */
    disabled?: boolean;
}
export type DataState = 'on' | 'off';
/**
 * @group Components
 */
export declare class RdxToggleDirective {
    /**
     * @ignore
     */
    readonly cva: RdxControlValueAccessor<any>;
    /**
     * The pressed state of the toggle when it is initially rendered.
     * Use when you do not need to control its pressed state.
     *
     * @group Props
     */
    readonly defaultPressed: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * The controlled pressed state of the toggle.
     * Must be used in conjunction with `onPressedChange`.
     *
     * @group Props
     */
    readonly pressed: import("@angular/core").ModelSignal<boolean>;
    /**
     * When true, prevents the user from interacting with the toggle.
     *
     * @group Props
     */
    readonly disabled: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * Event handler called when the pressed state of the toggle changes.
     *
     * @group Emits
     */
    readonly onPressedChange: import("@angular/core").OutputRef<any>;
    protected onClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxToggleDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxToggleDirective, "[rdxToggle]", ["rdxToggle"], { "defaultPressed": { "alias": "defaultPressed"; "required": false; "isSignal": true; }; "pressed": { "alias": "pressed"; "required": false; "isSignal": true; }; "disabled": { "alias": "disabled"; "required": false; "isSignal": true; }; }, { "pressed": "pressedChange"; "onPressedChange": "onPressedChange"; }, never, never, true, [{ directive: typeof i1.RdxControlValueAccessor; inputs: { "value": "pressed"; "disabled": "disabled"; }; outputs: {}; }]>;
}
