import { BooleanInput, NumberInput } from '@angular/cdk/coercion';
import { DestroyRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { RdxTooltipAnchorDirective } from './tooltip-anchor.directive';
import { RdxTooltipContentDirective } from './tooltip-content.directive';
import { RdxTooltipTriggerDirective } from './tooltip-trigger.directive';
import { RdxTooltipAction, RdxTooltipAnimationStatus, RdxTooltipAttachDetachEvent, RdxTooltipState } from './tooltip.types';
import * as i0 from "@angular/core";
export declare class RdxTooltipRootDirective {
    /** @ignore */
    readonly uniqueId: import("@angular/core").WritableSignal<number>;
    /** @ignore */
    readonly name: import("@angular/core").Signal<string>;
    /**
     * @description The anchor directive that comes form outside the tooltip rootDirective
     * @default undefined
     */
    readonly anchor: import("@angular/core").InputSignal<RdxTooltipAnchorDirective | undefined>;
    /**
     * @description The open state of the tooltip when it is initially rendered. Use when you do not need to control its open state.
     * @default false
     */
    readonly defaultOpen: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description The controlled state of the tooltip. `open` input take precedence of `defaultOpen` input.
     * @default undefined
     */
    readonly open: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * To customise the open delay for a specific tooltip.
     */
    readonly openDelay: import("@angular/core").InputSignalWithTransform<number, NumberInput>;
    /**
     * To customise the close delay for a specific tooltip.
     */
    readonly closeDelay: import("@angular/core").InputSignalWithTransform<number, NumberInput>;
    /**
     * @description Whether to control the state of the tooltip from external. Use in conjunction with `open` input.
     * @default undefined
     */
    readonly externalControl: import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /**
     * @description Whether to take into account CSS opening/closing animations.
     * @default false
     */
    readonly cssAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description Whether to take into account CSS opening animations. `cssAnimation` input must be set to 'true'
     * @default false
     */
    readonly cssOpeningAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /**
     * @description Whether to take into account CSS closing animations. `cssAnimation` input must be set to 'true'
     * @default false
     */
    readonly cssClosingAnimation: import("@angular/core").InputSignalWithTransform<boolean, BooleanInput>;
    /** @ignore */
    readonly cssAnimationStatus: import("@angular/core").WritableSignal<RdxTooltipAnimationStatus | null>;
    /** @ignore */
    readonly contentDirective: import("@angular/core").Signal<RdxTooltipContentDirective>;
    /** @ignore */
    readonly triggerDirective: import("@angular/core").Signal<RdxTooltipTriggerDirective>;
    /** @ignore */
    readonly arrowDirective: import("@angular/core").Signal<import("@radix-ng/primitives/tooltip").RdxTooltipArrowDirective | undefined>;
    /** @ignore */
    readonly closeDirective: import("@angular/core").Signal<import("@radix-ng/primitives/tooltip").RdxTooltipCloseDirective | undefined>;
    /** @ignore */
    readonly contentAttributesComponent: import("@angular/core").Signal<import("@radix-ng/primitives/tooltip").RdxTooltipContentAttributesComponent | undefined>;
    /** @ignore */
    private readonly internalAnchorDirective;
    /** @ignore */
    readonly viewContainerRef: ViewContainerRef;
    /** @ignore */
    readonly rdxCdkEventService: {
        document: Document;
        destroyRef: DestroyRef;
        ngZone: import("@angular/core").NgZone;
        renderer2: import("@angular/core").Renderer2;
        window: Window & typeof globalThis;
        primitiveConfigs?: import("./utils/types").PrimitiveConfigs;
        onDestroyCallbacks: Set<() => void>;
        "__#22490@#clickDomRootEventCallbacks": Set<(event: MouseEvent) => void>;
        registerPrimitive<T extends object>(primitiveInstance: T): void;
        deregisterPrimitive<T extends object>(primitiveInstance: T): void;
        preventPrimitiveFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        allowPrimitiveForCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): void;
        preventPrimitiveFromCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        allowPrimitiveForCdkMultiEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").EventType[]): void;
        setPreventPrimitiveFromCdkMixEvents<T extends object>(primitiveInstance: T, eventTypes: import("./utils/types").PrimitiveConfig): void;
        primitivePreventedFromCdkEvent<T extends object>(primitiveInstance: T, eventType: import("./utils/types").EventType): boolean | undefined;
        addClickDomRootEventCallback(callback: (event: MouseEvent) => void): void;
        removeClickDomRootEventCallback(callback: (event: MouseEvent) => void): boolean;
        "__#22490@#setPreventPrimitiveFromCdkEvent"<T extends object, R extends import("./utils/types").EventType, K extends import("./utils/types").PrimitiveConfig[`prevent${Capitalize<R>}`]>(primitiveInstance: T, eventType: R, value: K): void;
        "__#22490@#registerOnDestroyCallbacks"(): void;
        "__#22490@#listenToClickDomRootEvent"(): void;
    } | null;
    /** @ignore */
    readonly destroyRef: DestroyRef;
    /** @ignore */
    readonly state: import("@angular/core").WritableSignal<RdxTooltipState>;
    /** @ignore */
    readonly attachDetachEvent: import("@angular/core").WritableSignal<RdxTooltipAttachDetachEvent>;
    /** @ignore */
    private readonly isFirstDefaultOpen;
    /** @ignore */
    readonly anchorDirective: import("@angular/core").Signal<RdxTooltipAnchorDirective | undefined>;
    /** @ignore */
    readonly actionSubject$: Subject<RdxTooltipAction>;
    constructor();
    /** @ignore */
    getAnimationParamsSnapshot(): {
        cssAnimation: boolean;
        cssOpeningAnimation: boolean;
        cssClosingAnimation: boolean;
        cssAnimationStatus: RdxTooltipAnimationStatus | null;
        attachDetachEvent: RdxTooltipAttachDetachEvent;
        state: RdxTooltipState;
        canEmitOnOpenOrOnClosed: boolean;
    };
    /** @ignore */
    controlledExternally(): import("@angular/core").InputSignalWithTransform<boolean | undefined, BooleanInput>;
    /** @ignore */
    firstDefaultOpen(): boolean;
    /** @ignore */
    handleOpen(): void;
    /** @ignore */
    handleClose(closeButton?: boolean): void;
    /** @ignore */
    handleToggle(): void;
    /** @ignore */
    isOpen(state?: RdxTooltipState): boolean;
    /** @ignore */
    private setState;
    /** @ignore */
    private openContent;
    /** @ignore */
    private closeContent;
    /** @ignore */
    private emitOnOpen;
    /** @ignore */
    private emitOnClosed;
    /** @ignore */
    private ifOpenOrCloseWithoutAnimations;
    /** @ignore */
    private ifOpenOrCloseWithAnimations;
    /** @ignore */
    private openOrClose;
    /** @ignore */
    private emitOnOpenOrOnClosed;
    /** @ignore */
    private canEmitOnOpenOrOnClosed;
    /** @ignore */
    private onStateChangeEffect;
    /** @ignore */
    private onCssAnimationStatusChangeChangeEffect;
    /** @ignore */
    private emitOpenOrClosedEventEffect;
    /** @ignore */
    private onOpenChangeEffect;
    /** @ignore */
    private onIsFirstDefaultOpenChangeEffect;
    /** @ignore */
    private onAnchorChangeEffect;
    /** @ignore */
    private actionSubscription;
    static ɵfac: i0.ɵɵFactoryDeclaration<RdxTooltipRootDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<RdxTooltipRootDirective, "[rdxTooltipRoot]", ["rdxTooltipRoot"], { "anchor": { "alias": "anchor"; "required": false; "isSignal": true; }; "defaultOpen": { "alias": "defaultOpen"; "required": false; "isSignal": true; }; "open": { "alias": "open"; "required": false; "isSignal": true; }; "openDelay": { "alias": "openDelay"; "required": false; "isSignal": true; }; "closeDelay": { "alias": "closeDelay"; "required": false; "isSignal": true; }; "externalControl": { "alias": "externalControl"; "required": false; "isSignal": true; }; "cssAnimation": { "alias": "cssAnimation"; "required": false; "isSignal": true; }; "cssOpeningAnimation": { "alias": "cssOpeningAnimation"; "required": false; "isSignal": true; }; "cssClosingAnimation": { "alias": "cssClosingAnimation"; "required": false; "isSignal": true; }; }, {}, ["contentDirective", "triggerDirective", "arrowDirective", "closeDirective", "contentAttributesComponent", "internalAnchorDirective"], never, true, never>;
}
